<?xml version="1.0" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"  xmlns:fpml="http://www.fpml.org/2005/FpML-4-2" exclude-result-prefixes="fpml" version="1.0">

<xsl:variable name="version">
<xsl:value-of select="/fpml:SWDML/@version"/>
</xsl:variable>

<xsl:variable name="productType">
<xsl:choose>
<xsl:when test="/fpml:SWDML/fpml:swShortFormTrade/fpml:swFraParameters">FRA</xsl:when>
<xsl:when test="/fpml:SWDML/fpml:swShortFormTrade/fpml:swOisParameters">OIS</xsl:when>
<xsl:when test="/fpml:SWDML/fpml:swShortFormTrade/fpml:swIrsParameters">IRS</xsl:when>
<xsl:when test="/fpml:SWDML/fpml:swShortFormTrade/fpml:swSwaptionParameters">Swaption</xsl:when>
<xsl:when test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails[fpml:swProductType='SingleCurrencyInterestRateSwap']">IRS</xsl:when>
<xsl:when test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails[fpml:swProductType='ZC Inflation Swap']">ZCInflationSwap</xsl:when>
<xsl:otherwise><xsl:value-of select="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swProductType"/></xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="FpMLVersion">
<xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/@version"/>
</xsl:variable>

<xsl:variable name="docsType">
<xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:documentation/fpml:masterConfirmation/fpml:masterConfirmationType"/>
</xsl:variable>

<xsl:template match="fpml:SWDML">
<xsl:variable name="newContext">In <xsl:value-of select="local-name()"/></xsl:variable>

<results version="1.0">


<xsl:if test="not($version='4-2')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Invalid version attribute. Value = '<xsl:value-of select="$version"/>'.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:swShortFormTrade or fpml:swLongFormTrade)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing swShortFormTrade or swLongFormTrade element. Required in this context.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:swLongFormTrade">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</results>
</xsl:template>

<xsl:variable name="productSubType">
<xsl:choose>
<xsl:when test="fpml:SWDML/fpml:swShortFormTrade and $productType='IRS'">
<xsl:value-of select="fpml:SWDML/fpml:swShortFormTrade/fpml:swProductSubType"/>
</xsl:when>
</xsl:choose>
</xsl:variable>

<xsl:variable name="fixedLeg">
<xsl:choose>
<xsl:when test="$productType='ZCInflationSwap'">
<xsl:choose>
<xsl:when test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[1]/fpml:calculationPeriodAmount/fpml:calculation/fpml:inflationRateCalculation">2</xsl:when>
</xsl:choose>
</xsl:when>
<xsl:otherwise>
<xsl:choose>
<xsl:when test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[1]/fpml:resetDates">2</xsl:when>
<xsl:otherwise>1</xsl:otherwise>
</xsl:choose>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>




<xsl:variable name="floatingLeg">
<xsl:choose>
<xsl:when test="$productType='ZCInflationSwap'">
<xsl:choose>
<xsl:when test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swbStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[1]/fpml:calculationPeriodAmount/fpml:calculation/fpml:inflationRateCalculation">1</xsl:when>
</xsl:choose>
</xsl:when>
<xsl:otherwise>
<xsl:choose>
<xsl:when test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[1]/fpml:resetDates">1</xsl:when>
<xsl:otherwise>2</xsl:otherwise>
</xsl:choose>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>


<xsl:variable name="tradeCurrency">
<xsl:choose>
<xsl:when test="fpml:SWDML/fpml:swShortFormTrade">
<xsl:value-of select="fpml:SWDML/fpml:swShortFormTrade//fpml:notional/fpml:currency"/>
</xsl:when>
<xsl:otherwise>
<xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodAmount/fpml:calculation/fpml:notionalSchedule/fpml:notionalStepSchedule/fpml:currency"/>
<xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:fra/fpml:notional/fpml:currency"/>

</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="fixedPaymentFreq">
<xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$fixedLeg]/fpml:paymentDates/fpml:paymentFrequency/fpml:periodMultiplier"/>
<xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$fixedLeg]/fpml:paymentDates/fpml:paymentFrequency/fpml:period"/>
</xsl:variable>

<xsl:variable name="FixedAmount">
<xsl:if test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$fixedLeg]/fpml:calculationPeriodAmount/fpml:knownAmountSchedule">
<xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$fixedLeg]/fpml:calculationPeriodAmount/fpml:knownAmountSchedule/fpml:initialValue"/>
</xsl:if>
</xsl:variable>

<xsl:variable name="FixedNotional">
<xsl:if test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$fixedLeg]/fpml:calculationPeriodAmount/fpml:calculation">
<xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$fixedLeg]/fpml:calculationPeriodAmount/fpml:calculation/fpml:initialValue"/>
</xsl:if>
</xsl:variable>

<xsl:variable name="interestRateSwapType">
<xsl:choose>
<xsl:when test="($productType='IRS' and $fixedPaymentFreq = '1T' and /fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$fixedLeg]/fpml:calculationPeriodAmount/fpml:knownAmountSchedule and /fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodAmount/fpml:calculation )"><xsl:value-of select="'fpml:zeroCouponInterestRateSwapWithFixedAmount'"/>
</xsl:when>
<xsl:when test="($productType='IRS' and $fixedPaymentFreq = '1T' and
/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodAmount/fpml:calculation and /fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$fixedLeg]/fpml:calculationPeriodAmount/fpml:calculation)"><xsl:value-of select="'fpml:zeroCouponInterestRateSwapWithFixedNotional'"/>
</xsl:when>
<xsl:otherwise><xsl:value-of select="'fpml:someOtherInterestRateProduct'"/></xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="isZeroCouponInterestRateSwap">
<xsl:choose>
<xsl:when test="($interestRateSwapType='zeroCouponInterestRateSwapWithFixedAmount' or $interestRateSwapType='zeroCouponInterestRateSwapWithFixedNotional')"><xsl:value-of select="'true'"/>
</xsl:when>
<xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise>
</xsl:choose>
</xsl:variable>


<xsl:variable name="participantSupplement">
<xsl:choose>
<xsl:when test="fpml:SWDML/fpml:swShortFormTrade">
<xsl:value-of select="fpml:SWDML/fpml:swShortFormTrade/fpml:swParticipantSupplement"/>
</xsl:when>
<xsl:otherwise>
<xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swParticipantSupplement"/>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="isLongFormTrade">
<xsl:choose>
<xsl:when test="fpml:SWDML/fpml:swLongFormTrade">1</xsl:when>
<xsl:otherwise>0</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="isPrimeBrokerTrade">
<xsl:choose>
<xsl:when test="fpml:SWDML//fpml:swGiveUp">1</xsl:when>
<xsl:otherwise>0</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="isNovationTrade">
<xsl:choose>
<xsl:when test="fpml:SWDML//fpml:novation">1</xsl:when>
<xsl:otherwise>0</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="isAllocatedTrade">
<xsl:choose>
<xsl:when test="fpml:SWDML//fpml:swAllocations">1</xsl:when>
<xsl:otherwise>0</xsl:otherwise>
</xsl:choose>
</xsl:variable>


<xsl:variable name="blockAdditionalPaymentCount">
<xsl:value-of select="count(fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment)"/>
</xsl:variable>

<xsl:variable name="isBlockIndependentAmountPresent">
<xsl:for-each select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment">
<xsl:choose>
<xsl:when test="fpml:paymentType='Independent Amount'">true</xsl:when>
</xsl:choose>
</xsl:for-each>
</xsl:variable>

<xsl:variable name="test1">
<xsl:choose>
<xsl:when test="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=1] and (not(//fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=1]/fpml:paymentType) or /fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=1]/fpml:paymentType !='Independent Amount')">1</xsl:when>
<xsl:otherwise>0</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="test2">
<xsl:choose>
<xsl:when test="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=2] and (not(//fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=2]/fpml:paymentType) or /fpml:SWDML/fpml:swStructuredTradeDetails/fpml:additionalPayment[position()=2]/fpml:paymentType !='Independent Amount')">1</xsl:when>
<xsl:otherwise>0</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="test3">
<xsl:choose>
<xsl:when test="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=3] and (not(/fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=3]/fpml:paymentType) or /fpml:SWDML/fpml:swStructuredTradeDetails/fpml:additionalPayment[position()=3]/fpml:paymentType !='Independent Amount')">1</xsl:when>
<xsl:otherwise>0</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="test4">
<xsl:choose>
<xsl:when test="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=4] and (not(/fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=4]/fpml:paymentType) or /fpml:SWDML/fpml:swStructuredTradeDetails/fpml:additionalPayment[position()=4]/fpml:paymentType !='Independent Amount')">1</xsl:when>
<xsl:otherwise>0</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="test5">
<xsl:choose>
<xsl:when test="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=5] and (not(/fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=5]/fpml:paymentType) or /fpml:SWDML/fpml:swStructuredTradeDetails/fpml:additionalPayment[position()=5]/fpml:paymentType !='Independent Amount')">1</xsl:when>
<xsl:otherwise>0</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="test6">
<xsl:choose>
<xsl:when test="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=6] and (not(/fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=6]/fpml:paymentType) or /fpml:SWDML/fpml:swStructuredTradeDetails/fpml:additionalPayment[position()=6]/fpml:paymentType !='Independent Amount')">1</xsl:when>
<xsl:otherwise>0</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="test7">
<xsl:choose>
<xsl:when test="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=7] and (not(/fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=7]/fpml:paymentType) or /fpml:SWDML/fpml:swStructuredTradeDetails/fpml:additionalPayment[position()=7]/fpml:paymentType !='Independent Amount')">1</xsl:when>
<xsl:otherwise>0</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="blockAdditionalPayCurrency1">
<xsl:choose>
<xsl:when test="$test1">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=1]/fpml:paymentAmount/fpml:currency"/>
</xsl:when>
<xsl:when test="$test2">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=2]/fpml:paymentAmount/fpml:currency"/>
</xsl:when>
<xsl:when test="$test3">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=3]/fpml:paymentAmount/fpml:currency"/>
</xsl:when>
</xsl:choose>
</xsl:variable>

<xsl:variable name="blockAdditionalPayUnadjDate1">
<xsl:choose>
<xsl:when test="$test1">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=1]/fpml:paymentDate/fpml:unadjustedDate"/>
</xsl:when>
<xsl:when test="$test2">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=2]/fpml:paymentDate/fpml:unadjustedDate"/>
</xsl:when>
<xsl:when test="$test3">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=3]/fpml:paymentDate/fpml:unadjustedDate"/>
</xsl:when>
</xsl:choose>
</xsl:variable>

<xsl:variable name="blockAdditionalPayConvention1">
<xsl:choose>
<xsl:when test="$test1">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=1]/fpml:paymentDate/fpml:dateAdjustments/fpml:businessDayConvention"/>
</xsl:when>
<xsl:when test="$test2">
<xsl:value-of select="fpml:SWDML/fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=2]/fpml:paymentDate/fpml:dateAdjustments/fpml:businessDayConvention"/>
</xsl:when>
<xsl:when test="$test3">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=3]/fpml:paymentDate/fpml:dateAdjustments/fpml:businessDayConvention"/>
</xsl:when>
</xsl:choose>
</xsl:variable>

<xsl:variable name="blockAdditionalPayBusCenters1">
<xsl:choose>
<xsl:when test="$test1">
<xsl:for-each select="fpml:SWDML//fpml:swStructuredTradeDetails/fpml:additionalPayment[position()=1]/fpml:paymentDate/fpml:dateAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:when>
<xsl:when test="$test2">
<xsl:for-each select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=2]/fpml:paymentDate/fpml:dateAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:when>
<xsl:when test="$test3">
<xsl:for-each select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=3]/fpml:paymentDate/fpml:dateAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:when>
</xsl:choose>
</xsl:variable>

<xsl:variable name="blockAdditionalPayType1">
<xsl:choose>
<xsl:when test="$test1">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=1]/fpml:paymentType"/>
</xsl:when>
<xsl:when test="$test2">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=2]/fpml:paymentType"/>
</xsl:when>
<xsl:when test="$test3">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=3]/fpml:paymentType"/>
</xsl:when>
</xsl:choose>
</xsl:variable>

<xsl:variable name="blockAdditionalPayCurrency2">
<xsl:choose>
<xsl:when test="$test2">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=2]/fpml:paymentAmount/fpml:currency"/>
</xsl:when>
<xsl:when test="$test3">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=3]/fpml:paymentAmount/fpml:currency"/>
</xsl:when>
</xsl:choose>
</xsl:variable>

<xsl:variable name="blockAdditionalPayUnadjDate2">
<xsl:choose>
<xsl:when test="$test2">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=2]/fpml:paymentDate/fpml:unadjustedDate"/>
</xsl:when>
<xsl:when test="$test3">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=3]/fpml:paymentDate/fpml:unadjustedDate"/>
</xsl:when>
</xsl:choose>
</xsl:variable>

<xsl:variable name="blockAdditionalPayConvention2">
<xsl:choose>
<xsl:when test="$test2">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=2]/fpml:paymentDate/fpml:dateAdjustments/fpml:businessDayConvention"/>
</xsl:when>
<xsl:when test="$test3">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=3]/fpml:paymentDate/fpml:dateAdjustments/fpml:businessDayConvention"/>
</xsl:when>
</xsl:choose>
</xsl:variable>

<xsl:variable name="blockAdditionalPayBusCenters2">
<xsl:choose>
<xsl:when test="$test2">
<xsl:for-each select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=2]/fpml:paymentDate/fpml:dateAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:when>
<xsl:when test="$test3">
<xsl:for-each select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=3]/fpml:paymentDate/fpml:dateAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:when>
</xsl:choose>
</xsl:variable>

<xsl:variable name="blockAdditionalPayType2">
<xsl:choose>
<xsl:when test="$test2">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=2]/fpml:paymentType"/>
</xsl:when>
<xsl:when test="$test3">
<xsl:value-of select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment[position()=3]/fpml:paymentType"/>
</xsl:when>
</xsl:choose>
</xsl:variable>

<xsl:variable name="blockIndependentAmountCurrency">
<xsl:for-each select="fpml:SWDML//fpml:swStructuredTradeDetails//fpml:additionalPayment">
<xsl:choose>
<xsl:when test="fpml:paymentType='Independent Amount'">
<xsl:value-of select="fpml:paymentAmount/fpml:currency"/>
</xsl:when>
</xsl:choose>
</xsl:for-each>
</xsl:variable>

<xsl:template match="fpml:swGiveUp">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:variable name="hrefC"><xsl:value-of select="fpml:swCustomerTransaction/fpml:swCustomer/@href"/></xsl:variable>
<xsl:variable name="hrefD"><xsl:value-of select="fpml:swInterDealerTransaction/fpml:swExecutingDealer/@href"/></xsl:variable>
<xsl:variable name="hrefCPB"><xsl:value-of select="fpml:swCustomerTransaction/fpml:swPrimeBroker/@href"/></xsl:variable>
<xsl:variable name="hrefDPB"><xsl:value-of select="fpml:swInterDealerTransaction/fpml:swPrimeBroker/@href"/></xsl:variable>


<xsl:if test="$hrefC=$hrefD">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swCustomerTransaction/swCustomer/@href and swInterDealerTransaction/swExecutingDealer/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="$hrefC=$hrefCPB">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swCustomerTransaction/swCustomer/@href and swCustomerTransaction/swPrimeBroker/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="$hrefD=$hrefCPB">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swInterDealerTransaction/swExecutingDealer/@href and swCustomerTransaction/swPrimeBroker/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="$hrefD=$hrefDPB">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swInterDealerTransaction/swExecutingDealer/@href and swInterDealerTransaction/swPrimeBroker/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="$hrefC=$hrefDPB">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swCustomerTransaction/swCustomer/@href and swInterDealerTransaction/swPrimeBroker/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$hrefC])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swCustomerTransaction/swCustomer/@href does not reference a valid FpML/trade/party/@id. Value = '<xsl:value-of select="$hrefC"/>'.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$hrefCPB])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swCustomerTransaction/swPrimeBroker/@href does not reference a valid FpML/trade/party/@id. Value = '<xsl:value-of select="$hrefCPB"/>'.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$hrefD])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swInterDealerTransaction/swExecutingDealer/@href does not reference a valid FpML/trade/party/@id. Value = '<xsl:value-of select="$hrefD"/>'.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$hrefDPB])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swInterDealerTransaction/swPrimeBroker/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$hrefDPB"/>'.</text></error>
</xsl:if>


<xsl:if test="$hrefDPB=$hrefCPB">
<xsl:if test="count(//fpml:FpML/fpml:party) != 3">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of party child elements encountered. 3 expected.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="$hrefDPB!=$hrefCPB">
<xsl:if test="count(//fpml:FpML/fpml:party) != 4">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of party child elements encountered. 4 expected.</text></error>
</xsl:if>
</xsl:if>



<xsl:if test="$productType = 'OIS' or $productType = 'IRS' or $productType='Swaption'">
<xsl:if test="($hrefD != //fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:payerPartyReference/@href) and ($hrefD != //fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:receiverPartyReference/@href)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swInterDealerTransaction/swExecutingDealer/@href must be a payer or receiver on swap if product type is 'SingleCurrencyInterestRateSwap', 'OIS' or 'Swaption'.</text></error>
</xsl:if>
<xsl:if test="($hrefC != //fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:receiverPartyReference/@href) and ($hrefC != //fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:payerPartyReference/@href)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swCustomerTransaction/swCustomer/@href must be a payer or receiver on swap if product type is 'SingleCurrencyInterestRateSwap', 'OIS' or 'Swaption'.</text></error>
</xsl:if>
</xsl:if>



<xsl:if test="$productType = 'FRA'">
<xsl:if test="($hrefD != //fpml:FpML/fpml:trade//fpml:fra/fpml:buyerPartyReference/@href) and ($hrefD != //fpml:FpML/fpml:trade//fpml:fra/fpml:sellerPartyReference/@href)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swInterDealerTransaction/swExecutingDealer/@href must be a buyer or seller on FRA if product type is 'FRA'.</text></error>
</xsl:if>
<xsl:if test="($hrefC != //fpml:FpML/fpml:trade//fpml:fra/fpml:sellerPartyReference/@href) and ($hrefC != //fpml:FpML/fpml:trade//fpml:fra/fpml:buyerPartyReference/@href)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swCustomerTransaction/swCustomer/@href must be a buyer or seller on FRA if product type is 'FRA'.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="$productType = 'IRS' or $productType='Swaption'">
<xsl:if test=".//fpml:swEarlyTerminationProvision">
<error><context><xsl:value-of select="$newContext"/></context><text>*** ./swEarlyTerminationProvision must not be specified in a Primary Prime Brokered Trade.</text></error>
</xsl:if>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:swAllocations">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:swAllocation">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>
</xsl:template>

<xsl:template match="fpml:swAllocation">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>


<xsl:apply-templates select="fpml:allocatedNotional">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:variable name="AddPayNumber">
<xsl:value-of select="count(fpml:additionalPayment)"/>
</xsl:variable>


<xsl:if test="$AddPayNumber>2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of additionalPayment child elements encountered. 0 to 2 expected.</text></error>
</xsl:if>


<xsl:if test="($blockAdditionalPaymentCount=2 and $isBlockIndependentAmountPresent='true' and $AddPayNumber>1) or ($blockAdditionalPaymentCount=1 and $isBlockIndependentAmountPresent='true' and $AddPayNumber>0) or ($blockAdditionalPaymentCount=1 and $isBlockIndependentAmountPresent!='true' and $AddPayNumber>1) or ($blockAdditionalPaymentCount=0 and $AddPayNumber>0)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** There must not be more additionalPayment child elements in swAllocation than in the block trade.</text></error>
</xsl:if>

<xsl:if test="$productType = 'OIS' or $productType = 'IRS'">

<xsl:if test="not(//fpml:swStreamReference)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swStreamReference must be present if product type is 'SingleCurrencyInterestRateSwap' or 'OIS'.</text></error>
</xsl:if>

<xsl:variable name="payerPartyRef">
<xsl:value-of select="fpml:payerPartyReference/@href"/>
</xsl:variable>

<xsl:variable name="receiverPartyRef">
<xsl:value-of select="fpml:receiverPartyReference/@href"/>
</xsl:variable>


<xsl:if test="$payerPartyRef=$receiverPartyRef">
<error><context><xsl:value-of select="$newContext"/></context><text>*** fpml:payerPartyReference/@href and receiverPartyReference/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$payerPartyRef])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** fpml:payerPartyReference/@href does not reference a valid FpML/trade/party/@id. Value = '<xsl:value-of select="$payerPartyRef"/>'.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$receiverPartyRef])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** receiverPartyReference/@href does not reference a valid FpML/trade/party/@id. Value = '<xsl:value-of select="$receiverPartyRef"/>'.</text></error>
</xsl:if>

<xsl:variable name="payerPartyId">
<xsl:value-of select="//fpml:FpML/fpml:party[@id=$payerPartyRef]/fpml:partyId"/>
</xsl:variable>

<xsl:variable name="receiverPartyId">
<xsl:value-of select="//fpml:FpML/fpml:party[@id=$receiverPartyRef]/fpml:partyId"/>
</xsl:variable>


<xsl:if test="$payerPartyId=$receiverPartyId">
<error><context><xsl:value-of select="$newContext"/></context><text>*** partyId (legal entity) referenced by payerPartyReference/@href must not equal partyId (legal entity) referenced by receiverPartyReference/@href.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:independentAmount">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
<xsl:with-param name="allocPartyA"><xsl:value-of select="$payerPartyRef"/></xsl:with-param>
<xsl:with-param name="allocPartyB"><xsl:value-of select="$receiverPartyRef"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates mode="allocation" select="fpml:additionalPayment">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
<xsl:with-param name="allocPartyA"><xsl:value-of select="$payerPartyRef"/></xsl:with-param>
<xsl:with-param name="allocPartyB"><xsl:value-of select="$receiverPartyRef"/></xsl:with-param>
</xsl:apply-templates>

</xsl:if>


<xsl:if test="$productType = 'Swaption' or $productType = 'FRA'">
<xsl:if test="not(//fpml:buyerPartyReference)">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference must be present if product type is 'Swaption' or 'FRA'.</text></error>
</xsl:if>

<xsl:variable name="fpml:buyerPartyRef">
<xsl:value-of select="fpml:buyerPartyReference/@href"/>
</xsl:variable>

<xsl:variable name="fpml:sellerPartyRef">
<xsl:value-of select="fpml:sellerPartyReference/@href"/>
</xsl:variable>


<xsl:if test="$buyerPartyRef=$sellerPartyRef">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href and sellerPartyReference/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$buyerPartyRef])">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$buyerPartyRef"/>'.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$sellerPartyRef])">
<error><context><xsl:value-of select="$newContext"/></context><text>***sellerPartyReference/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$sellerPartyRef"/>'.</text></error>
</xsl:if>

<xsl:variable name="buyerPartyId">
<xsl:value-of select="//fpml:FpML/fpml:party[@id=$buyerPartyRef]/fpml:partyId"/>
</xsl:variable>

<xsl:variable name="sellerPartyId">
<xsl:value-of select="//fpml:FpML/fpml:party[@id=$sellerPartyRef]/fpml:partyId"/>
</xsl:variable>


<xsl:if test="$buyerPartyId=$sellerPartyId">
<error><context><xsl:value-of select="$newContext"/></context><text>*** partyId (legal entity) referenced by buyerPartyReference/@href must not equal partyId (legal entity) referenced by sellerPartyReference/@href.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:independentAmount">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
<xsl:with-param name="allocPartyA"><xsl:value-of select="$buyerPartyRef"/></xsl:with-param>
<xsl:with-param name="allocPartyB"><xsl:value-of select="$sellerPartyRef"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates mode="allocation" select="fpml:additionalPayment">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
<xsl:with-param name="allocPartyA"><xsl:value-of select="$buyerPartyRef"/></xsl:with-param>
<xsl:with-param name="allocPartyB"><xsl:value-of select="$sellerPartyRef"/></xsl:with-param>
</xsl:apply-templates>

</xsl:if>


<xsl:if test="fpml:swSalesCredit">
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">swSalesCredit</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swSalesCredit"/></xsl:with-param>
<xsl:with-param name="minIncl">0.01</xsl:with-param>
<xsl:with-param name="maxIncl">999999999999.99</xsl:with-param>
<xsl:with-param name="maxDecs">2</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:allocatedNotional">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:variable name="allocatedNotionalCurrency">
<xsl:value-of select="fpml:currency"/>
</xsl:variable>


<xsl:if test="$allocatedNotionalCurrency != $tradeCurrency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** allocatedNotional/currency must be the same as the block notional currency within an allocated trade. Value = '<xsl:value-of select="$allocatedNotionalCurrency"/>'.</text></error>
</xsl:if>


<xsl:call-template name="isValidCurrency">
<xsl:with-param name="elementName">currency</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:currency"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="amount"><xsl:value-of select="fpml:amount"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">amount</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$amount"/></xsl:with-param>
<xsl:with-param name="minIncl">0.01</xsl:with-param>
<xsl:with-param name="maxIncl">999999999999.99</xsl:with-param>
<xsl:with-param name="maxDecs">2</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:template>


<xsl:template match="fpml:independentAmount">
<xsl:param name="context"/>
<xsl:param name="allocPartyA"/>
<xsl:param name="allocPartyB"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:variable name="payerPartyRef">
<xsl:value-of select="fpml:payerPartyReference/@href"/>
</xsl:variable>

<xsl:variable name="receiverPartyRef">
<xsl:value-of select="fpml:receiverPartyReference/@href"/>
</xsl:variable>


<xsl:if test="$payerPartyRef=$receiverPartyRef">
<error><context><xsl:value-of select="$newContext"/></context><text>*** payerPartyReference/@href and receiverPartyReference/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="$payerPartyRef!=$allocPartyA and $payerPartyRef!=$allocPartyB">
<error><context><xsl:value-of select="$newContext"/></context><text>*** payerPartyReference/@href must reference one of the parties to the allocation.</text></error>
</xsl:if>


<xsl:if test="$receiverPartyRef!=$allocPartyA and $receiverPartyRef!=$allocPartyB">
<error><context><xsl:value-of select="$newContext"/></context><text>*** receiverPartyReference/@href must reference one of the parties to the allocation.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:paymentDetail">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:paymentDetail">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:paymentAmount">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:variable name="currency">
<xsl:value-of select="fpml:paymentAmount/fpml:currency"/>
</xsl:variable>


<xsl:if test="$currency!=$blockIndependentAmountCurrency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** paymentAmount/currency must equal the block trade independent amount currency.</text></error>
</xsl:if>

</xsl:template>


<xsl:template mode="allocation" match="fpml:additionalPayment">
<xsl:param name="context"/>
<xsl:param name="allocPartyA"/>
<xsl:param name="allocPartyB"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>



<xsl:if test="not(@seq)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing @seq attribute. Required in this context.</text></error>
</xsl:if>

<xsl:variable name="payerPartyRef">
<xsl:value-of select="fpml:payerPartyReference/@href"/>
</xsl:variable>

<xsl:variable name="receiverPartyRef">
<xsl:value-of select="fpml:receiverPartyReference/@href"/>
</xsl:variable>


<xsl:if test="$payerPartyRef=$receiverPartyRef">
<error><context><xsl:value-of select="$newContext"/></context><text>*** payerPartyReference/@href and receiverPartyReference/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="$payerPartyRef!=$allocPartyA and $payerPartyRef!=$allocPartyB">
<error><context><xsl:value-of select="$newContext"/></context><text>*** payerPartyReference/@href must reference one of the parties to the allocation.</text></error>
</xsl:if>


<xsl:if test="$receiverPartyRef!=$allocPartyA and $receiverPartyRef!=$allocPartyB">
<error><context><xsl:value-of select="$newContext"/></context><text>*** receiverPartyReference/@href must reference one of the parties to the allocation.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:paymentAmount">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="not(fpml:paymentDate)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing paymentDate. Required in this context.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:paymentDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:variable name="allocAdditionalPayCurrency">
<xsl:value-of select="fpml:paymentAmount/fpml:currency"/>
</xsl:variable>

<xsl:variable name="allocAdditionalPayUnadjDate">
<xsl:value-of select="fpml:paymentDate/fpml:unadjustedDate"/>
</xsl:variable>

<xsl:variable name="allocAdditionalPayConvention">
<xsl:value-of select="fpml:paymentDate/fpml:dateAdjustments/fpml:businessDayConvention"/>
</xsl:variable>

<xsl:variable name="allocAdditionalPayBusCenters">
<xsl:for-each select="fpml:paymentDate/fpml:dateAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>

<xsl:variable name="allocAdditionalPayType">
<xsl:value-of select="fpml:paymentType"/>
</xsl:variable>

<xsl:choose>
<xsl:when test="@seq='1'">

<xsl:if test="$allocAdditionalPayCurrency!=$blockAdditionalPayCurrency1">
<error><context><xsl:value-of select="$newContext"/></context><text>*** paymentAmount/currency must equal thepaymentAmount/currency of the corresponding additional payment on the block trade.</text></error>
</xsl:if>


<xsl:if test="$allocAdditionalPayUnadjDate!=$blockAdditionalPayUnadjDate1">
<error><context><xsl:value-of select="$newContext"/></context><text>*** paymentDate/unadjustedDate must equal the paymentDate/unadjustedDate of the corresponding additional payment on the block trade..</text></error>
</xsl:if>


<xsl:if test="$allocAdditionalPayConvention!=$blockAdditionalPayConvention1">
<error><context><xsl:value-of select="$newContext"/></context><text>*** paymentDate/dateAdjustments/businessDayConvention must equal the paymentDate/dateAdjustments/businessDayConvention of the corresponding additional payment on the block trade.</text></error>
</xsl:if>


<xsl:if test="$allocAdditionalPayBusCenters!=$blockAdditionalPayBusCenters1">
<error><context><xsl:value-of select="$newContext"/></context><text>*** paymentDate/dateAdjustments/businessCenters must equal the paymentDate/dateAdjustments/businessCenters of the corresponding additional payment on the block trade.</text></error>
</xsl:if>


<xsl:if test="$allocAdditionalPayType!=$blockAdditionalPayType1">
<error><context><xsl:value-of select="$newContext"/></context><text>*** paymentType must equal the paymentType of the corresponding additional payment on the block trade.</text></error>
</xsl:if>
</xsl:when>

<xsl:when test="@seq='2'">

<xsl:if test="$allocAdditionalPayCurrency!=$blockAdditionalPayCurrency2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** paymentAmount/currency must equal the paymentAmount/currency of the corresponding additional payment on the block trade.</text></error>
</xsl:if>


<xsl:if test="$allocAdditionalPayUnadjDate!=$blockAdditionalPayUnadjDate2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** paymentDate/unadjustedDate must equal the paymentDate/unadjustedDate of the corresponding additional payment on the block trade..</text></error>
</xsl:if>


<xsl:if test="$allocAdditionalPayConvention!=$blockAdditionalPayConvention2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** paymentDate/dateAdjustments/businessDayConvention must equal the paymentDate/dateAdjustments/businessDayConvention of the corresponding additional payment on the block trade.</text></error>
</xsl:if>


<xsl:if test="$allocAdditionalPayBusCenters!=$blockAdditionalPayBusCenters2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** paymentDate/fpml:dateAdjustments/businessCenters must equal the paymentDate/dateAdjustments/businessCenters of the corresponding additional payment on the block trade.</text></error>
</xsl:if>


<xsl:if test="$allocAdditionalPayType!=$blockAdditionalPayType2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** paymentType must equal the paymentType of the corresponding additional payment on the block trade.</text></error>
</xsl:if>
</xsl:when>
</xsl:choose>

</xsl:template>


<xsl:template match="fpml:novation">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="transferor"><xsl:value-of select="fpml:transferor/@href"/></xsl:variable>
<xsl:if test="not(//fpml:FpML/fpml:party[@id=$transferor])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** transferor/@href does not reference a valid FpML/trade/party/@id. Value = '<xsl:value-of select="$transferor"/>'.</text></error>
</xsl:if>


<xsl:variable name="transferee"><xsl:value-of select="fpml:transferee/@href"/></xsl:variable>
<xsl:if test="not(//fpml:FpML/fpml:party[@id=$transferee])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** transferee/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$transferee"/>'.</text></error>
</xsl:if>


<xsl:variable name="remainingParty"><xsl:value-of select="fpml:remainingParty/@href"/></xsl:variable>
<xsl:if test="not(//fpml:FpML/fpml:party[@id=$remainingParty])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** remainingParty/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$remainingParty"/>'.</text></error>
</xsl:if>



<xsl:variable name="otherRemainingParty"><xsl:value-of select="fpml:otherRemainingParty/@href"/></xsl:variable>
<xsl:if test="fpml:otherRemainingParty">
<xsl:if test="not(//fpml:FpML/fpml:party[@id=$otherRemainingParty])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** otherRemainingParty/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$otherRemainingParty"/>'.</text></error>
</xsl:if>

<xsl:if test="$remainingParty = $otherRemainingParty">
<error><context><xsl:value-of select="$newContext"/></context><text>***otherRemainingParty/@href must not equal remainingParty/@href.</text></error>
</xsl:if>
</xsl:if>


<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">novationDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:novationDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">novationTradeDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:novationTradeDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="novationTradeDate"><xsl:value-of select="fpml:novationTradeDate"/></xsl:variable>
<xsl:variable name="novationDate"><xsl:value-of select="fpml:novationDate"/></xsl:variable>
<xsl:variable name="novTradeDate"><xsl:value-of select="number(concat(substring($novationTradeDate,1,4),substring($novationTradeDate,6,2),substring($novationTradeDate,9,2)))"/></xsl:variable>
<xsl:variable name="novDate"><xsl:value-of select="number(concat(substring($novationDate,1,4),substring($novationDate,6,2),substring($novationDate,9,2)))"/></xsl:variable>
<xsl:if test="$novDate &lt; $novTradeDate"><error><context><xsl:value-of select="$newContext"/></context><text>*** The novationDate must be greater than or equal to the novationTradeDate.</text></error></xsl:if>


<xsl:if test="not($productType='Swaption')">
<xsl:call-template name="isValidBoolean">
<xsl:with-param name="elementName">fullFirstCalculationPeriod</xsl:with-param>
<xsl:with-param name="elementValue">
<xsl:value-of select="fpml:fullFirstCalculationPeriod"/>
</xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context">
<xsl:value-of select="$newContext"/>
</xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="not(fpml:novatedamount)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing fpml:novatedamount. Required in this context.</text></error>
</xsl:if>


<xsl:if test="fpml:novatedamount/fpml:currency != $tradeCurrency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** novatedamount/currency must equal trade currency.</text></error>
</xsl:if>


<xsl:variable name="tradeNotional">
<xsl:choose>
<xsl:when test="$productType='IRS' or $productType='OIS' or $productType='Swaption'">
<xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodAmount/fpml:calculation/fpml:notionalSchedule/fpml:notionalStepSchedule/fpml:initialValue"/>
</xsl:when>
<xsl:when test="$productType='FRA'">
<xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:fra/fpml:notional/fpml:amount"/>
</xsl:when>
<xsl:when test="$productType='capFloor'">
<xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:capFloor/fpml:capFloorStream/fpml:calculationPeriodAmount/fpml:calculation/fpml:notionalSchedule/fpml:notionalStepSchedule/fpml:initialValue"/>
</xsl:when>
</xsl:choose>
</xsl:variable>
<xsl:if test="number(fpml:novatedamount/fpml:amount) != number($tradeNotional)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** novatedamount/notional must equal trade notional.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:novatedamount">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>





<xsl:if test="fpml:payment">
<xsl:if test="fpml:payment[fpml:paymentType != 'Novation']">
<error><context><xsl:value-of select="$newContext"/></context><text>*** payment/paymentType must be equal to 'Novation'. Value = '<xsl:value-of select="payment/fpml:paymentType"/>'.</text></error>
</xsl:if>
<xsl:if test="($transferor != fpml:payment/fpml:payerPartyReference/@href) and ($transferor != fpml:payment/fpml:receiverPartyReference/@href)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** transferor/@href must equal payment/fpml:payerPartyReference/@href or payment/fpml:receiverPartyReference/@href.</text></error>
</xsl:if>
<xsl:if test="($remainingParty =fpml:payment/fpml:payerPartyReference/@href) or ($remainingParty = fpml:payment/fpml:receiverPartyReference/@href)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** payment/fpml:payerPartyReference/@href or payment/fpml:receiverPartyReference/@href must not be equal to remainingParty/@href.</text></error>
</xsl:if>
<xsl:if test="fpml:otherRemainingParty">
<xsl:if test="($otherRemainingParty = fpml:payment/fpml:payerPartyReference/@href) or ($otherRemainingParty = fpml:payment/fpml:receiverPartyReference/@href)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** payment/fpml:payerPartyReference/@href or payment/fpml:receiverPartyReference/@href must not be equal to fpml:otherRemainingParty/@href.</text></error>
</xsl:if>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:payment">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:SWDML">
<xsl:variable name="newContext">In <xsl:value-of select="local-name()"/></xsl:variable>

<results version="1.0">


<xsl:if test="not($version='4-2')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid version attribute. Value = '<xsl:value-of select="$version"/>'.</text></error>
</xsl:if>


<xsl:if test="not(fpml:swShortFormTrade or fpml:swLongFormTrade)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing swShortFormTrade or swLongFormTrade element. Required in this context.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:swShortFormTrade">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swLongFormTrade">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</results>
</xsl:template>


<xsl:template match="fpml:swShortFormTrade">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="not(fpml:swOriginatorPartyReference)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing swOriginatorPartyReference.</text></error>
</xsl:if>


<xsl:variable name="href"><xsl:value-of select="fpml:swOriginatorPartyReference/@href"/></xsl:variable>
<xsl:if test="not(.//fpml:party[@id=$href])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swOriginatorPartyReference/@href does not reference a valid .party/@id. Value = '<xsl:value-of select="$href"/>'.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:swSwaptionParameters">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swIrsParameters">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swOisParameters">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swFraParameters">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:swLongFormTrade">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:swGiveUp">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swAllocations">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:novation">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="not(fpml:swOriginatorPartyReference)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing swOriginatorPartyReference.</text></error>
</xsl:if>


<xsl:variable name="href"><xsl:value-of select="fpml:swOriginatorPartyReference/@href"/></xsl:variable>
<xsl:if test="not(//fpml:FpML/fpml:party[@id=$href])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swOriginatorPartyReference/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$href"/>'.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:swStructuredTradeDetails">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:swFraParameters">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">tradeDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:tradeDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:swEffectiveDateTenor">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swTerminationDateTenor">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:swTerminationDateTenor/fpml:periodMultiplier &lt;= fpml:swEffectiveDateTenor/fpml:periodMultiplier">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swTerminationDateTenor must be greater than swEffectiveDateTenor. swEffectiveDateTenor = '<xsl:value-of select="fpml:swEffectiveDateTenor/fpml:periodMultiplier"/><xsl:value-of select="fpml:swEffectiveDateTenor/fpml:period"/>' and fpml:swTerminationDateTenor = '<xsl:value-of select="fpml:swTerminationDateTenor/fpml:periodMultiplier"/><xsl:value-of select="fpml:swTerminationDateTenor/fpml:period"/>'.</text></error>
</xsl:if>


<xsl:if test="fpml:swTerminationDateTenor/fpml:periodMultiplier - fpml:swEffectiveDateTenor/fpml:periodMultiplier &gt; 12">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swTerminationDateTenor minus swEffectiveDateTenor must not be greater than 12 months. swEffectiveDateTenor = '<xsl:value-of select="fpml:swEffectiveDateTenor/fpml:periodMultiplier"/><xsl:value-of select="fpml:swEffectiveDateTenor/fpml:period"/>' and fpml:swTerminationDateTenor = '<xsl:value-of select="fpml:swTerminationDateTenor/fpml:periodMultiplier"/><xsl:value-of select="fpml:swTerminationDateTenor/fpml:period"/>'.</text></error>
</xsl:if>


<xsl:if test="rollConvention">
<xsl:call-template name="isValidRollConvention">
<xsl:with-param name="elementName">rollConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:rollConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:variable name="href1"><xsl:value-of select="fpml:buyerPartyReference/@href"/></xsl:variable>
<xsl:variable name="href2"><xsl:value-of select="fpml:sellerPartyReference/@href"/></xsl:variable>
<xsl:if test="$href1=$href2">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href and sellerPartyReference/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="not(fpml:party[@id=$href1])">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href does not reference a valid party/@id. Value = '<xsl:value-of select="$href1"/>'.</text></error>
</xsl:if>


<xsl:if test="not(fpml:party[@id=$href2])">
<error><context><xsl:value-of select="$newContext"/></context><text>***sellerPartyReference/@href does not reference a valid party/@id. Value = '<xsl:value-of select="$href2"/>'.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:notional">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>



<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">fixedRate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:fixedRate"/></xsl:with-param>
<xsl:with-param name="minIncl">0</xsl:with-param>
<xsl:with-param name="maxIncl">9.99999999</xsl:with-param>
<xsl:with-param name="maxDecs">8</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>




<xsl:if test="fpml:floatingRateIndex">
<xsl:variable name="floatingRateIndex"><xsl:value-of select="fpml:floatingRateIndex"/></xsl:variable>
<xsl:if test="$floatingRateIndex=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Empty floatingRateIndex.</text></error>
</xsl:if>
<xsl:if test="$tradeCurrency != 'PLN'">
<xsl:variable name="floatingRateIndexCurrency"><xsl:value-of select="substring($floatingRateIndex,1,3)"/></xsl:variable>
<xsl:if test="$tradeCurrency != $floatingRateIndexCurrency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** floatingRateIndex value of '<xsl:value-of select="$floatingRateIndex"/>' is not valid for trade currency of '<xsl:value-of select="$tradeCurrency"/>'.</text></error>
</xsl:if>
</xsl:if>
</xsl:if>


<xsl:if test="count(fpml:party)!=2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of party child elements encountered. Exactly 2 expected.</text></error>
</xsl:if>


<xsl:variable name="id1"><xsl:value-of select="fpml:party[1]/@id"/></xsl:variable>
<xsl:variable name="id2"><xsl:value-of select="fpml:party[2]/@id"/></xsl:variable>
<xsl:if test="$id1=$id2"><error><context><xsl:value-of select="$newContext"/></context><text>*** party[1]/@id and party[2]/@id values must not be the same.</text></error></xsl:if>

<xsl:apply-templates select="fpml:party">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:swOisParameters">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">tradeDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:tradeDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="swSwapTermTenor">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:adjustedEffectiveDate">
<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">adjustedEffectiveDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:adjustedEffectiveDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="fpml:swUnadjustedTerminationDate">
<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">swUnadjustedTerminationDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swUnadjustedTerminationDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="fpml:rollConvention">
<xsl:call-template name="isValidRollConvention">
<xsl:with-param name="elementName">rollConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:rollConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>

<xsl:apply-templates select="fpml:swFixedAmounts">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:notional">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">fixedRate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:fixedRate"/></xsl:with-param>
<xsl:with-param name="minIncl">0</xsl:with-param>
<xsl:with-param name="maxIncl">9.99999999</xsl:with-param>
<xsl:with-param name="maxDecs">8</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>



<xsl:if test="fpml:floatingRateIndex">
<xsl:variable name="floatingRateIndex"><xsl:value-of select="fpml:floatingRateIndex"/></xsl:variable>
<xsl:if test="$floatingRateIndex=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Empty or missing floatingRateIndex.</text></error>
</xsl:if>
<xsl:if test="$tradeCurrency != 'PLN'">
<xsl:variable name="floatingRateIndexCurrency"><xsl:value-of select="substring($floatingRateIndex,1,3)"/></xsl:variable>
<xsl:if test="$tradeCurrency != $floatingRateIndexCurrency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** floatingRateIndex value of '<xsl:value-of select="$floatingRateIndex"/>' is not valid for trade currency of '<xsl:value-of select="$tradeCurrency"/>'.</text></error>
</xsl:if>
</xsl:if>
</xsl:if>


<xsl:if test="count(fpml:party)!=2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of party child elements encountered. Exactly 2 expected.</text></error>
</xsl:if>


<xsl:variable name="id1"><xsl:value-of select="fpml:party[1]/@id"/></xsl:variable>
<xsl:variable name="id2"><xsl:value-of select="fpml:party[2]/@id"/></xsl:variable>
<xsl:if test="$id1=$id2"><error><context><xsl:value-of select="$newContext"/></context><text>*** party[1]/@id and party[2]/@id values must not be the same.</text></error></xsl:if>

<xsl:apply-templates select="fpml:party">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swSettlementProvision">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:swIrsParameters">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="fpml:swProductSubType">
<xsl:call-template name="isValidProductSubType">
<xsl:with-param name="elementName">swProductSubType</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swProductSubType"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="fpml:fixedRate and fpml:fixedAmount">
<error><context><xsl:value-of select="$newContext"/></context><text>*** fixedRate must not be present for Zero Coupon IRS with fixedAmount</text></error>
</xsl:if>


<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">tradeDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:tradeDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:swSwapTermTenor">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:adjustedEffectiveDate">
<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">adjustedEffectiveDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:adjustedEffectiveDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="fpml:swUnadjustedTerminationDate">
<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">swUnadjustedTerminationDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swUnadjustedTerminationDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="fpml:rollConvention">
<xsl:call-template name="isValidRollConvention">
<xsl:with-param name="elementName">rollConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:rollConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="fpml:swStubPosition">
<xsl:call-template name="isValidStubPosition">
<xsl:with-param name="elementName">swStubPosition</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swStubPosition"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="fpml:swStubPosition and fpml:rollConvention">
<xsl:variable name="rollConvention">
<xsl:value-of select="fpml:rollConvention"/>
</xsl:variable>
<xsl:if test="starts-with($rollConvention,'IMM') and not(//fpml:swStubPosition[.='Start'])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swStubPosition must equal 'Start' if rollConvention is equal to 'IMM'.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:swFixedAmounts">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swEarlyTerminationProvision">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:swAssociatedBonds">
<xsl:if test="not($tradeCurrency = 'USD' or $tradeCurrency = 'CAD')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swAssociatedBonds should only be present if trade currency is equal to 'USD' or 'CAD'. Value = '<xsl:value-of select="$tradeCurrency"/>'.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:swAssociatedBonds">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:notional">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:if test="fpml:fixedRate">

<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">fixedRate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:fixedRate"/></xsl:with-param>
<xsl:with-param name="minIncl">0</xsl:with-param>
<xsl:with-param name="maxIncl">9.99999999</xsl:with-param>
<xsl:with-param name="maxDecs">8</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>

<xsl:if test="fpml:fixedAmount">

<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">fixedRate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:fixedAmount"/></xsl:with-param>
<xsl:with-param name="minIncl">0.01</xsl:with-param>
<xsl:with-param name="maxIncl">999999999999.99</xsl:with-param>
<xsl:with-param name="maxDecs">2</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>




<xsl:if test="fpml:floatingRateIndex">
<xsl:variable name="floatingRateIndex"><xsl:value-of select="fpml:floatingRateIndex"/></xsl:variable>
<xsl:if test="$floatingRateIndex=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Empty or missing floatingRateIndex.</text></error>
</xsl:if>
<xsl:if test="$tradeCurrency != 'PLN'">
<xsl:variable name="floatingRateIndexCurrency"><xsl:value-of select="substring($floatingRateIndex,1,3)"/></xsl:variable>
<xsl:if test="$tradeCurrency != $floatingRateIndexCurrency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** floatingRateIndex value of '<xsl:value-of select="$floatingRateIndex"/>' is not valid for trade currency of '<xsl:value-of select="$tradeCurrency"/>'.</text></error>
</xsl:if>
</xsl:if>
</xsl:if>


<xsl:if test="fpml:initialRate">
<xsl:variable name="initialRate"><xsl:value-of select="fpml:initialRate"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">initialRate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$initialRate"/></xsl:with-param>
<xsl:with-param name="minIncl">-9.9999999</xsl:with-param>
<xsl:with-param name="maxIncl">9.9999999</xsl:with-param>
<xsl:with-param name="maxDecs">7</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>

<xsl:apply-templates select="fpml:additionalTerms">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="count(fpml:party)!=2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of party child elements encountered. Exactly 2 expected.</text></error>
</xsl:if>


<xsl:variable name="id1"><xsl:value-of select="fpml:party[1]/@id"/></xsl:variable>
<xsl:variable name="id2"><xsl:value-of select="fpml:party[2]/@id"/></xsl:variable>
<xsl:if test="$id1=$id2"><error><context><xsl:value-of select="$newContext"/></context><text>*** party[1]/@id and party[2]/@id values must not be the same.</text></error></xsl:if>

<xsl:apply-templates select="fpml:party">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swSettlementProvision">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>

<xsl:template match="fpml:swSwaptionParameters">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">tradeDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:tradeDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="href1"><xsl:value-of select="fpml:buyerPartyReference/@href"/></xsl:variable>
<xsl:variable name="href2"><xsl:value-of select="fpml:sellerPartyReference/@href"/></xsl:variable>
<xsl:if test="$href1=$href2">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href and fpml:sellerPartyReference/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:party[@id=$href1])">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href does not reference a valid party/@id. Value = '<xsl:value-of select="$href1"/>'.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:party[@id=$href2])">
<error><context><xsl:value-of select="$newContext"/></context><text>***sellerPartyReference/@href does not reference a valid party/@id. Value = '<xsl:value-of select="$href2"/>'.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:swPremium">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swEuropeanExercise">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:call-template name="isValidBoolean">
<xsl:with-param name="elementName">swaptionStraddle</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swaptionStraddle"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:call-template name="isValidBoolean">
<xsl:with-param name="elementName">swCashSettlement</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swCashSettlement"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:swSwapTermTenor">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:adjustedEffectiveDate">
<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">adjustedEffectiveDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:adjustedEffectiveDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="fpml:swUnadjustedTerminationDate">
<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">swUnadjustedTerminationDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swUnadjustedTerminationDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="fpml:rollConvention">
<xsl:call-template name="isValidRollConvention">
<xsl:with-param name="elementName">rollConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:rollConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="fpml:swStubPosition">
<xsl:call-template name="isValidStubPosition">
<xsl:with-param name="elementName">swStubPosition</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swStubPosition"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="fpml:swStubPosition and fpml:rollConvention">
<xsl:variable name="rollConvention">
<xsl:value-of select="fpml:rollConvention"/>
</xsl:variable>
<xsl:if test="starts-with($rollConvention,'IMM') and not(//fpml:swStubPosition[.='Start'])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swStubPosition must equal 'Start' if rollConvention is equal to 'IMM'.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:swFixedAmounts">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swEarlyTerminationProvision">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:notional">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">fixedRate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:fixedRate"/></xsl:with-param>
<xsl:with-param name="minIncl">0</xsl:with-param>
<xsl:with-param name="maxIncl">9.99999999</xsl:with-param>
<xsl:with-param name="maxDecs">8</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>



<xsl:if test="fpml:floatingRateIndex">
<xsl:variable name="floatingRateIndex"><xsl:value-of select="fpml:floatingRateIndex"/></xsl:variable>
<xsl:if test="$floatingRateIndex=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Empty or missing floatingRateIndex.</text></error>
</xsl:if>
<xsl:if test="$tradeCurrency != 'PLN'">
<xsl:variable name="floatingRateIndexCurrency"><xsl:value-of select="substring($floatingRateIndex,1,3)"/></xsl:variable>
<xsl:if test="$tradeCurrency != $floatingRateIndexCurrency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** floatingRateIndex value of '<xsl:value-of select="$floatingRateIndex"/>' is not valid for trade currency of '<xsl:value-of select="$tradeCurrency"/>'.</text></error>
</xsl:if>
</xsl:if>
</xsl:if>


<xsl:if test="count(fpml:party)!=2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of party child elements encountered. Exactly 2 expected.</text></error>
</xsl:if>


<xsl:variable name="id1"><xsl:value-of select="fpml:party[1]/@id"/></xsl:variable>
<xsl:variable name="id2"><xsl:value-of select="fpml:party[2]/@id"/></xsl:variable>
<xsl:if test="$id1=$id2"><error><context><xsl:value-of select="$newContext"/></context><text>*** party[1]/@id and party[2]/@id values must not be the same.</text></error></xsl:if>

<xsl:apply-templates select="fpml:party">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:swPremium">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidCurrency">
<xsl:with-param name="elementName">paymentAmount/currency</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:paymentAmount/fpml:currency"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="amount"><xsl:value-of select="fpml:paymentAmount/fpml:amount"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">paymentAmount/amount</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$amount"/></xsl:with-param>
<xsl:with-param name="minIncl">0.01</xsl:with-param>
<xsl:with-param name="maxIncl">999999999999.99</xsl:with-param>
<xsl:with-param name="maxDecs">2</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">swPaymentDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swPaymentDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


</xsl:template>

<xsl:template match="fpml:swEuropeanExercise">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>




<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">swExpirationDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swExpirationDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


</xsl:template>



<xsl:template match="fpml:swFixedAmounts">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="href1"><xsl:value-of select="fpml:payerPartyReference/@href"/></xsl:variable>
<xsl:variable name="href2"><xsl:value-of select="fpml:receiverPartyReference/@href"/></xsl:variable>
<xsl:if test="$href1=$href2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** payerPartyReference/@href and receiverPartyReference/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="not(../fpml:party[@id=$href1])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** payerPartyReference/@href does not reference a valid ..:/party/@id. Value = '<xsl:value-of select="$href1"/>'.</text></error>
</xsl:if>


<xsl:if test="not(../fpml:party[@id=$href2])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** receiverPartyReference/@href does not reference a valid ../party/@id. Value = '<xsl:value-of select="$href2"/>'.</text></error>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:swStructuredTradeDetails">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidProductType">
<xsl:with-param name="elementName">swProductType</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swProductType"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:FpML">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swExtendedTradeDetails">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:swExtendedTradeDetails">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:swTradeHeader">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:swStub">
<xsl:if test="not($productType ='IRS' or $productType ='OIS' or $productType='Swaption')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swStub should only be present if product type is 'SingleCurrencyInterestRateSwap' or 'OIS or 'Swaption'.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:swStub">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:swEarlyTerminationProvision">
<xsl:if test="not($productType ='IRS' or $productType='ZCInflationSwap' or $productType='Swaption')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swEarlyTerminationProvision should only be present if product type is 'SingleCurrencyInterestRateSwap' or 'Swaption'.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:swEarlyTerminationProvision">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:swAssociatedBonds">
<xsl:if test="not($productType ='IRS') or not($tradeCurrency = 'USD' or $tradeCurrency = 'CAD')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swAssociatedBonds should only be present if product type is 'SingleCurrencyInterestRateSwap' and trade currency is equal to 'USD' or 'CAD'.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:swAssociatedBonds">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>




<xsl:if test="count(fpml:additionalPayment) &gt; 8">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of additionalPayment child elements encountered. 0 to 8 expected.</text></error>
</xsl:if>


<xsl:if test="count(fpml:additionalPayment) = 7">
<xsl:if test="not(//fpml:additionalPayment[fpml:paymentType = 'Independent Amount'] or fpml:additionalPayment[fpml:paymentType = 'Cancellation'])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** If seven additionalPayment child elements are present then one must be identified as an Independent Amount (paymentType = 'Independent Amount') or Cancellation (paymentType = 'Cancellation').</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="count(fpml:additionalPayment) = 8">
<xsl:if test="not(//fpml:additionalPayment[fpml:paymentType = 'Independent Amount'] and fpml:additionalPayment[fpml:paymentType = 'Cancellation'])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** If eight additionalPayment child elements are present then one must be identified as an Independent Amount (paymentType = 'Independent Amount') and one a Cancellation (paymentType = 'Independent Amount').</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="count(fpml:additionalPayment[fpml:paymentType = 'Independent Amount']) &gt; 1">
<error><context><xsl:value-of select="$newContext"/></context><text>*** A maximum of one additionalPayment child element can be identified as an Independent Amount (paymentType = 'Independent Amount').</text></error>
</xsl:if>


<xsl:if test="count(fpml:additionalPayment[fpml:paymentType = 'Cancellation']) &gt; 1">
<error><context><xsl:value-of select="$newContext"/></context><text>*** A maximum of one additionalPayment child element can be identified as a Cancellation (paymentType = 'Cancellation').</text></error>
</xsl:if>


<xsl:if test="fpml:additionalPayment">
<xsl:if test="not($productType='FRA' or $productType='Swaption')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** additionalPayment is only allowed in this context if product type is 'FRA' or 'Swaption'.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:additionalPayment">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:swSettlementProvision">
<xsl:if test="not($productType='IRS' or $productType='OIS')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swSettlementProvision should only be present if product type is 'IRS' or 'OIS'. Value = '<xsl:value-of select="$productType"/>' .</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:swSettlementProvision">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


</xsl:template>


<xsl:template match="fpml:swTradeHeader">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidBoolean">
<xsl:with-param name="elementName">swManualConfirmationRequired</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swManualConfirmationRequired"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:call-template name="isValidMasterAgreementType">
<xsl:with-param name="elementName">swMasterAgreementType</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swMasterAgreementType"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="$productType='FRA' or $productType='OIS'">
<xsl:if test="not(//fpml:swClearingNotRequired[. = 'false'])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swClearingNotRequired must be equal to 'false' if product type is 'FRA' or 'OIS'. Value = '<xsl:value-of select="swClearingNotRequired"/>'.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="$productType='IRS' or $productType='Swaption'">
<xsl:call-template name="isValidBoolean">
<xsl:with-param name="elementName">swClearingNotRequired</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swClearingNotRequired"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="not(//fpml:swStandardSettlementInstructions[. = 'true'])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swStandardSettlementInstructions must be equal to 'true'. Value = '<xsl:value-of select="fpml:swStandardSettlementInstructions"/>'.</text></error>
</xsl:if>


<xsl:if test="fpml:swNormalised">
<xsl:call-template name="isValidBoolean">
<xsl:with-param name="elementName">swNormalised</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swNormalised"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="not($productType='IRS')">
<xsl:if test="fpml:swNormalised">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swNormalised must not be present if product type is not equal to 'SingleCurrencyInterestRateSwap'.</text></error>
</xsl:if>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:swStub">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidStubPosition">
<xsl:with-param name="elementName">swStubPosition</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swStubPosition"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:swStubPosition[.='Start']">
<xsl:if test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:stubCalculationPeriodAmount/fpml:finalStub">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swStubPosition value of 'Start' is inconsistent with presence of floating leg /stubCalculationPeriodAmount/finalStub element.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="fpml:swStubPosition[.='End']">
<xsl:if test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:stubCalculationPeriodAmount/fpml:initialStub">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swStubPosition value of 'End' is inconsistent with presence of floating leg //stubCalculationPeriodAmount/initialStub element.</text></error>
</xsl:if>
</xsl:if>

<xsl:for-each select="fpml:swStubLength">


<xsl:call-template name="isValidStubLength">
<xsl:with-param name="elementName">ANDREWswStubLength[<xsl:number value="position()"/>]</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="."/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="href"><xsl:value-of select="@href"/></xsl:variable>
<xsl:if test="not(//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[@id=$href])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swStubLength[<xsl:number value="position()"/>]/@href does not reference a valid /FpML/:trade/swap/swapStream/@id. Value = '<xsl:value-of select="$href"/>'.</text></error>
</xsl:if>

</xsl:for-each>

<xsl:if test="fpml:swStubLength[2]">


<xsl:if test="count(fpml:swStubLength)=2">
<xsl:variable name="href1"><xsl:value-of select="fpml:swStubLength[1]/@href"/></xsl:variable>
<xsl:variable name="href2"><xsl:value-of select="fpml:swStubLength[2]/@href"/></xsl:variable>
<xsl:if test="$href1=$href2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swStubLength[1]/@href and swStubLength[2]/@href values must not be the same.</text></error>
</xsl:if>
</xsl:if>

</xsl:if>

</xsl:template>


<xsl:template match="fpml:additionalPayment|fpml:payment">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>



<xsl:variable name="href1"><xsl:value-of select="fpml:payerPartyReference/@href"/></xsl:variable>
<xsl:variable name="href2"><xsl:value-of select="fpml:receiverPartyReference/@href"/></xsl:variable>
<xsl:if test="$href1=$href2"><error><context><xsl:value-of select="$newContext"/></context><text>*** payerPartyReference/@href and receiverPartyReference/@href values must not be the same.</text></error></xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$href1])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** payerPartyReference/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$href1"/>'.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$href2])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** receiverPartyReference/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$href2"/>'.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:paymentAmount">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:variable name="paymentTypeDesc">
<xsl:value-of select="fpml:paymentType"/>
</xsl:variable>


<xsl:if test="not(//fpml:paymentDate) and $paymentTypeDesc != 'Independent Amount'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing paymentDate. Required in this context unless paymentType equals 'Independent Amount'.</text></error>
</xsl:if>


<xsl:variable name="tradeDate"><xsl:value-of select="//fpml:FpML/fpml:trade//fpml:tradeHeader/fpml:tradeDate"/></xsl:variable>
<xsl:variable name="trdDate"><xsl:value-of select="number(concat(substring($tradeDate,1,4),substring($tradeDate,6,2),substring($tradeDate,9,2)))"/></xsl:variable>
<xsl:variable name="paymentDate"><xsl:value-of select="fpml:paymentDate/fpml:unadjustedDate"/></xsl:variable>
<xsl:variable name="payDate"><xsl:value-of select="number(concat(substring($paymentDate,1,4),substring($paymentDate,6,2),substring($paymentDate,9,2)))"/></xsl:variable>
<xsl:if test="$payDate &lt; $trdDate"><error><context><xsl:value-of select="$newContext"/></context><text>*** The payment date (paymentDate/fpml:unadjustedDate) must be greater than or equal to the tradeDate.  Value = '<xsl:value-of select="fpml:paymentDate/fpml:unadjustedDate"/>'.</text></error></xsl:if>

<xsl:apply-templates select="fpml:paymentDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>
</xsl:template>


<xsl:template match="fpml:paymentAmount|fpml:novatedamount">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidCurrency">
<xsl:with-param name="elementName">currency</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:currency"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="amount"><xsl:value-of select="fpml:amount"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">amount</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$amount"/></xsl:with-param>
<xsl:with-param name="minIncl">0.01</xsl:with-param>
<xsl:with-param name="maxIncl">999999999999.99</xsl:with-param>
<xsl:with-param name="maxDecs">2</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:template>


<xsl:template match="fpml:FpML">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:variable name="businessCenterSchemeDefault"><xsl:value-of select="@businessCenterSchemeDefault"/></xsl:variable>
<xsl:variable name="businessDayConventionSchemeDefault"><xsl:value-of select="@businessDayConventionSchemeDefault"/></xsl:variable>
<xsl:variable name="compoundingMethodSchemeDefault"><xsl:value-of select="@compoundingMethodSchemeDefault"/></xsl:variable>
<xsl:variable name="currencySchemeDefault"><xsl:value-of select="@currencySchemeDefault"/></xsl:variable>
<xsl:variable name="dateRelativeToSchemeDefault"><xsl:value-of select="@dateRelativeToSchemeDefault"/></xsl:variable>
<xsl:variable name="dayCountFractionSchemeDefault"><xsl:value-of select="@dayCountFractionSchemeDefault"/></xsl:variable>
<xsl:variable name="dayTypeSchemeDefault"><xsl:value-of select="@dayTypeSchemeDefault"/></xsl:variable>
<xsl:variable name="floatingRateIndexSchemeDefault"><xsl:value-of select="@floatingRateIndexSchemeDefault"/></xsl:variable>
<xsl:variable name="partyIdSchemeDefault"><xsl:value-of select="@partyIdSchemeDefault"/></xsl:variable>
<xsl:variable name="payerReceiverSchemeDefault"><xsl:value-of select="@payerReceiverSchemeDefault"/></xsl:variable>
<xsl:variable name="paymentTypeSchemeDefault"><xsl:value-of select="@paymentTypeSchemeDefault"/></xsl:variable>
<xsl:variable name="payRelativeToSchemeDefault"><xsl:value-of select="@payRelativeToSchemeDefault"/></xsl:variable>
<xsl:variable name="periodSchemeDefault"><xsl:value-of select="@periodSchemeDefault"/></xsl:variable>
<xsl:variable name="resetRelativeToSchemeDefault"><xsl:value-of select="@resetRelativeToSchemeDefault"/></xsl:variable>
<xsl:variable name="rollConventionSchemeDefault"><xsl:value-of select="@rollConventionSchemeDefault"/></xsl:variable>
<xsl:variable name="tradeIdSchemeDefault"><xsl:value-of select="@tradeIdSchemeDefault"/></xsl:variable>

<xsl:variable name="FpMLVersion">
<xsl:value-of select="@version"/>
</xsl:variable>


<xsl:if test="not($FpMLVersion='4-2')"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid version attribute. Value = '<xsl:value-of select="$FpMLVersion"/>'.</text></error></xsl:if>


<xsl:if test="count(fpml:party)&lt; 2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of party child elements encountered. At least 2 expected.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:party">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:apply-templates select="fpml:trade">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:trade">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>




<xsl:apply-templates select="fpml:tradeHeader">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:fra">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swap">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:swaption">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>



</xsl:template>


<xsl:template match="fpml:tradeHeader">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>





<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">tradeDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:tradeDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:partyTradeIdentifier">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:partyTradeIdentifier">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>



<xsl:variable name="href"><xsl:value-of select="fpml:partyReference/@href"/></xsl:variable>
<xsl:if test="not(//fpml:FpML/fpml:party[@id=$href])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** partyReference/@href does not reference a valid FpML/trade/party/@id. Value = '<xsl:value-of select="$href"/>'.</text></error>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:premium">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="href1"><xsl:value-of select="fpml:payerPartyReference/@href"/></xsl:variable>
<xsl:choose>
<xsl:when test="$href1='partyA'"/>
<xsl:when test="$href1='partyB'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid fpml:payerPartyReference/@href value. Value = '<xsl:value-of select="$href1"/>'.</text></error></xsl:otherwise>
</xsl:choose>


<xsl:variable name="href2"><xsl:value-of select="fpml:receiverPartyReference/@href"/></xsl:variable>
<xsl:choose>
<xsl:when test="$href2='partyA'"/>
<xsl:when test="$href2='partyB'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid receiverPartyReference/@href value. Value = '<xsl:value-of select="$href2"/>'.</text></error></xsl:otherwise>
</xsl:choose>


<xsl:if test="$href1=$href2"><error><context><xsl:value-of select="$newContext"/></context><text>*** payerPartyReference/@href and receiverPartyReference/@href values are the same.</text></error></xsl:if>




<xsl:variable name="amount"><xsl:value-of select="fpml:paymentAmount/fpml:amount"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">paymentAmount/amount</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$amount"/></xsl:with-param>
<xsl:with-param name="minIncl">0.01</xsl:with-param>
<xsl:with-param name="maxIncl">999999999999.99</xsl:with-param>
<xsl:with-param name="maxDecs">2</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:paymentDate/fpml:dateAdjustments[fpml:businessDayConvention!='FOLLOWING']">
<error><context><xsl:value-of select="$newContext"/></context><text>*** paymentDate/dateAdjustments/businessDayConvention must be equal to 'FOLLOWING'. Value = '<xsl:value-of select="fpml:paymentDate/fpml:dateAdjustments/fpml:businessDayConvention"/>'</text></error>
</xsl:if>


<xsl:variable name="tradeDate"><xsl:value-of select="fpml:SWDML/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:tradeHeader/fpml:tradeDate"/></xsl:variable>
<xsl:variable name="paymentDate"><xsl:value-of select="fpml:paymentDate/fpml:unadjustedDate"/></xsl:variable>
<xsl:variable name="trdDate"><xsl:value-of select="number(concat(substring($tradeDate,1,4),substring($tradeDate,6,2),substring($tradeDate,9,2)))"/></xsl:variable>
<xsl:variable name="payDate"><xsl:value-of select="number(concat(substring($paymentDate,1,4),substring($paymentDate,6,2),substring($paymentDate,9,2)))"/></xsl:variable>
<xsl:if test="$payDate &lt; $trdDate"><error><context><xsl:value-of select="$newContext"/></context><text>*** The premium payment date (paymentDate/fpml:unadjustedDate) must be greater than or equal to the tradeDate.  Value = '<xsl:value-of select="fpml:paymentDate/fpml:unadjustedDate"/>'.</text></error></xsl:if>

<xsl:apply-templates select="fpml:paymentDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:exerciseProcedure">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="not(fpml:automaticExercise) and not(fpml:manualExercise)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing automaticExercise or manualExercise element. Required in this context'.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:automaticExercise">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:manualExercise">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:followUpConfirmation">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:automaticExercise">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">thresholdRate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:thresholdRate"/></xsl:with-param>
<xsl:with-param name="minIncl">0</xsl:with-param>
<xsl:with-param name="maxIncl">9.9999999</xsl:with-param>
<xsl:with-param name="maxDecs">7</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:template>


<xsl:template match="fpml:manualExercise">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="not(fpml:fallbackExercise)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing fallbackExercise element. Required in this context'.</text></error>
</xsl:if>
<xsl:if test="fpml:fallbackExercise!='true'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** fallbackExercise element must have the value of 'true' in SwapsWire.</text></error>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:followUpConfirmation">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:call-template name="isValidBoolean">
<xsl:with-param name="elementName">followUpConfirmation</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="../fpml:followUpConfirmation"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:template>


<xsl:template match="fpml:swaption">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="buyerhref1">
<xsl:value-of select="fpml:buyerPartyReference/@href"/>
</xsl:variable>
<xsl:variable name="sellerhref2">
<xsl:value-of select="fpml:sellerPartyReference/@href"/>
</xsl:variable>
<xsl:if test="$buyerhref1=$sellerhref2">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href and sellerPartyReference/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$buyerhref1])">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href does not reference a valid /FpML/party/@id. Value = '<xsl:value-of select="$buyerhref1"/>'.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$sellerhref2])">
<error><context><xsl:value-of select="$newContext"/></context><text>***sellerPartyReference/@href does not reference a valid /FpML/party/@id. Value = '<xsl:value-of select="$sellerhref2"/>'.</text></error>
</xsl:if>




<xsl:if test="fpml:premium">
<xsl:variable name="payer"><xsl:value-of select="fpml:premium/fpml:payerPartyReference/@href"/></xsl:variable>
<xsl:variable name="receiver"><xsl:value-of select="fpml:premium/fpml:receiverPartyReference/@href"/></xsl:variable>
<xsl:if test="$buyerhref1!=$payer"><error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href (buyer) and premium/payerPartyReference/@href (premium payer) values are not the same.</text></error></xsl:if>
<xsl:if test="$sellerhref2!=$receiver"><error><context><xsl:value-of select="$newContext"/></context><text>***sellerPartyReference/@href (seller) and premium/receiverPartyReference/@href (premium receiver) values are not the same.</text></error></xsl:if>
</xsl:if>


<xsl:if test="count(fpml:premium) &gt; 1">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of premium child elements encountered. 0 or 1 expected.</text></error>
</xsl:if>


<xsl:apply-templates select="fpml:premium">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="not(fpml:europeanExercise)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing europeanExercise element. Required in this context'.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:europeanExercise">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:exerciseProcedure">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>




<xsl:if test="count(fpml:calculationAgentPartyReference) = 0 or count(fpml:calculationAgentPartyReference) &gt; 2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of calculationAgentPartyReference child elements encountered. 1 or 2 expected.</text></error>
</xsl:if>


<xsl:if test="count(fpml:calculationAgentPartyReference) = 2">
<xsl:variable name="calAgentParty1">
<xsl:value-of select="fpml:calculationAgentPartyReference[1]/@href"/>
</xsl:variable>
<xsl:if test="not($calAgentParty1=$buyerhref1)">
<xsl:if test="not($calAgentParty1=$sellerhref2)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** calculationAgentPartyReference[1]@href must reference a buyerPartyReference/@href or sellerPartyReference/@href. Value = '<xsl:value-of select="$calAgentParty1"/>'</text></error>
</xsl:if>
</xsl:if>
<xsl:variable name="calAgentParty2">
<xsl:value-of select="fpml:calculationAgentPartyReference[2]/@href"/>
</xsl:variable>
<xsl:if test="not($calAgentParty2=$buyerhref1)">
<xsl:if test="not($calAgentParty2=$sellerhref2)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** calculationAgentPartyReference[2]@href must reference a buyerPartyReference/@href or sellerPartyReference/@href. Value = '<xsl:value-of select="$calAgentParty2"/>'</text></error>
</xsl:if>
</xsl:if>
<xsl:if test="$calAgentParty1=$calAgentParty2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** calculationAgentPartyReference[1]/@href and calculationAgentPartyReference[2]/@href values must not be the same.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:calculationAgentPartyReference">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:cashSettlement">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:call-template name="isValidBoolean">
<xsl:with-param name="elementName">swaptionStraddle</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swaptionStraddle"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:swap">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:swap">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="not($productType='IRS' or $productType='OIS' or $productType='ZCInflationSwap' or $productType='Swaption')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** SWDML/swLongFormTrade/swStructuredTradeDetails/productType must be equal to 'SingleCurrencyInterestRateSwap' or 'OIS' or 'ZCInflationSwap' or 'Swaption' if swap element is present.</text></error>
</xsl:if>


<xsl:if test="count(fpml:swapStream)!=2"><error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of swapStream child elements encountered. Exactly 2 expected.</text></error></xsl:if>


<xsl:if test="$productType ='ZCInflationSwap'">
<xsl:if test="not(fpml:swapStream/fpml:calculationPeriodAmount/fpml:calculation/fpml:inflationRateCalculation)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream is missing /calculationPeriodAmount/calculation/InflationRateCalculation element.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="$productType ='ZCInflationSwap'">
<xsl:if test="not(fpml:swapStream/fpml:calculationPeriodAmount/fpml:calculation/fpml:inflationRateCalculation/fpml:inflationLag)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream is missing /calculationPeriodAmount/calculation/InflationRateCalculation/InflationLag element.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="$productType !='ZCInflationSwap'">
<xsl:if test="not(fpml:swapStream/fpml:calculationPeriodAmount/fpml:calculation/fpml:floatingRateCalculation)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream is missing calculationPeriodAmount/calculation/floatingRateCalculation element.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="($productType!='ZCInflationSwap')">
<xsl:if test="not(fpml:swapStream[@id='floatingLeg']/fpml:calculationPeriodAmount/fpml:calculation/fpml:floatingRateCalculation)"><error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream is missing calculationPeriodAmount/calculation/floatingRateCalculation element.</text></error>
</xsl:if>
</xsl:if>

<xsl:if test="($productType='ZCInflationSwap')">
<xsl:if test="(fpml:swapStream[@id='floatingLeg']/fpml:resetDates)"><error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream should not contain the resetDates element for 'ZCInflationSwap'.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="($productType='ZCInflationSwap')">
<xsl:if test="not(fpml:swapStream[@id='floatingLeg']/fpml:calculationPeriodAmount/fpml:calculation/fpml:inflationRateCalculation)"><error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream of an ZCInflationSwap is missing the calculationPeriodAmount/calculation/inflationRateCalculation element.</text></error></xsl:if>
</xsl:if>



<xsl:if test="fpml:swapStream[@id='fixedLeg']/fpml:resetDates">
<error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed swapStream should not contain a resetDates element.</text></error>
</xsl:if>



<xsl:if test="$productType='ZCInflationSwap'">
<xsl:if test="not(//fpml:swapStream[@id='fixedLeg']/fpml:cashflows)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed swapStream should  contain a cashflows element.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="$productType='ZCInflationSwap'">
<xsl:if test="not(//fpml:swapStream[@id='fixedLeg']/fpml:cashflows/fpml:paymentCalculationPeriod/fpml:unadjustedPaymentDate)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed swapStream should contain a cashflows/paymentCalculationPeriod/unadjustedPaymentDate element.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="$productType='ZCInflationSwap'">
<xsl:if test="not(//fpml:swapStream[@id='fixedLeg']/fpml:cashflows/fpml:paymentCalculationPeriod/fpml:fixedPaymentAmount)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed swapStream should contain a cashflows/paymentCalculationPeriod/fixedPaymentAmount element.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="fpml:swapStream[@id='fixedLeg']/fpml:cashflows/fpml:paymentCalculationPeriod/fpml:fixedPaymentAmount">
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">fixedpaymentAmount</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swapStream[@id='fixedLeg']/fpml:cashflows/fpml:paymentCalculationPeriod/fpml:fixedPaymentAmount"/></xsl:with-param>
<xsl:with-param name="minIncl">0.01</xsl:with-param>
<xsl:with-param name="maxIncl">999999999999.99</xsl:with-param>
<xsl:with-param name="maxDecs">2</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="$interestRateSwapType != 'zeroCouponInterestRateSwapWithFixedAmount'">
<xsl:if test="not(//fpml:swapStream[@id='fixedLeg']/fpml:calculationPeriodAmount/fpml:calculation/fpml:fixedRateSchedule)"><error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed swapStream is missing the calculationPeriodAmount/calculation/fixedRateSchedule element.</text></error></xsl:if>
</xsl:if>


<xsl:if test="$interestRateSwapType = 'zeroCouponInterestRateSwapWithFixedNotional'">
<xsl:if test="fpml:swapStream[@id='fixedLeg']/fpml:calculationPeriodAmount/fpml:knownAmountSchedule"><error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed swapStream is missing the knownAmountSchedule element.</text></error></xsl:if>
</xsl:if>


<xsl:if test="$interestRateSwapType = 'zeroCouponInterestRateSwapWithFixedAmount'">
<xsl:if test="fpml:swapStream[@id='fixedLeg']/fpml:calculationPeriodAmount/fpml:calculation"><error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed swapStream should not contain the calculationPeriodAmount/calculation element for the product 'SingleCurrencyInterestRateSwap' (and Zero Coupon IRS with fixed amount).</text></error></xsl:if>
</xsl:if>


<xsl:variable name="stream1Payer"><xsl:value-of select="fpml:swapStream[position()=1]/fpml:payerPartyReference/@href"/></xsl:variable>
<xsl:variable name="stream2Receiver"><xsl:value-of select="fpml:swapStream[position()=2]/fpml:receiverPartyReference/@href"/></xsl:variable>
<xsl:if test="$stream1Payer != $stream2Receiver"><error><context><xsl:value-of select="$newContext"/></context><text>*** swapStream[1] payer party is not swapStream[2] receiver party.</text></error></xsl:if>


<xsl:variable name="stream1Receiver"><xsl:value-of select="fpml:swapStream[position()=1]/fpml:receiverPartyReference/@href"/></xsl:variable>
<xsl:variable name="stream2Payer"><xsl:value-of select="fpml:swapStream[position()=2]/fpml:payerPartyReference/@href"/></xsl:variable>
<xsl:if test="$stream1Receiver != $stream2Payer"><error><context><xsl:value-of select="$newContext"/></context><text>*** swapStream[1] receiver party is not swapStream[2] payer party.</text></error></xsl:if>


<xsl:if test="not($productType='IRS' or $productType='Swaption')">
<xsl:variable name="effectiveDate1"><xsl:value-of select="fpml:swapStream[position()=1]/fpml:calculationPeriodDates/fpml:effectiveDate/fpml:unadjustedDate"/></xsl:variable>
<xsl:variable name="effectiveDate2"><xsl:value-of select="fpml:swapStream[position()=2]/fpml:calculationPeriodDates/fpml:effectiveDate/fpml:unadjustedDate"/></xsl:variable>
<xsl:if test="$effectiveDate1!= $effectiveDate2"><error><context><xsl:value-of select="$newContext"/></context><text>*** swapStream[1] and swapStream[2] effectiveDate do not match.</text></error></xsl:if>
</xsl:if>


<xsl:variable name="payBusDayConv1"><xsl:value-of select="fpml:swapStream[position()=1]/fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:variable name="payBusDayConv2"><xsl:value-of select="fpml:swapStream[position()=2]/fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="$productType = 'IRS' and $tradeCurrency = 'MXN'">
<xsl:if test="($payBusDayConv1 != 'FOLLOWING') or ($payBusDayConv2 != 'FOLLOWING')">
<error><context><xsl:value-of select="$newContext"/></context><text>***swapStream[1] and swapStream[2] paymentDates/paymentDatesAdjustments/businessDayConvention must equal 'FOLLOWING' if product type is 'SingleCurrencyInterestRateSwap' and trade currency is 'MXN'.</text></error>
</xsl:if>
</xsl:if>




<xsl:variable name="terminationDate1"><xsl:value-of select="fpml:swapStream[position()=1]/fpml:calculationPeriodDates/fpml:terminationDate/fpml:unadjustedDate"/></xsl:variable>
<xsl:variable name="terminationDate2"><xsl:value-of select="fpml:swapStream[position()=2]/fpml:calculationPeriodDates/fpml:terminationDate/fpml:unadjustedDate"/></xsl:variable>
<xsl:if test="$terminationDate1!= $terminationDate2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swapStream[1] and swapStream[2] terminationDate/unadjustedDate do not match.</text></error>
</xsl:if>


<xsl:variable name="rollConvention1"><xsl:value-of select="fpml:swapStream[position()=1]/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:rollConvention"/></xsl:variable>
<xsl:variable name="rollConvention2"><xsl:value-of select="fpml:swapStream[position()=2]/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:rollConvention"/></xsl:variable>
<xsl:if test="$isZeroCouponInterestRateSwap != 'true'">
<xsl:if test="$rollConvention1 != $rollConvention2"><error><context><xsl:value-of select="$newContext"/></context><text>*** swapStream[1] and swapStream[2] rollConvention do not match.</text></error></xsl:if></xsl:if>


<xsl:variable name="notional1"><xsl:value-of select="fpml:swapStream[position()=1]/fpml:calculationPeriodAmount/fpml:calculation/fpml:notionalSchedule/fpml:notionalStepSchedule/fpml:initialValue"/></xsl:variable>
<xsl:variable name="notional2"><xsl:value-of select="fpml:swapStream[position()=2]/fpml:calculationPeriodAmount/fpml:calculation/fpml:notionalSchedule/fpml:notionalStepSchedule/fpml:initialValue"/></xsl:variable>
<xsl:if test="($interestRateSwapType != 'zeroCouponInterestRateSwapWithFixedAmount')">
<xsl:if test="$notional1!= $notional2"><error><context><xsl:value-of select="$newContext"/></context><text>*** swapStream[1] and swapStream[2] notional do not match.</text></error></xsl:if></xsl:if>


<xsl:variable name="notional"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodAmount/fpml:calculation/fpml:notionalSchedule/fpml:notionalStepSchedule/fpml:initialValue"/></xsl:variable>
<xsl:variable name="fixedAmount"><xsl:value-of select="fpml:swapStream[position()=$fixedLeg]/fpml:calculationPeriodAmount/fpml:knownAmountSchedule/fpml:initialValue"/></xsl:variable>
<xsl:if test="($interestRateSwapType = 'zeroCouponInterestRateSwapWithFixedAmount')">
<xsl:if test="$notional= $fixedAmount"><error><context><xsl:value-of select="$newContext"/></context><text>*** fixedLeg fixed amount and floatingLeg notional match.</text></error></xsl:if></xsl:if>


<xsl:variable name="currency1"><xsl:value-of select="fpml:swapStream[position()=1]/fpml:calculationPeriodAmount/fpml:calculation/fpml:notionalSchedule/fpml:notionalStepSchedule/fpml:currency"/></xsl:variable>
<xsl:variable name="currency2"><xsl:value-of select="fpml:swapStream[position()=2]/fpml:calculationPeriodAmount/fpml:calculation/fpml:notionalSchedule/fpml:notionalStepSchedule/fpml:currency"/></xsl:variable>
<xsl:if test="($interestRateSwapType != 'zeroCouponInterestRateSwapWithFixedAmount')">
<xsl:if test="$currency1!= $currency2"><error><context><xsl:value-of select="$newContext"/></context><text>*** swapStream[1] and swapStream[2] currency do not match.</text></error></xsl:if></xsl:if>


<xsl:variable name="floatingLegCurrency"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodAmount/fpml:calculation/fpml:notionalSchedule/fpml:notionalStepSchedule/fpml:currency"/></xsl:variable>
<xsl:variable name="fixedLegCurrency"><xsl:value-of select="fpml:swapStream[position()=$fixedLeg]/fpml:calculationPeriodAmount/fpml:knownAmountSchedule/fpml:currency"/></xsl:variable>
<xsl:if test="$interestRateSwapType = 'zeroCouponInterestRateSwapWithFixedAmount'">
<xsl:if test="$floatingLegCurrency!= $fixedLegCurrency"><error><context><xsl:value-of select="$newContext"/></context><text>*** swapStream[1] and swapStream[2] currency do not match.</text></error></xsl:if></xsl:if>


<xsl:variable name="paymentLag1"><xsl:value-of select="fpml:swapStream[position()=1]/fpml:paymentDates/fpml:paymentDaysOffset/fpml:periodMultiplier"/></xsl:variable>
<xsl:variable name="paymentLag2"><xsl:value-of select="fpml:swapStream[position()=2]/fpml:paymentDates/fpml:paymentDaysOffset/fpml:periodMultiplier"/></xsl:variable>
<xsl:if test="$paymentLag1!= $paymentLag2"><error><context><xsl:value-of select="$newContext"/></context><text>*** swapStream[1] and swapStream[2] paymentDaysOffset do not match.</text></error></xsl:if>


<xsl:variable name="busCenters5">
<xsl:for-each select="fpml:swapStream[position()=1]/fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:variable name="busCenters6">
<xsl:for-each select="fpml:swapStream[position()=2]/fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:if test="$busCenters5!= $busCenters6"><error><context><xsl:value-of select="$newContext"/></context><text>*** swapStream[1] and swapStream[2] paymentDates/paymentDatesAdjustments/businessCenters do not match.</text></error></xsl:if>


<xsl:variable name="fixedLegAdjustment"  >
<xsl:value-of select="fpml:swapStream[@id='fixedLeg']/fpml:calculationPeriodDates/fpml:calculationPeriodDatesAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="$isZeroCouponInterestRateSwap = 'true' and $fixedLegAdjustment != 'NONE'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** fixedLeg calculationPeriodDates/calculationPeriodDatesAdjustments/businessDayConvention for a ZC IRS must be set to 'NONE'.  Value = <xsl:value-of select="$fixedLegAdjustment"/></text></error></xsl:if>

<xsl:variable name="periodMultiplier1"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:periodMultiplier"/></xsl:variable>
<xsl:variable name="periodMultiplier2"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:resetDates[@id='resetDates']/fpml:resetFrequency/fpml:periodMultiplier"/></xsl:variable>
<xsl:variable name="periodMultiplier3"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodAmount/fpml:calculation/fpml:floatingRateCalculation/fpml:indexTenor/fpml:periodMultiplier"/></xsl:variable>
<xsl:variable name="periodMultiplier6"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:paymentDates/fpml:paymentFrequency/fpml:periodMultiplier"/></xsl:variable>

<xsl:variable name="periodMultiplier4"><xsl:value-of select="fpml:swapStream[position()=$fixedLeg]/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:periodMultiplier"/></xsl:variable>
<xsl:variable name="periodMultiplier5"><xsl:value-of select="fpml:swapStream[position()=$fixedLeg]/fpml:paymentDates/fpml:paymentFrequency/fpml:periodMultiplier"/></xsl:variable>

<xsl:variable name="period1"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:period"/></xsl:variable>
<xsl:variable name="period2"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:resetDates[@id='resetDates']/fpml:resetFrequency/fpml:period"/></xsl:variable>
<xsl:variable name="period3"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodAmount/fpml:calculation/fpml:floatingRateCalculation/fpml:indexTenor/fpml:period"/></xsl:variable>
<xsl:variable name="period6"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:paymentDates/fpml:paymentFrequency/fpml:period"/></xsl:variable>

<xsl:variable name="period4"><xsl:value-of select="fpml:swapStream[position()=$fixedLeg]/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:period"/></xsl:variable>
<xsl:variable name="period5"><xsl:value-of select="fpml:swapStream[position()=$fixedLeg]/fpml:paymentDates/fpml:paymentFrequency/fpml:period"/></xsl:variable>



<xsl:if test="$productType='IRS' or $productType='Swaption'">
<xsl:if test="not(($periodMultiplier1 = $periodMultiplier2) and ($periodMultiplier1 = $periodMultiplier3))"><error><context><xsl:value-of select="$newContext"/></context><text>*** The floating fpml:swapStream calculationPeriodFrequency, resetFrequency and indexTenor do not match.</text></error></xsl:if>
<xsl:if test="not(($period1 = $period2) and ($period1 = $period3))"><error><context><xsl:value-of select="$newContext"/></context><text>*** The floating stream calculationPeriodFrequency, resetFrequency and indexTenor do not match. <xsl:value-of select="$period1"/>%%<xsl:value-of select="$period2"/>**<xsl:value-of select="$period3"/> </text></error></xsl:if>
</xsl:if>


<xsl:if test="$productType='OIS'">
<xsl:if test="not($periodMultiplier1 = $periodMultiplier2) or not($period1 = $period2)"><error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream calculationPeriodFrequency and resetFrequency do not match. They must match if product type is 'OIS'</text></error></xsl:if>
</xsl:if>


<xsl:if test="$productType='OIS'">
<xsl:if test="not($periodMultiplier6 = $periodMultiplier5)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** fpml:swapStream[1] and fpml:swapStream[2] paymentFrequency do not match. They must match if product type is 'OIS'.</text></error>
</xsl:if>
<xsl:if test="not($period6 = $period5)"><error><context><xsl:value-of select="$newContext"/></context><text>***  swapStream[1] and swapStream[2] paymentFrequency do not match. They must match if product type is 'OIS'.</text></error></xsl:if>
</xsl:if>



<xsl:if test="not($productType='ZCInflationSwap')">
<xsl:if test="not($periodMultiplier4 = $periodMultiplier5)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed swapStream calculationPeriodFrequency/periodMultiplier and paymentFrequency/periodMultiplier do not match.</text></error></xsl:if>
</xsl:if>
<xsl:if test="not($period4 = $period5)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed swapStream calculationPeriodFrequency/period and paymentFrequency/period do not match.</text></error>
</xsl:if>



<xsl:variable name="businessDayConvention1"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodDates[@id='floatingCalcPeriodDates']/fpml:calculationPeriodDatesAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:variable name="businessDayConvention2"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:variable name="businessDayConvention3"><xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:resetDates/fpml:resetDatesAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="($productType!='ZCInflationSwap')">
<xsl:if test="not(($businessDayConvention1 = $businessDayConvention2) and ($businessDayConvention1 = $businessDayConvention3))"><error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream calculationPeriodDatesAdjustments/businessDayConvention, paymentDatesAdjustments/businessDayConvention and resetDatesAdjustments/businessDayConvention do not match.<xsl:value-of select="$businessDayConvention1"/>*<xsl:value-of select="$businessDayConvention2"/>%<xsl:value-of select="$businessDayConvention3"/></text></error></xsl:if>
</xsl:if>




<xsl:variable name="floatCalcPayFreqCombo">
<xsl:value-of select="fpml:swapStream[@id='floatingLeg']/fpml:calculationPeriodDates[@id='floatingCalcPeriodDates']/fpml:calculationPeriodFrequency/fpml:periodMultiplier"/>
<xsl:value-of select="fpml:swapStream[@id='floatingLeg']/fpml:calculationPeriodDates[@id='floatingCalcPeriodDates']/fpml:calculationPeriodFrequency/fpml:period"/>
<xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:paymentDates/fpml:paymentFrequency/fpml:periodMultiplier"/>
<xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:paymentDates/fpml:paymentFrequency/fpml:period"/>
</xsl:variable>


<xsl:if test="$productType='IRS' or $productType='Swaption'">
<xsl:choose>
<xsl:when test="$floatCalcPayFreqCombo='28D28D'"/>
<xsl:when test="$floatCalcPayFreqCombo='1M1M'"/>
<xsl:when test="$floatCalcPayFreqCombo='1M3M'"/>
<xsl:when test="$floatCalcPayFreqCombo='1M6M'"/>
<xsl:when test="$floatCalcPayFreqCombo='1M1Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='3M3M'"/>
<xsl:when test="$floatCalcPayFreqCombo='3M6M'"/>
<xsl:when test="$floatCalcPayFreqCombo='3M1Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='6M6M'"/>
<xsl:when test="$floatCalcPayFreqCombo='6M1Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='1Y1Y'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream calculationPeriodDates/calculationPeriodFrequency and paymentDates/paymentFrequency combination is invalid for a product type of 'SingleCurrencyInterestRateSwap'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>


<xsl:if test="$productType='ZCInflationSwap'">
<xsl:choose>
<xsl:when test="$floatCalcPayFreqCombo='1Y1Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='2Y2Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='3Y3Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='4Y4Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='5Y5Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='6Y6Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='7Y7Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='8Y8Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='9Y9Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='10Y10Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='11Y11Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='12Y12Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='13Y13Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='14Y14Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='15Y15Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='16Y16Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='17Y17Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='18Y18Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='19Y19Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='20Y20Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='25Y25Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='30Y30Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='35Y35Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='40Y40Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='45Y45Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='50Y50Y'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream calculationPeriodDates/calculationPeriodFrequency and paymentDates/paymentFrequency combination is invalid for a product type of 'ZCInflationSwap'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>



<xsl:if test="$productType='OIS'">
<xsl:choose>
<xsl:when test="$floatCalcPayFreqCombo='6M6M'"/>
<xsl:when test="$floatCalcPayFreqCombo='1Y1Y'"/>
<xsl:when test="$floatCalcPayFreqCombo='1T1T'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream calculationPeriodDates/calculationPeriodFrequency and paymentDates/paymentFrequency combination is invalid for a product type of 'OIS'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

<xsl:variable name="floatCalcFreq">
<xsl:value-of select="fpml:swapStream[@id='floatingLeg']/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:periodMultiplier"/>
<xsl:value-of select="fpml:swapStream[@id='floatingLeg']/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:period"/>
</xsl:variable>


<xsl:if test="$productType='IRS' or $productType='Swaption'">
<xsl:choose>
<xsl:when test="$floatCalcFreq='28D'"/>
<xsl:when test="$floatCalcFreq='1M'"/>
<xsl:when test="$floatCalcFreq='3M'"/>
<xsl:when test="$floatCalcFreq='6M'"/>
<xsl:when test="$floatCalcFreq='1Y'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream calculationPeriodFrequency must be equal to 28D, 1M, 3M, 6M or 1Y if product type is 'SingleCurrencyInterestRateSwap' or 'Swaption'. Value = '<xsl:value-of select="$floatCalcFreq"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

<xsl:variable name="fixedCalcFreq">
<xsl:value-of select="fpml:swapStream[@id='fixedLeg']/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:periodMultiplier"/>
<xsl:value-of select="fpml:swapStream[@id='fixedLeg']/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:period"/>
</xsl:variable>

<xsl:choose>
<xsl:when test="$isZeroCouponInterestRateSwap != 'true'">
<xsl:if test="$productType='IRS' or $productType='Swaption'">
<xsl:choose>
<xsl:when test="$fixedCalcFreq='28D'"/>
<xsl:when test="$fixedCalcFreq='1M'"/>
<xsl:when test="$fixedCalcFreq='3M'"/>
<xsl:when test="$fixedCalcFreq='6M'"/>
<xsl:when test="$fixedCalcFreq='1Y'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed fpml:swapStream calculationPeriodFrequency must be equal to 28D, 1M, 3M, 6M or 1Y if product type is 'SingleCurrencyInterestRateSwap' (except Zero Coupon IRS) or 'Swaption'. Value = '<xsl:value-of select="$fixedCalcFreq"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>
</xsl:when>
<xsl:when test="$isZeroCouponInterestRateSwap = 'true'">
<xsl:if test="$productType='IRS'">
<xsl:choose>
<xsl:when test="$fixedCalcFreq='1T'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed fpml:swapStream calculationPeriodFrequency must be equal to 1T if product type is 'SingleCurrencyInterestRateSwap' and a Zero Coupon IRS. Value = '<xsl:value-of select="$fixedCalcFreq"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>
</xsl:when>
</xsl:choose>

<xsl:variable name="floatPayFreq">
<xsl:value-of select="fpml:swapStream[@id='floatingLeg']/fpml:paymentDates/fpml:paymentFrequency/fpml:periodMultiplier"/>
<xsl:value-of select="fpml:swapStream[@id='floatingLeg']/fpml:paymentDates/fpml:paymentFrequency/fpml:period"/>
</xsl:variable>

<xsl:if test="$productType='IRS' or $productType='Swaption'">
<xsl:choose>
<xsl:when test="$floatPayFreq='28D'"/>
<xsl:when test="$floatPayFreq='1M'"/>
<xsl:when test="$floatPayFreq='3M'"/>
<xsl:when test="$floatPayFreq='6M'"/>
<xsl:when test="$floatPayFreq='1Y'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** The floating swapStream paymentFrequency must be equal to 28D, 1M, 3M, 6M or 1Y if product type is 'SingleCurrencyInterestRateSwap' or 'Swaption'. Value = '<xsl:value-of select="$floatPayFreq"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

<xsl:variable name="fixedPayFreq">
<xsl:value-of select="fpml:swapStream[@id='fixedLeg']/fpml:paymentDates/fpml:paymentFrequency/fpml:periodMultiplier"/>
<xsl:value-of select="fpml:swapStream[@id='fixedLeg']/fpml:paymentDates/fpml:paymentFrequency/fpml:period"/>
</xsl:variable>

<xsl:choose>
<xsl:when test="$isZeroCouponInterestRateSwap != 'true'">
<xsl:if test="$productType='IRS' or $productType='Swaption'">
<xsl:choose>
<xsl:when test="$fixedPayFreq='28D'"/>
<xsl:when test="$fixedPayFreq='1M'"/>
<xsl:when test="$fixedPayFreq='3M'"/>
<xsl:when test="$fixedPayFreq='6M'"/>
<xsl:when test="$fixedPayFreq='1Y'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed swapstream paymentFrequency must be equal to 28D, 1M, 3M, 6M or 1Y if product type is 'SingleCurrencyInterestRateSwap' (except Zero Coupon IRS) or 'Swaption'. Value = '<xsl:value-of select="$fixedPayFreq"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>
</xsl:when>
<xsl:when test="$isZeroCouponInterestRateSwap = 'true'">
<xsl:if test="$productType='IRS'">
<xsl:choose>
<xsl:when test="$fixedPayFreq='1T'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** The fixed swapStream paymentFrequency must be equal to 1T if product type is 'SingleCurrencyInterestRateSwap' and a Zero Coupon IRS. Value = '<xsl:value-of select="$fixedPayFreq"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>
</xsl:when>
</xsl:choose>




<xsl:variable name="rollConvention">
<xsl:value-of select="fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:rollConvention"/>
</xsl:variable>
<xsl:if test="starts-with($rollConvention,'IMM')">
<xsl:if test="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swStub/fpml:swStubPosition and not(//fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swStub/fpml:swStubPosition[.='Start'])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** SWDML/swLongFormTrade/swStructuredTradeDetails/swExtendedTradeDetails/swStub/swStubPosition must be equal to 'Start' for IMM rolls.</text></error>
</xsl:if>
<xsl:if test="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swStub/fpml:swStubLength and not(//fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swStub/fpml:swStubLength[.='Short'])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** SWDML/swLongFormTrade/swStructuredTradeDetails/swExtendedTradeDetails/swStub/swStubLength must be equal to 'Short' for IMM rolls.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:swapStream">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:earlyTerminationProvision">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="count(fpml:additionalPayment) &gt; 8">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of additionalPayment child elements encountered. 0 to 8 expected.</text></error>
</xsl:if>


<xsl:if test="count(fpml:additionalPayment) = 7">
<xsl:if test="not(//fpml:additionalPayment[fpml:paymentType = 'Independent Amount'] or fpml:additionalPayment[fpml:paymentType = 'Cancellation'])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** If seven additionalPayment child elements are present then one must be identified as an Independent Amount (paymentType = 'Independent Amount') or Cancellation (paymentType = 'Cancellation').</text></error>
</xsl:if>
</xsl:if>



<xsl:if test="count(fpml:additionalPayment) = 8">
<xsl:if test="not(//fpml:additionalPayment[fpml:paymentType = 'Independent Amount'] and fpml:additionalPayment[fpml:paymentType = 'Cancellation'])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** If eight additionalPayment child elements are present then one must be identified as an Independent Amount (paymentType = 'Independent Amount') and one a Cancellation (paymentType = 'Independent Amount').</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="count(fpml:additionalPayment[fpml:paymentType = 'Independent Amount']) &gt; 1">
<error><context><xsl:value-of select="$newContext"/></context><text>*** A maximum of one additionalPayment child element can be identified as an Independent Amount (paymentType = 'Independent Amount').</text></error>
</xsl:if>


<xsl:if test="count(fpml:additionalPayment[fpml:paymentType = 'Cancellation']) &gt; 1">
<error><context><xsl:value-of select="$newContext"/></context><text>*** A maximum of one additionalPayment child element can be identified as a Cancellation (paymentType = 'Cancellation').</text></error>
</xsl:if>


<xsl:if test="fpml:additionalPayment">
<xsl:if test="not($productType='IRS' or $productType='OIS' or $productType='Swaption' or $productType='OIS' or $productType='ZCInflationSwap')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** additionalPayment is only allowed in this context if product type is 'SingleCurrencyInterestRateSwap' or 'OIS' or 'Swaption' or 'ZCInflationSwap'.</text></error>
</xsl:if>
</xsl:if>






<xsl:apply-templates select="fpml:additionalPayment">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:additionalTerms">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>

<xsl:template match="fpml:additionalTerms">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>


<xsl:variable name="instrumentId"><xsl:value-of select="fpml:bondReference/fpml:bond/fpml:instrumentId"/></xsl:variable>

<xsl:if test="$productType='ZCInflationSwap'">
<xsl:if test="string-length($instrumentId) &gt; 12">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Invalid instrumentId string length. Exceeded max length of 12 characters for productType 'ZCInflationSwap'.</text></error>
</xsl:if>
</xsl:if>

<xsl:if test="$productType='IRS'">
<xsl:variable name="conditionPrecedentBondId"><xsl:value-of select="fpml:conditionPrecedentBond/fpml:instrumentId"/></xsl:variable>
<xsl:variable name="conditionPrecedentBondMaturity"><xsl:value-of select="fpml:conditionPrecedentBond/fpml:maturity"/></xsl:variable>

<xsl:if test="$participantSupplement='Fannie Mae' and (($conditionPrecedentBondId!='' and $conditionPrecedentBondMaturity='') or ($conditionPrecedentBondMaturity!='' and $conditionPrecedentBondId=''))">
<error><context><xsl:value-of select="$newContext"/></context>
<text>*** For a swParticipantSupplement value of Fannie Mae if either conditionPrecedentBond/instrumentId or conditionPrecedentBond/maturity have a value they both must have.</text>
</error>
</xsl:if>
</xsl:if>


<xsl:variable name="conditionPrecedentBond"> <xsl:value-of select="fpml:bondReference/fpml:conditionPrecedentBond"/></xsl:variable>

<xsl:if test="$productType='ZCInflationSwap'">
<xsl:if test="$conditionPrecedentBond != 'false'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** conditionPrecedentBond must be present and equal to 'false'. Value = '<xsl:value-of select="$conditionPrecedentBond"/>'.</text></error>
</xsl:if>
</xsl:if>

</xsl:template>

<xsl:template match="fpml:swapStream">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>



<xsl:variable name="href1"><xsl:value-of select="fpml:payerPartyReference/@href"/></xsl:variable>
<xsl:variable name="href2"><xsl:value-of select="fpml:receiverPartyReference/@href"/></xsl:variable>
<xsl:if test="$href1=$href2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** payerPartyReference/@href and receiverPartyReference/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$href1])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** payerPartyReference/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$href1"/>'.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$href2])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** receiverPartyReference/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$href2"/>'.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:calculationPeriodDates">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:paymentDates">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:resetDates">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:calculationPeriodAmount">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:stubCalculationPeriodAmount">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:calculationPeriodDates">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="id"><xsl:value-of select="./@id"/></xsl:variable>
<xsl:if test="$id = ''"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or empty calculationPeriodDates/@id value.</text></error></xsl:if>


<xsl:variable name="effectiveDate"><xsl:value-of select="fpml:effectiveDate/fpml:unadjustedDate"/></xsl:variable>
<xsl:variable name="terminationDate"><xsl:value-of select="fpml:terminationDate/fpml:unadjustedDate"/></xsl:variable>
<xsl:variable name="effDate"><xsl:value-of select="number(concat(substring($effectiveDate,1,4),substring($effectiveDate,6,2),substring($effectiveDate,9,2)))"/></xsl:variable>
<xsl:variable name="termDate"><xsl:value-of select="number(concat(substring($terminationDate,1,4),substring($terminationDate,6,2),substring($terminationDate,9,2)))"/></xsl:variable>
<xsl:if test="$effDate &gt;= $termDate"><error><context><xsl:value-of select="$newContext"/></context><text>*** The terminationDate must be greater than the effectiveDate.</text></error></xsl:if>

<xsl:apply-templates select="fpml:effectiveDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:terminationDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:calculationPeriodDatesAdjustments">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:if test="fpml:firstRegularPeriodStartDate">
<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">firstRegularPeriodStartDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:firstRegularPeriodStartDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>

<xsl:if test="fpml:lastRegularPeriodEndDate">
<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">lastRegularPeriodEndDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:lastRegularPeriodEndDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>

<xsl:apply-templates select="fpml:calculationPeriodFrequency">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:effectiveDate">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="//fpml:swap">
<xsl:variable name="businessDayConvention1"><xsl:value-of select="fpml:dateAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="$businessDayConvention1!='NONE'">
<xsl:variable name="businessDayConvention2">
<xsl:value-of select="../../fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessDayConvention"/>
</xsl:variable>
<xsl:if test="$businessDayConvention1!=$businessDayConvention2">
<error><context><xsl:value-of select="$newContext"/></context><text>***  If not equal to 'NONE' dateAdjustments/businessDayConvention must equal ../../paymentDates/paymentDatesAdjustments/businessDayConvention.</text></error>
</xsl:if>
</xsl:if>
</xsl:if>


<xsl:if test="//fpml:swap">
<xsl:variable name="businessDayConvention1"><xsl:value-of select="fpml:dateAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="$businessDayConvention1!='NONE'">
<xsl:variable name="busCenters1">
<xsl:for-each select="fpml:dateAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:variable name="busCenters2">
<xsl:for-each select="//fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodDates/fpml:calculationPeriodDatesAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:if test="$busCenters1!= $busCenters2"><error><context><xsl:value-of select="$newContext"/></context><text>*** If dateAdjustments/businessDayConvention is not equal to 'NONE' /dateAdjustments/businessCenters must equal floating leg calculationPeriodDates/calculationPeriodDatesAdjustments/businessCenters.</text></error></xsl:if>
</xsl:if>
</xsl:if>


<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">unadjustedDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:unadjustedDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:dateAdjustments">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:terminationDate">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="//fpml:swap">
<xsl:variable name="businessDayConvention1"><xsl:value-of select="fpml:dateAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="$businessDayConvention1!='NONE'">
<xsl:variable name="businessDayConvention2">
<xsl:value-of select="../../fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessDayConvention"/>
</xsl:variable>
<xsl:if test="$businessDayConvention1!=$businessDayConvention2">
<error><context><xsl:value-of select="$newContext"/></context><text>***  If not equal to 'NONE' dateAdjustments/businessDayConvention must equal ../../paymentDates/paymentDatesAdjustments/businessDayConvention.</text></error>
</xsl:if>
</xsl:if>
</xsl:if>


<xsl:if test="//fpml:swap">
<xsl:variable name="businessDayConvention1"><xsl:value-of select="fpml:dateAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="$businessDayConvention1!='NONE'">
<xsl:variable name="busCenters1">
<xsl:for-each select="fpml:dateAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:variable name="busCenters2">
<xsl:for-each select="//fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodDates/fpml:calculationPeriodDatesAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:if test="$busCenters1!= $busCenters2"><error><context><xsl:value-of select="$newContext"/></context><text>*** If dateAdjustments/businessDayConvention is not equal to 'NONE' /dateAdjustments/businessCenters must equal floating leg calculationPeriodDates/calculationPeriodDatesAdjustments/businessCenters.</text></error></xsl:if>
</xsl:if>
</xsl:if>


<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">unadjustedDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:unadjustedDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:dateAdjustments">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:calculationPeriodDatesAdjustments">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="fpml:swap">
<xsl:variable name="businessDayConvention1"><xsl:value-of select="fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="$businessDayConvention1!='NONE'">
<xsl:variable name="businessDayConvention2">
<xsl:value-of select="../../fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessDayConvention"/>
</xsl:variable>
<xsl:if test="$businessDayConvention1!=$businessDayConvention2">
<error><context><xsl:value-of select="$newContext"/></context><text>***  If not equal to 'NONE' businessDayConvention must equal ../../paymentDates/paymentDatesAdjustments/businessDayConvention.</text></error>
</xsl:if>
</xsl:if>
</xsl:if>


<xsl:if test="fpml:swap">
<xsl:variable name="businessDayConvention1"><xsl:value-of select="fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="$businessDayConvention1!='NONE'">
<xsl:variable name="busCenters1">
<xsl:for-each select="fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:variable name="busCenters2">
<xsl:for-each select="fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodDates/fpml:calculationPeriodDatesAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:if test="$busCenters1!= $busCenters2"><error><context><xsl:value-of select="$newContext"/></context><text>*** If businessDayConvention is not equal to 'NONE' businessCenters must equal floating leg calculationPeriodDates/calculationPeriodDatesAdjustments/businessCenters.</text></error></xsl:if>
</xsl:if>
</xsl:if>



<xsl:variable name="businessDayConvention"><xsl:value-of select="fpml:businessDayConvention"/></xsl:variable>
<xsl:call-template name="isValidBusinessDayConvention">
<xsl:with-param name="elementName">businessDayConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$businessDayConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:businessCentersReference"><error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected element businessCentersReference encountered.</text></error></xsl:if>


<xsl:if test="$businessDayConvention='NONE'">
<xsl:if test="fpml:businessCenters"><error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected element businessCenters encountered when businessDayConvention = 'NONE'.</text></error></xsl:if>
</xsl:if>


<xsl:if test="$businessDayConvention!='NONE'">
<xsl:if test="not(fpml:businessCenters)"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing businessCenters. Needed when businessDayConvention not equal to 'NONE'.</text></error></xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:businessCenters">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:calculationPeriodFrequency">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidperiodMultiplier">
<xsl:with-param name="elementName">periodMultiplier</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:periodMultiplier"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:call-template name="isValidPeriod">
<xsl:with-param name="elementName">period</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:period"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:variable name="freq"><xsl:value-of select="fpml:periodMultiplier"/><xsl:value-of select="fpml:period"/></xsl:variable>

<xsl:if test="$productType='OIS'">
<xsl:choose>
<xsl:when test="$freq='6M'"/>
<xsl:when test="$freq='1Y'"/>
<xsl:when test="$freq='1T'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** calculationPeriodFrequency must be equal to 6M, 1Y or 1T if product type is 'OIS'. Value = '<xsl:value-of select="$freq"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>


<xsl:call-template name="isValidRollConvention">
<xsl:with-param name="elementName">rollConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:rollConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="rollConvention"><xsl:value-of select="fpml:rollConvention"/></xsl:variable>
<xsl:if test="$freq='1T'">
<xsl:if test="not($rollConvention='NONE')"><error><context><xsl:value-of select="$newContext"/></context><text>*** rollConvention must be equal to 'NONE' if calculationPeriodFrequency is equal to '1T'. Value = '<xsl:value-of select="$rollConvention"/>'.</text></error></xsl:if>
</xsl:if>


<xsl:if test="$productType='IRS' and $tradeCurrency='MXN'">
<xsl:if test="not($rollConvention='NONE')"><error><context><xsl:value-of select="$newContext"/></context><text>*** rollConvention must be equal to 'NONE' if product type is 'SingleCurrencyInterestRateSwap' and currency is 'MXN'. Value = '<xsl:value-of select="$rollConvention"/>'.</text></error></xsl:if>
</xsl:if>




<xsl:if test="(starts-with($rollConvention,'IMM'))">
<xsl:variable name="floatFreq">
<xsl:value-of select="//fpml:swapStream[@id='floatingLeg']/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:periodMultiplier"/><xsl:value-of select="//fpml:swapStream[@id='floatingLeg']/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:period"/>
<xsl:value-of select="//fpml:capFloorStream/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:periodMultiplier"/><xsl:value-of select="//fpml:capFloorStream/fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:period"/>
</xsl:variable>
<xsl:call-template name="isValidIMMCurrency">
<xsl:with-param name="elementName"></xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$tradeCurrency"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
<xsl:call-template name="isValidIMMMonth">
<xsl:with-param name="elementName">../effectiveDate/unadjustedDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="../fpml:effectiveDate/fpml:unadjustedDate"/></xsl:with-param>
<xsl:with-param name="calculationPeriodFrequency"><xsl:value-of select="$floatFreq"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
<xsl:call-template name="isValidIMMMonth">
<xsl:with-param name="elementName">../terminationDate/unadjustedDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="../fpml:terminationDate/fpml:unadjustedDate"/></xsl:with-param>
<xsl:with-param name="calculationPeriodFrequency"><xsl:value-of select="$floatFreq"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:paymentDates">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="href"><xsl:value-of select="fpml:calculationPeriodDatesReference/@href"/></xsl:variable>
<xsl:variable name="id"><xsl:value-of select="../fpml:calculationPeriodDates/@id"/></xsl:variable>
<xsl:if test="$href!=$id"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid calculationPeriodDatesReference/@href value. Value is not equal to ../calculationPeriodDates/@id. Value of href = '<xsl:value-of select="$href"/>' and id = '<xsl:value-of select="$id"/>'.</text></error></xsl:if>

<xsl:apply-templates select="fpml:paymentFrequency">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:if test="fpml:firstPaymentDate">
<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">firstPaymentDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:firstPaymentDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>

<xsl:if test="fpml:lastRegularPaymentDate">
<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">lastRegularPaymentDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:lastRegularPaymentDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:variable name="payRelativeTo"><xsl:value-of select="fpml:payRelativeTo"/></xsl:variable>
<xsl:call-template name="isValidPayRelativeTo">
<xsl:with-param name="elementName">payRelativeTo</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$payRelativeTo"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:paymentDaysOffset">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:paymentDatesAdjustments">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:paymentFrequency">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="periodMultiplier"><xsl:value-of select="fpml:periodMultiplier"/></xsl:variable>
<xsl:call-template name="isValidperiodMultiplier">
<xsl:with-param name="elementName">periodMultiplier</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$periodMultiplier"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="period"><xsl:value-of select="fpml:period"/></xsl:variable>
<xsl:call-template name="isValidPeriod">
<xsl:with-param name="elementName">period</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$period"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:variable name="freq"><xsl:value-of select="fpml:periodMultiplier"/><xsl:value-of select="fpml:period"/></xsl:variable>

<xsl:if test="$productType='OIS'">
<xsl:choose>
<xsl:when test="$freq='6M'"/>
<xsl:when test="$freq='1Y'"/>
<xsl:when test="$freq='1T'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** paymentFrequency must be equal to 6M, 1Y or 1T if product type is 'OIS'. Value = '<xsl:value-of select="$freq"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:paymentDaysOffset">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="periodMultiplier"><xsl:value-of select="fpml:periodMultiplier"/></xsl:variable>
<xsl:call-template name="isValidperiodMultiplier">
<xsl:with-param name="elementName">periodMultiplier</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$periodMultiplier"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="$periodMultiplier='0'"><error><context><xsl:value-of select="$newContext"/></context><text>*** periodMultiplier must not be equal to '0'</text></error></xsl:if>


<xsl:variable name="period"><xsl:value-of select="fpml:period"/></xsl:variable>
<xsl:if test="$period!='D'"><error><context><xsl:value-of select="$newContext"/></context><text>*** period must be equal to 'D' in this context. Value = '<xsl:value-of select="$period"/>'</text></error></xsl:if>


<xsl:variable name="dayType"><xsl:value-of select="fpml:dayType"/></xsl:variable>
<xsl:if test="$dayType!='Business'"><error><context><xsl:value-of select="$newContext"/></context><text>*** dayType must be equal to 'Business'. Value = '<xsl:value-of select="$dayType"/>'</text></error></xsl:if>

</xsl:template>


<xsl:template match="fpml:paymentDatesAdjustments">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="businessDayConvention"><xsl:value-of select="fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="$businessDayConvention='NONE'"><error><context><xsl:value-of select="$newContext"/></context><text>*** businessDayConvention must not be equal to 'NONE'.</text></error></xsl:if>


<xsl:call-template name="isValidBusinessDayConvention">
<xsl:with-param name="elementName">businessDayConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$businessDayConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:businessCentersReference"><error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected element businessCentersReference encountered.</text></error></xsl:if>


<xsl:if test="$businessDayConvention!='NONE'">
<xsl:if test="not(fpml:businessCenters)"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing businessCenters. Needed when businessDayConvention not equal to 'NONE'.</text></error></xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:businessCenters">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:resetDates">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="href"><xsl:value-of select="fpml:calculationPeriodDatesReference/@href"/></xsl:variable>
<xsl:variable name="id"><xsl:value-of select="../fpml:calculationPeriodDates/@id"/></xsl:variable>
<xsl:if test="$href!=$id"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid calculationPeriodDatesReference/@href value. Value is not equal to ../calculationPeriodDates/@id. Value of href = '<xsl:value-of select="$href"/>' and id = '<xsl:value-of select="$id"/>'.</text></error></xsl:if>


<xsl:variable name="id2"><xsl:value-of select="./@id"/></xsl:variable>
<xsl:if test="$id2 =''"><error><context><xsl:value-of select="$newContext"/></context><text>*** Empty or missing resetDates/@id value. Value = '<xsl:value-of select="$id2"/>'.</text></error></xsl:if>


<xsl:call-template name="isValidResetRelativeTo">
<xsl:with-param name="elementName">resetRelativeTo</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:resetRelativeTo"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:initialFixingDate">
<xsl:if test="$productType='OIS'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected initialFixingDate child element encountered. Not allowed if product type is 'OIS'.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="fpml:initialFixingDate">
<xsl:if test="not($tradeCurrency = 'USD' or $tradeCurrency = 'CHF')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** initialFixingDate should only be present if trade currency is equal to 'USD' or 'CHF'. Value = '<xsl:value-of select="$tradeCurrency"/>'.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:initialFixingDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:fixingDates">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:initialFixingDate">
<xsl:variable name="initialFixingperiodMultiplier">
<xsl:for-each select="fpml:initialFixingDate/fpml:periodMultiplier">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:variable name="fixingperiodMultiplier">
<xsl:for-each select="fpml:fixingDates/fpml:periodMultiplier">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:variable name="initialFixingBusCenters">
<xsl:for-each select="fpml:initialFixingDate/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:variable name="fixingBusCenters">
<xsl:for-each select="fpml:fixingDates/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:if test="($initialFixingperiodMultiplier = $fixingperiodMultiplier) and ($initialFixingBusCenters = $fixingBusCenters)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** initialFixingDate offset rules must only be included if they are different to those specified in fixingDates. Currently they are specified the same.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:resetFrequency">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:resetDatesAdjustments">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:initialFixingDate|fpml:fixingDates">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="periodMultiplier"><xsl:value-of select="fpml:periodMultiplier"/></xsl:variable>
<xsl:call-template name="isValidIntegerNumber">
<xsl:with-param name="elementName">periodMultiplier</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$periodMultiplier"/></xsl:with-param>
<xsl:with-param name="minIncl">-99</xsl:with-param>
<xsl:with-param name="maxIncl">0</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="period"><xsl:value-of select="fpml:period"/></xsl:variable>
<xsl:if test="$period!='D'"><error><context><xsl:value-of select="$newContext"/></context><text>*** period must be equal to 'D' in this context. Value = '<xsl:value-of select="$period"/>'</text></error></xsl:if>



<xsl:if test="$periodMultiplier='0' and $period='D'">
<xsl:if test="dayType"><error><context><xsl:value-of select="$newContext"/></context><text>*** dayType should not be present if periodMultiplier is '0' and period is 'D'.</text></error></xsl:if>
<xsl:if test="not(//fpml:businessDayConvention='PRECEDING')"><error><context><xsl:value-of select="$newContext"/></context><text>*** businessDayConvention must equal 'PRECEDING' if periodMultiplier is '0' and period is 'D'. Value = '<xsl:value-of select="fpml:businessDayConvention"/>'.</text></error></xsl:if>
</xsl:if>


<xsl:variable name="dayType"><xsl:value-of select="fpml:dayType"/></xsl:variable>
<xsl:if test="$periodMultiplier!='0' and $period='D' and $dayType='Business'">
<xsl:if test="not(//fpml:businessDayConvention='NONE')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** businessDayConvention must equal 'NONE' if period is equal to 'D' and periodMultiplier is not equal to '0' and dayType is equal to 'Business'. Value = '<xsl:value-of select="fpml:businessDayConvention"/>'.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="not($periodMultiplier='0' and $period='D')">
<xsl:call-template name="isValidDayType">
<xsl:with-param name="elementName">dayType</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$dayType"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:variable name="businessDayConvention"><xsl:value-of select="fpml:businessDayConvention"/></xsl:variable>
<xsl:call-template name="isValidBusinessDayConvention">
<xsl:with-param name="elementName">businessDayConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$businessDayConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:businessCentersReference"><error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected element businessCentersReference encountered.</text></error></xsl:if>


<xsl:if test="$businessDayConvention!='NONE'">
<xsl:if test="not(//fpml:businessCenters)"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing businessCenters. Needed when businessDayConvention not equal to 'NONE'.</text></error></xsl:if>
</xsl:if>


<xsl:if test="$dayType='Business'">
<xsl:if test="not(//fpml:businessCenters)"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing businessCenters. Needed when dayType is equal to 'Business'.</text></error></xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:businessCenters">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:variable name="href"><xsl:value-of select="fpml:dateRelativeTo/@href"/></xsl:variable>
<xsl:variable name="id"><xsl:value-of select="../../fpml:resetDates/@id"/></xsl:variable>
<xsl:if test="$href!=$id"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid dateRelativeTo/@href value. Value is not equal to ../../resetDates/@id. Value of href = '<xsl:value-of select="$href"/>' and id = '<xsl:value-of select="$id"/>'.</text></error></xsl:if>


<xsl:if test="$href!='resetDates'"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid dateRelativeTo value. Value = '<xsl:value-of select="$href"/>'.</text></error></xsl:if>

</xsl:template>


<xsl:template match="fpml:resetFrequency">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidperiodMultiplier">
<xsl:with-param name="elementName">periodMultiplier</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:periodMultiplier"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:call-template name="isValidPeriod">
<xsl:with-param name="elementName">period</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:period"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:variable name="freq"><xsl:value-of select="fpml:periodMultiplier"/><xsl:value-of select="fpml:period"/></xsl:variable>

<xsl:if test="$productType='IRS' or $productType='Swaption'">
<xsl:choose>
<xsl:when test="$freq='28D'"/>
<xsl:when test="$freq='1M'"/>
<xsl:when test="$freq='3M'"/>
<xsl:when test="$freq='6M'"/>
<xsl:when test="$freq='1Y'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** resetFrequency must be equal to 28D, 1M, 3M, 6M or 1Y if product type is 'SingleCurrencyInterestRateSwap' or 'Swaption'. Value = '<xsl:value-of select="$freq"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>


<xsl:if test="$productType='OIS'">
<xsl:choose>
<xsl:when test="$freq='6M'"/>
<xsl:when test="$freq='1Y'"/>
<xsl:when test="$freq='1T'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** resetFrequency must be equal to 6M, 1Y or 1T if product type is 'OIS'. Value = '<xsl:value-of select="$freq"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:resetDatesAdjustments">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="businessDayConvention"><xsl:value-of select="fpml:businessDayConvention"/></xsl:variable>
<xsl:call-template name="isValidBusinessDayConvention">
<xsl:with-param name="elementName">businessDayConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$businessDayConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:businessCentersReference"><error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected element businessCentersReference encountered.</text></error></xsl:if>


<xsl:if test="$businessDayConvention!='NONE'">
<xsl:if test="not(//fpml:businessCenters)"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing businessCenters. Needed when businessDayConvention not equal to 'NONE'.</text></error></xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:businessCenters">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:calculationPeriodAmount">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:if test="$interestRateSwapType = 'zeroCouponInterestRateSwapWithFixedAmount'">
<xsl:apply-templates select="fpml:knownAmountSchedule">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>
</xsl:if>

<xsl:apply-templates select="fpml:calculation">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>

<xsl:template match="fpml:knownAmountSchedule">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:variable name="initialValue"><xsl:value-of select="fpml:initialValue"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">initialValue</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$initialValue"/></xsl:with-param>
<xsl:with-param name="minIncl">0.01</xsl:with-param>
<xsl:with-param name="maxIncl">999999999999.99</xsl:with-param>
<xsl:with-param name="maxDecs">2</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:template>

<xsl:template match="fpml:calculation">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidDayCountFraction">
<xsl:with-param name="elementName">dayCountFraction</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:dayCountFraction"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>




<xsl:if test="fpml:compoundingMethod">
<xsl:choose>
<xsl:when test="$productType='OIS'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** compoundingMethod must not be present if product type is 'OIS'.</text></error>
</xsl:when>
<xsl:when test="not(../../fpml:resetDates)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** compoundingMethod must only exist on floating stream.</text></error>
</xsl:when>
<xsl:otherwise>
<xsl:call-template name="isValidCompoundingMethod">
<xsl:with-param name="elementName">compoundingMethod</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:compoundingMethod"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:otherwise>
</xsl:choose>
</xsl:if>



<xsl:if test="not($productType='OIS')">
<xsl:if test="../../fpml:resetDates">
<xsl:variable name="calcFreq">
<xsl:value-of select="../../fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:periodMultiplier"/>
<xsl:value-of select="../../fpml:calculationPeriodDates/fpml:calculationPeriodFrequency/fpml:period"/>
</xsl:variable>
<xsl:variable name="payFreq">
<xsl:value-of select="../../fpml:paymentDates/fpml:paymentFrequency/fpml:periodMultiplier"/>
<xsl:value-of select="../../fpml:paymentDates/fpml:paymentFrequency/fpml:period"/>
</xsl:variable>
<xsl:if test="not($calcFreq = $payFreq)">
<xsl:if test="not(//fpml:compoundingMethod)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing element. compoundingMethod must be present when compounding is implied by different payment and calculation frequencies.</text></error>
</xsl:if>
</xsl:if>
<xsl:if test="$calcFreq = $payFreq">
<xsl:if test="fpml:compoundingMethod">
<error><context><xsl:value-of select="$newContext"/></context><text>*** compoundingMethod must not be present when compounding is not implied by payment and calculation frequencies.</text></error>
</xsl:if>
</xsl:if>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:notionalSchedule">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:if test="($productType='ZCInflationSwap')">
<xsl:apply-templates select="fpml:inflationRateCalculation">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>
</xsl:if>

<xsl:apply-templates select="fpml:fixedRateSchedule">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:floatingRateCalculation">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:notionalSchedule">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:notionalStepSchedule">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:notionalStepSchedule">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="initialValue"><xsl:value-of select="fpml:initialValue"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">initialValue</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$initialValue"/></xsl:with-param>
<xsl:with-param name="minIncl">0.01</xsl:with-param>
<xsl:with-param name="maxIncl">999999999999.99</xsl:with-param>
<xsl:with-param name="maxDecs">2</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:call-template name="isValidCurrency">
<xsl:with-param name="elementName">currency</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:currency"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:template>



<xsl:template match="fpml:inflationRateCalculation">

<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="inflationLag"><xsl:value-of select="fpml:inflationLag/fpml:periodMultiplier"/><xsl:value-of select="fpml:inflationLag/fpml:period"/></xsl:variable>
<xsl:choose>
<xsl:when test="$inflationLag='0M'"/>
<xsl:when test="$inflationLag='1M'"/>
<xsl:when test="$inflationLag='2M'"/>
<xsl:when test="$inflationLag='3M'"/>
<xsl:when test="$inflationLag='4M'"/>
<xsl:when test="$inflationLag='5M'"/>
<xsl:when test="$inflationLag='6M'"/>
<xsl:when test="$inflationLag='7M'"/>
<xsl:when test="$inflationLag='8M'"/>
<xsl:when test="$inflationLag='9M'"/>
<xsl:when test="$inflationLag='10M'"/>
<xsl:when test="$inflationLag='11M'"/>
<xsl:when test="$inflationLag='12M'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** inflationLag must be equal to 0M,1M, 2M, 3M, 4M, 5M, 6M, 7M, 8M, 9M, 10M, 11M, 12M. Value = '<xsl:value-of select="$inflationLag"/>'.</text></error></xsl:otherwise>
</xsl:choose>


<xsl:variable name="interpolationMethod"><xsl:value-of select="fpml:interpolationMethod"/></xsl:variable>
<xsl:choose>
<xsl:when test="$interpolationMethod='Linear'"/>
<xsl:when test="$interpolationMethod='None'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** interpolationMethod must be equal to 'Linear' or 'None'. Value = '<xsl:value-of select="$interpolationMethod"/>'.</text></error></xsl:otherwise>
</xsl:choose>


</xsl:template>


<xsl:template match="fpml:fixedRateSchedule">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="initialValue"><xsl:value-of select="fpml:initialValue"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">initialValue</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$initialValue"/></xsl:with-param>
<xsl:with-param name="minIncl">-9.99999999</xsl:with-param>
<xsl:with-param name="maxIncl">9.99999999</xsl:with-param>
<xsl:with-param name="maxDecs">8</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:template>


<xsl:template match="fpml:floatingRateCalculation">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="floatingRateIndex"><xsl:value-of select="fpml:floatingRateIndex"/></xsl:variable>
<xsl:if test="$floatingRateIndex=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Empty or missing floatingRateIndex.</text></error>
</xsl:if>


<xsl:if test="$tradeCurrency != 'PLN'">
<xsl:variable name="floatingRateIndexCurrency"><xsl:value-of select="substring($floatingRateIndex,1,3)"/></xsl:variable>
<xsl:if test="$tradeCurrency != $floatingRateIndexCurrency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** floatingRateIndex value of '<xsl:value-of select="$floatingRateIndex"/>' is not valid for trade currency of '<xsl:value-of select="$tradeCurrency"/>'.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="$productType='OIS'">
<xsl:if test="fpml:initialRate">
<error><context><xsl:value-of select="$newContext"/></context><text>*** initialRate must not be present if product type is 'OIS'.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="$productType='Swaption'">
<xsl:if test="fpml:initialRate">
<error><context><xsl:value-of select="$newContext"/></context><text>*** initialRate must not be present if product type is 'Swaption'.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="fpml:initialRate">
<xsl:if test="../../../fpml:stubCalculationPeriodAmount/fpml:initialStub">
<error><context><xsl:value-of select="$newContext"/></context><text>*** initialRate and ../../../stubCalculationPeriodAmount/initialStub must not both be present.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="fpml:initialRate">
<xsl:variable name="initialRate"><xsl:value-of select="fpml:initialRate"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">initialRate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$initialRate"/></xsl:with-param>
<xsl:with-param name="minIncl">-9.9999999</xsl:with-param>
<xsl:with-param name="maxIncl">9.9999999</xsl:with-param>
<xsl:with-param name="maxDecs">7</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="$productType='OIS'">
<xsl:if test="fpml:indexTenor">
<error><context><xsl:value-of select="$newContext"/></context><text>*** indexTenor must not be present if product type is 'OIS'.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:indexTenor">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="$productType='OIS'">
<xsl:if test="fpml:spreadSchedule">
<error><context><xsl:value-of select="$newContext"/></context><text>*** spreadSchedule must not be present if product type is 'OIS'.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:spreadSchedule">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:indexTenor">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>



<xsl:call-template name="isValidperiodMultiplier">
<xsl:with-param name="elementName">periodMultiplier</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:periodMultiplier"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:call-template name="isValidPeriod">
<xsl:with-param name="elementName">period</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:period"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>



<xsl:if test="($productType='IRS' or $productType='Swaption') and not(parent::fpml:floatingRate)">
<xsl:variable name="indexTenor"><xsl:value-of select="fpml:periodMultiplier"/><xsl:value-of select="fpml:period"/></xsl:variable>
<xsl:choose>
<xsl:when test="$indexTenor='28D'"/>
<xsl:when test="$indexTenor='1M'"/>
<xsl:when test="$indexTenor='3M'"/>
<xsl:when test="$indexTenor='6M'"/>
<xsl:when test="$indexTenor='1Y'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** indexTenor must be equal to 28D, 1M, 3M, 6M or 1Y if product type is 'SingleCurrencyInterestRateSwap' or 'Swaption'. Value = '<xsl:value-of select="$indexTenor"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>


<xsl:if test="$productType='FRA'">
<xsl:variable name="indexTenor"><xsl:value-of select="fpml:periodMultiplier"/><xsl:value-of select="fpml:period"/></xsl:variable>
<xsl:choose>
<xsl:when test="$indexTenor='1W'"/>
<xsl:when test="$indexTenor='2W'"/>
<xsl:when test="$indexTenor='3W'"/>
<xsl:when test="$indexTenor='1M'"/>
<xsl:when test="$indexTenor='2M'"/>
<xsl:when test="$indexTenor='3M'"/>
<xsl:when test="$indexTenor='4M'"/>
<xsl:when test="$indexTenor='5M'"/>
<xsl:when test="$indexTenor='6M'"/>
<xsl:when test="$indexTenor='7M'"/>
<xsl:when test="$indexTenor='8M'"/>
<xsl:when test="$indexTenor='9M'"/>
<xsl:when test="$indexTenor='10M'"/>
<xsl:when test="$indexTenor='11M'"/>
<xsl:when test="$indexTenor='12M'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** indexTenor must be equal to 1W, 2W, 3W, 1M, 2M, 3M, 4M, 5M, 6M, 7M, 8M, 9M, 10M, 11M or 12M if product type is 'FRA'. Value = '<xsl:value-of select="$indexTenor"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:spreadSchedule">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="initialValue"><xsl:value-of select="fpml:initialValue"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">initialValue</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$initialValue"/></xsl:with-param>
<xsl:with-param name="minIncl">-0.0999999</xsl:with-param>
<xsl:with-param name="maxIncl">0.0999999</xsl:with-param>
<xsl:with-param name="maxDecs">7</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:template>


<xsl:template match="fpml:stubCalculationPeriodAmount">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="href"><xsl:value-of select="fpml:calculationPeriodDatesReference/@href"/></xsl:variable>
<xsl:variable name="id"><xsl:value-of select="../fpml:calculationPeriodDates/@id"/></xsl:variable>
<xsl:if test="$href!=$id"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid calculationPeriodDatesReference/@href value. Value is not equal to ../calculationPeriodDates/@id. Value of href = '<xsl:value-of select="$href"/>' and id = '<xsl:value-of select="$id"/>'.</text></error></xsl:if>


<xsl:if test="fpml:initialStub and fpml:finalStub">
<error><context><xsl:value-of select="$newContext"/></context><text>*** initialStub and finalStub must not both be present.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:initialStub or fpml:finalStub)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** initialStub or finalStub must be present.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:initialStub">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:finalStub">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:initialStub">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="count(fpml:floatingRate) &gt; 2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of floatingRate child elements encountered. 0, 1 or 2 expected. <xsl:value-of select="count(fpml:floatingRate)"/> found.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:floatingRate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:stubRate">
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">stubRate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:stubRate"/></xsl:with-param>
<xsl:with-param name="minIncl">-9.9999999</xsl:with-param>
<xsl:with-param name="maxIncl">9.9999999</xsl:with-param>
<xsl:with-param name="maxDecs">7</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:finalStub">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="not(count(fpml:floatingRate)=1 or count(fpml:floatingRate)=2)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of floatingRate child elements encountered. 1 or 2 expected. <xsl:value-of select="count(fpml:floatingRate)"/> found.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:floatingRate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:stubRate">
<error><context><xsl:value-of select="$newContext"/></context><text>*** stubRate must not be present in this context.</text></error>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:floatingRate">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>



<xsl:variable name="floatingRateIndex"><xsl:value-of select="fpml:floatingRateIndex"/></xsl:variable>
<xsl:if test="$floatingRateIndex=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Empty or missing floatingRateIndex.</text></error>
</xsl:if>


<xsl:if test="../../../fpml:stubCalculationPeriodAmount">
<xsl:variable name="floatingRateIndex2"><xsl:value-of select="../../../fpml:calculationPeriodAmount/fpml:calculation/fpml:floatingRateCalculation/fpml:floatingRateIndex"/></xsl:variable>
<xsl:if test="$floatingRateIndex != $floatingRateIndex2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** floatingRateIndex (<xsl:value-of select="$floatingRateIndex"/>) must equal ../../../calculationPeriodAmount/calculation/floatingRateCalculation/floatingRateIndex (<xsl:value-of select="$floatingRateIndex2"/>)</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="$tradeCurrency != 'PLN'">
<xsl:variable name="floatingRateIndexCurrency"><xsl:value-of select="substring($floatingRateIndex,1,3)"/></xsl:variable>
<xsl:if test="$tradeCurrency != $floatingRateIndexCurrency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** floatingRateIndex value of '<xsl:value-of select="$floatingRateIndex"/>' is not valid for trade currency of '<xsl:value-of select="$tradeCurrency"/>'.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:indexTenor">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:spreadSchedule">
<error><context><xsl:value-of select="$newContext"/></context><text>*** spreadSchedule must not be present in this context.</text></error>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:earlyTerminationProvision">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="not(/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swEarlyTerminationProvision)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing /SWDML/swLongFormTrade/swStructuredTradeDetails/swExtendedTradeDetails/swEarlyTerminationProvision element. Required if earlyTerminationProvision is present.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:mandatoryEarlyTermination">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:optionalEarlyTermination">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:mandatoryEarlyTermination">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swEarlyTerminationProvision/fpml:swBreakFrequency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected /SWDML/swLongFormTrade/swStructuredTradeDetails/fpml:swExtendedTradeDetails/swEarlyTerminationProvision/swBreakFrequency element encountered. Element not allowed for mandatory early termination.</text></error>
</xsl:if>


<xsl:variable name="id"><xsl:value-of select=".//@id"/></xsl:variable>
<xsl:if test="$id=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or empty mandatoryEarlyTermination/@id attribute value. Value = '<xsl:value-of select="$id"/>'.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:mandatoryEarlyTerminationDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swEarlyTerminationProvision/fpml:swBreakCalculationMethod = 'ISDA Standard Method'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** /fpml:SWDML/swLongFormTrade/swStructuredTradeDetails/swExtendedTradeDetails/fpml:swEarlyTerminationProvision/swBreakCalculationMethod must not be equal to 'ISDA Standard Method' for mandatory early termination. For mandatory early termination valid values are 'Adjust To Coupon Dates' or 'Straight Calendar Dates'.</text></error>
</xsl:if>


<xsl:apply-templates select="fpml:calculationAgent">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:cashSettlement">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:mandatoryEarlyTerminationDate">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="businessDayConvention"><xsl:value-of select="fpml:dateAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="$businessDayConvention='NONE'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** dateAdjustments/businessDayConvention must not be equal to 'NONE'.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:dateAdjustments">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:variable name="businessDayConvention1">
<xsl:value-of select="fpml:dateAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:variable name="businessDayConvention2">
<xsl:value-of select="//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessDayConvention"/>
</xsl:variable>
<xsl:if test="$businessDayConvention1!=$businessDayConvention2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** dateAdjustments/fpml:businessDayConvention must be the same as the swap floating stream paymentDates/fpml:paymentDatesAdjustments/fpml:businessDayConvention. Value = '<xsl:value-of select="$businessDayConvention1"/>' and '<xsl:value-of select="$businessDayConvention2"/>.'</text></error>
</xsl:if>


<xsl:variable name="businessCenters1">
<xsl:for-each select="fpml:dateAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:variable name="businessCenters2">
<xsl:for-each select="//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:if test="$businessCenters1!=$businessCenters2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** dateAdjustments/businessCenters must be the same as the swap floating stream paymentDates/paymentDatesAdjustments/businessCenters. Value = '<xsl:value-of select="$businessCenters1"/>' and '<xsl:value-of select="$businessCenters2"/>.'</text></error>
</xsl:if>


<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">unadjustedDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:unadjustedDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:template>


<xsl:template match="fpml:calculationAgent">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="count(fpml:calculationAgentPartyReference) &gt; 2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of calculationAgentPartyReference child elements encountered. 0 to 2 expected.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:calculationAgentPartyReference">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:calculationAgentParty">
<xsl:call-template name="isValidCalculationAgentParty">
<xsl:with-param name="elementName">calculationAgentParty</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:calculationAgentParty"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:calculationAgentPartyReference">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>


<xsl:variable name="href"><xsl:value-of select="@href"/></xsl:variable>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$href])">
<error><context><xsl:value-of select="$newContext"/></context><text>*** calculationAgentPartyReference/@href does not reference a valid /FpML/party/@id. Value = '<xsl:value-of select="$href"/>'.</text></error>
</xsl:if>


</xsl:template>


<xsl:template match="fpml:cashSettlement">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>





<xsl:apply-templates select="fpml:cashSettlementValuationTime">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:cashSettlementValuationDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="../../fpml:mandatoryEarlyTermination">
<xsl:if test="fpml:cashSettlementPaymentDate">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Element cashSettlementPaymentDate must not be present for mandatory early termination.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="../../fpml:optionalEarlyTermination">
<xsl:if test="not(fpml:cashSettlementPaymentDate)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** cashSettlementPaymentDate must be present for optional early termination.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:cashSettlementPaymentDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:cashPriceMethod">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:cashPriceAlternateMethod">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:parYieldCurveAdjustedMethod">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:parYieldCurveUnadjustedMethod">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:zeroCouponYieldAdjustedMethod">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:cashSettlementValuationTime|fpml:earliestExerciseTime|fpml:latestExerciseTime|fpml:expirationTime">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidTime">
<xsl:with-param name="elementName">hourMinuteTime</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:hourMinuteTime"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:call-template name="isValidBusinessCenter">
<xsl:with-param name="elementName">businessCenter</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:businessCenter"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="businessCenter"><xsl:value-of select="fpml:businessCenter"/></xsl:variable>
<xsl:if test="$businessCenter='EUTA'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** A time businessCenter must not be equal to 'EUTA'.</text></error>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:cashSettlementValuationDate|fpml:relativeDate|fpml:relativeDates">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="periodMultiplier"><xsl:value-of select="fpml:periodMultiplier"/></xsl:variable>
<xsl:call-template name="isValidperiodMultiplier">
<xsl:with-param name="elementName">periodMultiplier</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$periodMultiplier"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="period"><xsl:value-of select="fpml:period"/></xsl:variable>
<xsl:if test="$period!='D'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** period must be equal to 'D' in this context. Value = '<xsl:value-of select="$period"/>'</text></error>
</xsl:if>



<xsl:if test="$periodMultiplier='0' and $period='D'">
<xsl:if test="fpml:dayType">
<error><context><xsl:value-of select="$newContext"/></context><text>*** dayType should not be present if periodMultiplier is '0' and period is 'D'.</text></error>
</xsl:if>
<xsl:choose>
<xsl:when test="not(../../../../fpml:swaption) and not(../../../fpml:swaption)">
<xsl:if test="not(//fpml:businessDayConvention='PRECEDING')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** businessDayConvention must equal 'PRECEDING' if periodMultiplier is '0' and period is 'D' if product type is 'SingleCurrencyInterestRateSwap'. Value = '<xsl:value-of select="fpml:businessDayConvention"/>'.</text></error>
</xsl:if>
</xsl:when>

<xsl:when test="../../../../fpml:swaption or ../../../fpml:swaption">
<xsl:if test="not(fpml:businessDayConvention='NONE')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** businessDayConvention must equal 'NONE' if periodMultiplier is '0' and period is 'D' if product type is 'Swaption'. Value = '<xsl:value-of select="fpml:businessDayConvention"/>'.</text></error>
</xsl:if>
</xsl:when>
<xsl:otherwise>*** Unknown condition occurred</xsl:otherwise>
</xsl:choose>
</xsl:if>


<xsl:if test="not($periodMultiplier='0' and $period='D')">
<xsl:call-template name="isValidDayType">
<xsl:with-param name="elementName">dayType</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:dayType"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:variable name="businessDayConvention"><xsl:value-of select="fpml:businessDayConvention"/></xsl:variable>
<xsl:call-template name="isValidBusinessDayConvention">
<xsl:with-param name="elementName">businessDayConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$businessDayConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:businessCentersReference">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected element businessCentersReference encountered.</text></error>
</xsl:if>


<xsl:if test="$businessDayConvention!='NONE'">
<xsl:if test="not(fpml:businessCenters)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing businessCenters.  Needed when businessDayConvention not equal to 'NONE'.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:businessCenters">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:if test="ancestor::fpml:mandatoryEarlyTermination">

<xsl:variable name="href"><xsl:value-of select="fpml:dateRelativeTo/@href"/></xsl:variable>
<xsl:variable name="id"><xsl:value-of select="ancestor::fpml:mandatoryEarlyTermination//@id"/></xsl:variable>
<xsl:if test="$href!=$id">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid dateRelativeTo/@href value. Value is not equal to ancestor::mandatoryEarlyTermination/@id. Value of href = '<xsl:value-of select="$href"/>' and id = '<xsl:value-of select="$id"/>'..</text></error>
</xsl:if>


<xsl:if test="$href!='mandatoryEarlyTerminationDate'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid dateRelativeTo value. Value = '<xsl:value-of select="$href"/>'.</text></error>
</xsl:if>
</xsl:if>

<xsl:if test="ancestor::fpml:swap/fpml:optionalEarlyTermination">

<xsl:variable name="href"><xsl:value-of select="fpml:dateRelativeTo/@href"/></xsl:variable>
<xsl:variable name="id"><xsl:value-of select="//fpml:FpML/fpml:trade//fpml:swap/fpml:earlyTerminationProvision/fpml:optionalEarlyTermination/fpml:cashSettlement/@id"/></xsl:variable>
<xsl:if test="$href!=$id">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid dateRelativeTo/@href value. Value is not equal to FpML/trade/swap/fpml:earlyTerminationProvision/fpml:optionalEarlyTermination/fpml:cashSettlement/@id. Value of href = '<xsl:value-of select="$href"/>' and id = '<xsl:value-of select="$id"/>'..</text></error>
</xsl:if>


<xsl:if test="$href!='cashSettlementPaymentDate'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid dateRelativeTo value. Value = '<xsl:value-of select="$href"/>'.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="ancestor::fpml:swaption/fpml:cashSettlement">
<xsl:if test="../../../../fpml:swaption or ../../../fpml:swaption">


<xsl:if test="../../fpml:cashSettlementPaymentDate or ../fpml:cashSettlementValuationDate">
<xsl:variable name="href"><xsl:value-of select="fpml:dateRelativeTo/@href"/></xsl:variable>
<xsl:variable name="id"><xsl:value-of select="//fpml:FpML/fpml:trade//fpml:swaption/fpml:europeanExercise/@id"/></xsl:variable>
<xsl:if test="$href!=$id">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid dateRelativeTo/@href value. Value is not equal to //fpml:FpML/fpml:trade//fpml:swaption/fpml:europeanExercise/@id. Value of href = '<xsl:value-of select="$href"/>' and id = '<xsl:value-of select="$id"/>'..</text></error>
</xsl:if>


<xsl:if test="$href!='exercisePeriod'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid dateRelativeTo value. Value = '<xsl:value-of select="$href"/>'.</text></error>
</xsl:if>
</xsl:if>



</xsl:if>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:cashPriceMethod|fpml:cashPriceAlternateMethod">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:cashSettlementReferenceBanks">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="not(/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swSettlementProvision/fpml:swNonDeliverableSettlement)">
<xsl:variable name="cashSettlementCurrency"><xsl:value-of select="fpml:cashSettlementCurrency"/></xsl:variable>
<xsl:if test="not($cashSettlementCurrency=$tradeCurrency)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** cashSettlementCurrency must be the same as trade currency if trade currency is deliverable. Value = '<xsl:value-of select="$cashSettlementCurrency"/>'.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swSettlementProvision/fpml:swNonDeliverableSettlement">
<xsl:if test="fpml:cashSettlementCurrency!='USD'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** cashSettlementCurrency must be equal to 'USD' if trade currency is non-deliverable. Value = '<xsl:value-of select="cashSettlementCurrency"/>'.</text></error>
</xsl:if>
</xsl:if>


<xsl:call-template name="isValidQuotationRateType">
<xsl:with-param name="elementName">quotationRateType</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:quotationRateType"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="ancestor::fpml:mandatoryEarlyTermination">
<xsl:if test="fpml:quotationRateType='ExercisingPartyPays'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** A quotationRateType value of 'ExercisingPartyPays' is not allowed for a mandatory early termination.</text></error>
</xsl:if>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:parYieldCurveAdjustedMethod|fpml:parYieldCurveUnadjustedMethod|fpml:zeroCouponYieldAdjustedMethod">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:settlementRateSource">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:call-template name="isValidQuotationRateType">
<xsl:with-param name="elementName">quotationRateType</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:quotationRateType"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="ancestor::fpml:mandatoryEarlyTermination">
<xsl:if test="fpml:quotationRateType='fpml:ExercisingPartyPays'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** A quotationRateType value of 'ExercisingPartyPays' is not allowed for a mandatory early termination.</text></error>
</xsl:if>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:settlementRateSource">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:informationSource">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:cashSettlementReferenceBanks">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:informationSource">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidInformationProvider">
<xsl:with-param name="elementName">rateSource</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:rateSource"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:rateSourcePage">
<xsl:if test="fpml:rateSourcePage=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** rateSourcePage is empty.</text></error>
</xsl:if>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:cashSettlementPaymentDate">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:relativeDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:adjustableDates">
<xsl:if test="../../fpml:americanExercise">
<error><context><xsl:value-of select="$newContext"/></context><text>*** adjustableDates must only be present if European or Bermuda exercise.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="fpml:businessDateRange">
<xsl:if test="not(../../fpml:americanExercise)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** businessDateRange must only be present if American exercise.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:adjustableDates">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:businessDateRange">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>

<xsl:template match="fpml:adjustableDate">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">unadjustedDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:unadjustedDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:dateAdjustments">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>



<xsl:template match="fpml:adjustableDates">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="../../../fpml:europeanExercise">
<xsl:if test="count(fpml:unadjustedDate)!=1">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of unadjustedDate child elements encountered for European exercise. Exactly 1 expected.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="ancestor::fpml:optionalEarlyTermination">
<xsl:variable name="unadjustedDate"><xsl:value-of select="fpml:unadjustedDate[position()=last()]"/></xsl:variable>
<xsl:variable name="terminationDate"><xsl:value-of select="//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodDates/fpml:terminationDate/fpml:unadjustedDate"/></xsl:variable>
<xsl:variable name="unadjDate"><xsl:value-of select="number(concat(substring($unadjustedDate,1,4),substring($unadjustedDate,6,2),substring($unadjustedDate,9,2)))"/></xsl:variable>
<xsl:variable name="termDate"><xsl:value-of select="number(concat(substring($terminationDate,1,4),substring($terminationDate,6,2),substring($terminationDate,9,2)))"/></xsl:variable>
<xsl:if test="$unadjDate &gt; $termDate">
<error><context><xsl:value-of select="$newContext"/></context><text>*** The last unadjustedDate child element is greater than the swap floating leg terminationDate. Value = '<xsl:value-of select="$unadjustedDate"/>' Value = '<xsl:value-of select="$terminationDate"/>' </text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:unadjustedDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="ancestor::fpml:optionalEarlyTermination">
<xsl:variable name="businessDayConvention1"><xsl:value-of select="fpml:dateAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:choose>
<xsl:when test="//fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swEarlyTerminationProvision[fpml:swBreakCalculationMethod='ISDA Standard Method']">
<xsl:if test="$businessDayConvention1!='FOLLOWING'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** dateAdjustments/fpml:businessDayConvention must equal 'FOLLOWING' when /SWDML/swLongFormTrade/swStructuredTradeDetails/fpml:swExtendedTradeDetails/swEarlyTerminationProvision/swBreakCalculationMethod is equal to 'ISDA Standard Method'. Value = '<xsl:value-of select="$businessDayConvention1"/>'</text></error>
</xsl:if>
</xsl:when>
<xsl:otherwise>
<xsl:variable name="businessDayConvention2"><xsl:value-of select="//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="$businessDayConvention1!=$businessDayConvention2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** dateAdjustments/businessDayConvention must be the same as the swap floating stream paymentDates/paymentDatesAdjustments/businessDayConvention. Value = '<xsl:value-of select="$businessDayConvention1"/>' and '<xsl:value-of select="$businessDayConvention2"/>'</text></error>
</xsl:if>
</xsl:otherwise>
</xsl:choose>
</xsl:if>


<xsl:if test="ancestor::fpml:optionalEarlyTermination">
<xsl:variable name="businessCenters1">
<xsl:for-each select="fpml:dateAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:variable name="businessCenters2">
<xsl:for-each select="//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:if test="$businessCenters1!=$businessCenters2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** dateAdjustments/businessCenters must be the same as the swap floating stream paymentDates/paymentDatesAdjustments/businessCenters. Value = '<xsl:value-of select="$businessCenters1"/>' and '<xsl:value-of select="$businessCenters2"/>'</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:dateAdjustments">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:unadjustedDate">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>



<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">unadjustedDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="."/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:template>


<xsl:template match="fpml:businessDateRange">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">unadjustedFirstDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:unadjustedFirstDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">unadjustedLastDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:unadjustedLastDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="ancestor::fpml:optionalEarlyTermination">
<xsl:variable name="unadjustedLastDate"><xsl:value-of select="fpml:unadjustedLastDate"/></xsl:variable>
<xsl:variable name="terminationDate"><xsl:value-of select="//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:calculationPeriodDates/fpml:terminationDate/fpml:unadjustedDate"/></xsl:variable>
<xsl:if test="$unadjustedLastDate!=$terminationDate">
<error><context><xsl:value-of select="$newContext"/></context><text>*** unadjustedLastDate does not match the swap floating stream calculationPeriodDates/terminationDate/unadjustedDate.</text></error>
</xsl:if>
</xsl:if>


<xsl:variable name="businessDayConvention"><xsl:value-of select="fpml:businessDayConvention"/></xsl:variable>
<xsl:call-template name="isValidBusinessDayConvention">
<xsl:with-param name="elementName">businessDayConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$businessDayConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:businessCentersReference">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected element businessCentersReference encountered.</text></error>
</xsl:if>


<xsl:if test="$businessDayConvention='NONE' and fpml:businessCenters">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected element businessCenters encountered when businessDayConvention = 'NONE'.</text></error>
</xsl:if>


<xsl:if test="$businessDayConvention!='NONE' and not(//fpml:businessCenters)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing businessCenters. Needed when businessDayConvention not equal to 'NONE'.</text></error>
</xsl:if>


<xsl:choose>
<xsl:when test="//fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swEarlyTerminationProvision/fpml:swBreakCalculationMethod='ISDA Standard Method'">
<xsl:if test="$businessDayConvention!='FOLLOWING'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** dateAdjustments/businessDayConvention must equal 'FOLLOWING' when /fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/swEarlyTerminationProvision/swBreakCalculationMethod is equal to 'ISDA Standard Method'. Value = '<xsl:value-of select="$businessDayConvention"/>'</text></error>
</xsl:if>
</xsl:when>
<xsl:otherwise>
<xsl:variable name="businessDayConvention2"><xsl:value-of select="//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessDayConvention"/></xsl:variable>
<xsl:if test="$businessDayConvention!=$businessDayConvention2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** dateAdjustments/fpml:businessDayConvention must be the same as the swap floating stream paymentDates/paymentDatesAdjustments/businessDayConvention. Value = '<xsl:value-of select="$businessDayConvention"/>' and '<xsl:value-of select="$businessDayConvention2"/>'</text></error>
</xsl:if>
</xsl:otherwise>
</xsl:choose>


<xsl:variable name="businessCenters1">
<xsl:for-each select="fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:variable name="businessCenters2">
<xsl:for-each select="//fpml:FpML/fpml:trade//fpml:swap/fpml:swapStream[position()=$floatingLeg]/fpml:paymentDates/fpml:paymentDatesAdjustments/fpml:businessCenters/fpml:businessCenter">
<xsl:sort select="."/>
<xsl:value-of select="."/>
</xsl:for-each>
</xsl:variable>
<xsl:if test="$businessCenters1!=$businessCenters2">
<error><context><xsl:value-of select="$newContext"/></context><text>*** businessCenters must be the same as floating stream paymentDates/paymentDatesAdjustments/businessCenters. Value = '<xsl:value-of select="$businessCenters1"/>' and '<xsl:value-of select="$businessCenters2"/>'</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:businessCenters">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:optionalEarlyTermination">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:singlePartyOption">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:europeanExercise and fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swEarlyTerminationProvision/fpml:swBreakFrequency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected /SWDML/swLongFormTrade/swStructuredTradeDetails/fpml:swExtendedTradeDetails/swEarlyTerminationProvision/swBreakFrequency element encountered. Element not allowed for european style optional early termination.</text></error>
</xsl:if>


<xsl:if test="fpml:americanExercise">
<xsl:variable name="breakFrequency">
<xsl:value-of select="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swEarlyTerminationProvision/fpml:swBreakFrequency/fpml:periodMultiplier"/>
<xsl:value-of select="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swEarlyTerminationProvision/fpml:swBreakFrequency/fpml:period"/>
</xsl:variable>
<xsl:if test="not($breakFrequency = '1D')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** /SWDML/swLongFormTrade/swStructuredTradeDetails/swExtendedTradeDetails/swEarlyTerminationProvision/swBreakFrequency element must be equal to 1D for american style optional early termination. Value = '<xsl:value-of select="$breakFrequency"/>'.</text></error>
</xsl:if>
</xsl:if>



<xsl:if test="fpml:bermudaExercise">
<xsl:variable name="breakFrequency">
<xsl:value-of select="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swEarlyTerminationProvision/fpml:swBreakFrequency/fpml:periodMultiplier"/>
<xsl:value-of select="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swEarlyTerminationProvision/fpml:swBreakFrequency/fpml:period"/>
</xsl:variable>
<xsl:if test="not(/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails/fpml:swExtendedTradeDetails/fpml:swEarlyTerminationProvision/fpml:swBreakFrequency)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing /SWDML/swLongFormTrade/swStructuredTradeDetails/swExtendedTradeDetails/swEarlyTerminationProvision/swBreakFrequency element. Required for bermuda style optional early termination.</text></error>
</xsl:if>
<xsl:if test="$breakFrequency = '1D'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** /fpml:SWDML/swLongFormTrade/swStructuredTradeDetails/swExtendedTradeDetails/swEarlyTerminationProvision/swBreakFrequency element must not be equal to 1D for bermuda style optional early termination.</text></error>
</xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:europeanExercise">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:bermudaExercise">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:americanExercise">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:calculationAgent">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:cashSettlement">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:singlePartyOption">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="href1"><xsl:value-of select="fpml:buyerPartyReference/@href"/></xsl:variable>
<xsl:variable name="href2"><xsl:value-of select="fpml:sellerPartyReference/@href"/></xsl:variable>
<xsl:if test="$href1=$href2">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href and sellerPartyReference/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$href1])">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$href1"/>'.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$href2])">
<error><context><xsl:value-of select="$newContext"/></context><text>***sellerPartyReference/@href does not reference a valid //fpml:FpML/trade/party/@id. Value = '<xsl:value-of select="$href2"/>'.</text></error>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:europeanExercise">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="fpml:earliestExerciseTime/fpml:businessCenter != fpml:expirationTime/fpml:businessCenter">
<error><context><xsl:value-of select="$newContext"/></context><text>*** earliestExerciseTime/businessCenter must equal expirationTime/businessCenter.</text></error>
</xsl:if>


<xsl:if test="../fpml:cashSettlement/fpml:cashSettlementValuationTime/fpml:businessCenter != fpml:expirationTime/fpml:businessCenter">
<error><context><xsl:value-of select="$newContext"/></context><text>*** ../fpml:cashSettlement/fpml:cashSettlementValuationTime/businessCenter must equal expirationTime/businessCenter.</text></error>
</xsl:if>


<xsl:variable name="earliest">
<xsl:value-of select="concat(substring(fpml:earliestExerciseTime/fpml:hourMinuteTime,1,2),substring(fpml:earliestExerciseTime/fpml:hourMinuteTime,4,2),substring(fpml:earliestExerciseTime/fpml:hourMinuteTime,7,2))"/>
</xsl:variable>
<xsl:variable name="expiration">
<xsl:value-of select="concat(substring(fpml:expirationTime/fpml:hourMinuteTime,1,2),substring(fpml:expirationTime/fpml:hourMinuteTime,4,2),substring(fpml:expirationTime/fpml:hourMinuteTime,7,2))"/>
</xsl:variable>
<xsl:if test="not($earliest &lt; $expiration)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** earliestExerciseTime/hourMinuteTime (<xsl:value-of select="fpml:earliestExerciseTime/hourMinuteTime"/>) must be less than expirationTime/hourMinuteTime (<xsl:value-of select="fpml:expirationTime/hourMinuteTime"/>).</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:expirationDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:earliestExerciseTime">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:expirationTime">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:expirationDate|fpml:commencementDate">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:relativeDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:adjustableDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:bermudaExerciseDates">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:relativeDates">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:bermudaExercise">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="fpml:earliestExerciseTime/fpml:businessCenter != fpml:expirationTime/fpml:businessCenter">
<error><context><xsl:value-of select="$newContext"/></context><text>*** earliestExerciseTime/fpml:businessCenter must equal expirationTime/fpml:businessCenter.</text></error>
</xsl:if>


<xsl:variable name="earliest">
<xsl:value-of select="concat(substring(fpml:earliestExerciseTime/fpml:hourMinuteTime,1,2),substring(fpml:earliestExerciseTime/fpml:hourMinuteTime,4,2),substring(fpml:earliestExerciseTime/fpml:hourMinuteTime,7,2))"/>
</xsl:variable>
<xsl:variable name="expiration">
<xsl:value-of select="concat(substring(fpml:expirationTime/fpml:hourMinuteTime,1,2),substring(fpml:expirationTime/fpml:hourMinuteTime,4,2),substring(fpml:expirationTime/fpml:hourMinuteTime,7,2))"/>
</xsl:variable>
<xsl:if test="not($earliest &lt; $expiration)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** earliestExerciseTime/hourMinuteTime (<xsl:value-of select="fpml:earliestExerciseTime/fpml:hourMinuteTime"/>) must be less than expirationTime/hourMinuteTime (<xsl:value-of select="fpml:expirationTime/fpml:hourMinuteTime"/>).</text></error>
</xsl:if>


<xsl:if test="fpml:latestExerciseTime and not(//fpml:latestExerciseTime/fpml:businessCenter = fpml:expirationTime/fpml:businessCenter)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** latestExerciseTime/fpml:businessCenter must equal expirationTime/businessCenter.</text></error>
</xsl:if>


<xsl:if test="fpml:latestExerciseTime and not(//fpml:latestExerciseTime/fpml:hourMinuteTime = fpml:expirationTime/fpml:hourMinuteTime)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** latestExerciseTime/hourMinuteTime must equal expirationTime/hourMinuteTime.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:bermudaExerciseDates">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:earliestExerciseTime">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:latestExerciseTime">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:expirationTime">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:americanExercise">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="fpml:earliestExerciseTime/fpml:businessCenter != fpml:expirationTime/fpml:businessCenter">
<error><context><xsl:value-of select="$newContext"/></context><text>*** earliestExerciseTime/businessCenter must equal expirationTime/businessCenter.</text></error>
</xsl:if>


<xsl:variable name="earliest">
<xsl:value-of select="concat(substring(fpml:earliestExerciseTime/fpml:hourMinuteTime,1,2),substring(fpml:earliestExerciseTime/fpml:hourMinuteTime,4,2),substring(fpml:earliestExerciseTime/fpml:hourMinuteTime,7,2))"/>
</xsl:variable>
<xsl:variable name="expiration">
<xsl:value-of select="concat(substring(fpml:expirationTime/fpml:hourMinuteTime,1,2),substring(fpml:expirationTime/fpml:hourMinuteTime,4,2),substring(fpml:expirationTime/fpml:hourMinuteTime,7,2))"/>
</xsl:variable>
<xsl:if test="not($earliest &lt; $expiration)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** earliestExerciseTime/hourMinuteTime (<xsl:value-of select="fpml:earliestExerciseTime/hourMinuteTime"/>) must be less than expirationTime/hourMinuteTime (<xsl:value-of select="fpml:expirationTime/fpml:hourMinuteTime"/>).</text></error>
</xsl:if>


<xsl:if test="fpml:latestExerciseTime and not(//fpml:latestExerciseTime/fpml:businessCenter = fpml:expirationTime/fpml:businessCenter)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** latestExerciseTime/fpml:businessCenter must equal expirationTime/fpml:businessCenter.</text></error>
</xsl:if>


<xsl:if test="fpml:latestExerciseTime and not(//fpml:latestExerciseTime/fpml:hourMinuteTime = fpml:expirationTime/fpml:hourMinuteTime)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** latestExerciseTime/hourMinuteTime must equal expirationTime/hourMinuteTime.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:commencementDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:expirationDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:earliestExerciseTime">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:latestExerciseTime">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:expirationTime">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:cashSettlementReferenceBanks">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="count(fpml:referenceBank) &gt; 5">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of referenceBank child elements encountered. 1 to 5 expected.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:referenceBank">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:referenceBank">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>



<xsl:variable name="referenceBankId"><xsl:value-of select="fpml:referenceBankId"/></xsl:variable>
<xsl:if test="$referenceBankId=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Empty referenceBankId.</text></error>
</xsl:if>


<xsl:if test="fpml:referenceBankName">
<xsl:variable name="referenceBankName"><xsl:value-of select="fpml:referenceBankName"/></xsl:variable>
<xsl:if test="$referenceBankName=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Empty referenceBankName.</text></error>
</xsl:if>
</xsl:if>

</xsl:template>



<xsl:template match="fpml:fra">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="not($productType='FRA')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** /SWDML/swLongFormTrade/swStructuredTradeDetails/productType must be equal to 'FRA' if fra element is present.</text></error>
</xsl:if>


<xsl:variable name="href1">
<xsl:value-of select="fpml:buyerPartyReference/@href"/>
</xsl:variable>
<xsl:variable name="href2">
<xsl:value-of select="fpml:sellerPartyReference/@href"/>
</xsl:variable>
<xsl:if test="$href1=$href2">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href and sellerPartyReference/@href values must not be the same.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$href1])">
<error><context><xsl:value-of select="$newContext"/></context><text>***buyerPartyReference/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$href1"/>'.</text></error>
</xsl:if>


<xsl:if test="not(//fpml:FpML/fpml:party[@id=$href2])">
<error><context><xsl:value-of select="$newContext"/></context><text>***sellerPartyReference/@href does not reference a valid /FpML/trade/party/@id. Value = '<xsl:value-of select="$href2"/>'.</text></error>
</xsl:if>


<xsl:variable name="id">
<xsl:value-of select="fpml:adjustedEffectiveDate/@id"/>
</xsl:variable>
<xsl:if test="$id = ''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or empty adjustedEffectiveDate/@id value.</text></error>
</xsl:if>


<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">adjustedEffectiveDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:adjustedEffectiveDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">adjustedTerminationDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:adjustedTerminationDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:paymentDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

<xsl:apply-templates select="fpml:fixingDateOffset">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:call-template name="isValidDayCountFraction">
<xsl:with-param name="elementName">dayCountFraction</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:dayCountFraction"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="calculationPeriodNumberOfDays"><xsl:value-of select="fpml:calculationPeriodNumberOfDays"/></xsl:variable>
<xsl:call-template name="isValidIntegerNumber">
<xsl:with-param name="elementName">calculationPeriodNumberOfDays</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$calculationPeriodNumberOfDays"/></xsl:with-param>
<xsl:with-param name="minIncl">1</xsl:with-param>
<xsl:with-param name="maxIncl">99999</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:notional">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:variable name="floatingRateIndex"><xsl:value-of select="fpml:floatingRateIndex"/></xsl:variable>
<xsl:if test="$floatingRateIndex=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Empty or missing floatingRateIndex.</text></error>
</xsl:if>


<xsl:if test="$tradeCurrency != 'PLN'">
<xsl:variable name="floatingRateIndexCurrency"><xsl:value-of select="substring($floatingRateIndex,1,3)"/></xsl:variable>
<xsl:if test="$tradeCurrency != $floatingRateIndexCurrency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** floatingRateIndex value of '<xsl:value-of select="$floatingRateIndex"/>' is not valid for trade currency of '<xsl:value-of select="$tradeCurrency"/>'.</text></error>
</xsl:if>
</xsl:if>


<xsl:variable name="fixedRate"><xsl:value-of select="fpml:fixedRate"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">fixedRate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$fixedRate"/></xsl:with-param>
<xsl:with-param name="minIncl">0</xsl:with-param>
<xsl:with-param name="maxIncl">9.99999999</xsl:with-param>
<xsl:with-param name="maxDecs">8</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="not(count(fpml:indexTenor)=1 or count(fpml:indexTenor)=2)"><error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of indexTenor child elements encountered. Exactly 1 or 2 expected.</text></error></xsl:if>

<xsl:apply-templates select="fpml:indexTenor">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:call-template name="isValidFRADiscounting">
<xsl:with-param name="elementName">fraDiscounting</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:fraDiscounting"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:template>


<xsl:template match="fpml:paymentDate">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">unadjustedDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:unadjustedDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="fpml:dateAdjustments">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:variable name="businessDayConvention">
<xsl:value-of select="fpml:dateAdjustments/fpml:businessDayConvention"/>
</xsl:variable>
<xsl:if test="$businessDayConvention='NONE'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** dateAdjustments/fpml:businessDayConvention must not equal 'NONE' in this context.</text></error>
</xsl:if>
</xsl:template>


<xsl:template match="fpml:dateAdjustments">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="businessDayConvention"><xsl:value-of select="fpml:businessDayConvention"/></xsl:variable>
<xsl:call-template name="isValidBusinessDayConvention">
<xsl:with-param name="elementName">businessDayConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$businessDayConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:businessCentersReference"><error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected element businessCentersReference encountered.</text></error></xsl:if>


<xsl:if test="$businessDayConvention='NONE'">
<xsl:if test="fpml:businessCenters"><error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected element businessCenters encountered when businessDayConvention = 'NONE'.</text></error></xsl:if>
</xsl:if>


<xsl:if test="$businessDayConvention!='NONE'">
<xsl:if test="not(//fpml:businessCenters)"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing businessCenters. Needed when businessDayConvention not equal to 'NONE'.</text></error></xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:businessCenters">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:businessCenters">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:businessCenter">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:businessCenter">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>



<xsl:call-template name="isValidBusinessCenter">
<xsl:with-param name="elementName">businessCenter</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="."/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:template>


<xsl:template match="fpml:fixingDateOffset">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="periodMultiplier"><xsl:value-of select="fpml:periodMultiplier"/></xsl:variable>
<xsl:call-template name="isValidIntegerNumber">
<xsl:with-param name="elementName">periodMultiplier</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$periodMultiplier"/></xsl:with-param>
<xsl:with-param name="minIncl">-99</xsl:with-param>
<xsl:with-param name="maxIncl">0</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="period"><xsl:value-of select="fpml:period"/></xsl:variable>
<xsl:if test="$period!='D'"><error><context><xsl:value-of select="$newContext"/></context><text>*** period must be equal to 'D' in this context. Value = '<xsl:value-of select="$period"/>'</text></error></xsl:if>



<xsl:if test="$periodMultiplier='0' and $period='D'">
<xsl:if test="fpml:dayType"><error><context><xsl:value-of select="$newContext"/></context><text>*** dayType should not be present if periodMultiplier is '0' and period is 'D'.</text></error></xsl:if>
<xsl:if test="not(//fpml:businessDayConvention='PRECEDING')"><error><context><xsl:value-of select="$newContext"/></context><text>*** businessDayConvention must equal 'PRECEDING' if periodMultiplier is '0' and period is 'D'. Value = '<xsl:value-of select="fpml:businessDayConvention"/>'.</text></error></xsl:if>
</xsl:if>


<xsl:variable name="dayType"><xsl:value-of select="fpml:dayType"/></xsl:variable>
<xsl:if test="$periodMultiplier!='0' and $period='D' and $dayType='Business'">
<xsl:if test="not(//fpml:businessDayConvention='NONE')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** businessDayConvention must equal 'NONE' if period is equal to 'D' and periodMultiplier is not equal to '0' and dayType is equal to 'Business'. Value = '<xsl:value-of select="fpml:businessDayConvention"/>'.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="not($periodMultiplier='0' and $period='D')">
<xsl:call-template name="isValidDayType">
<xsl:with-param name="elementName">dayType</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:dayType"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:variable name="businessDayConvention"><xsl:value-of select="fpml:businessDayConvention"/></xsl:variable>
<xsl:call-template name="isValidBusinessDayConvention">
<xsl:with-param name="elementName">businessDayConvention</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$businessDayConvention"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:businessCentersReference"><error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected element businessCentersReference encountered.</text></error></xsl:if>


<xsl:if test="$businessDayConvention!='NONE'">
<xsl:if test="not(//fpml:businessCenters)"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing businessCenters. Needed when businessDayConvention not equal to 'NONE'.</text></error></xsl:if>
</xsl:if>


<xsl:if test="$dayType='Business'">
<xsl:if test="not(//fpml:businessCenters)"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing businessCenters. Needed when dayType is equal to 'Business'.</text></error></xsl:if>
</xsl:if>

<xsl:apply-templates select="fpml:businessCenters">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:variable name="href"><xsl:value-of select="fpml:dateRelativeTo/@href"/></xsl:variable>
<xsl:variable name="id"><xsl:value-of select="../fpml:adjustedEffectiveDate/@id"/></xsl:variable>
<xsl:if test="$href!=$id"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid dateRelativeTo/@href value. Value is not equal to ../adjustedEffectiveDate/@id. Value of href = '<xsl:value-of select="$href"/>' and id = '<xsl:value-of select="$id"/>'.</text></error></xsl:if>


<xsl:if test="$href!='resetDate'"><error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or invalid dateRelativeTo value. Value = '<xsl:value-of select="$href"/>'.</text></error></xsl:if>

</xsl:template>


<xsl:template match="fpml:notional">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidCurrency">
<xsl:with-param name="elementName">currency</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:currency"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="amount"><xsl:value-of select="fpml:amount"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">amount</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$amount"/></xsl:with-param>
<xsl:with-param name="minIncl">0.01</xsl:with-param>
<xsl:with-param name="maxIncl">999999999999.99</xsl:with-param>
<xsl:with-param name="maxDecs">2</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:template>


<xsl:template match="fpml:swSwapTermTenor">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="period"><xsl:value-of select="fpml:period"/></xsl:variable>
<xsl:if test="not($period='W' or $period='M' or $period='Y')"><error><context><xsl:value-of select="$newContext"/></context><text>*** period must be equal to 'W', 'M' or 'Y'. Value = '<xsl:value-of select="$period"/>'</text></error></xsl:if>


<xsl:if test="$period='W'">
<xsl:if test="not($productType='OIS')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** period can only be in expressed in weeks (W) if product type is 'OIS'.</text></error>
</xsl:if>
</xsl:if>


<xsl:call-template name="isValidperiodMultiplier">
<xsl:with-param name="elementName">periodMultiplier</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:periodMultiplier"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="periodMultiplier"><xsl:value-of select="fpml:periodMultiplier"/></xsl:variable>
<xsl:if test="$period='W' and ($periodMultiplier &lt; 1 or $periodMultiplier &gt; 3)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** periodMultiplier must be in the range 1 to 3 in this context if period is equal to 'W'. Value = '<xsl:value-of select="$periodMultiplier"/>'</text></error>
</xsl:if>


<xsl:if test="$period='M' and ($periodMultiplier &lt; 1 or $periodMultiplier &gt; 11999)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** periodMultiplier must be in the range 1 to 11999 in this context if period is equal to 'M'. Value = '<xsl:value-of select="$periodMultiplier"/>'</text></error>
</xsl:if>


<xsl:if test="$period='Y' and ($periodMultiplier &lt; 1 or $periodMultiplier &gt; 999)">
<error><context><xsl:value-of select="$newContext"/></context><text>*** periodMultiplier must be in the range 1 to 999 in this context if period is equal to 'Y'. Value = '<xsl:value-of select="$periodMultiplier"/>'</text></error>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:swEffectiveDateTenor">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="period"><xsl:value-of select="fpml:period"/></xsl:variable>
<xsl:if test="not($period='M')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** period must be equal to 'M' in this context. Value = '<xsl:value-of select="$period"/>'</text></error>
</xsl:if>


<xsl:call-template name="isValidperiodMultiplier">
<xsl:with-param name="elementName">periodMultiplier</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:periodMultiplier"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="periodMultiplier"><xsl:value-of select="fpml:periodMultiplier"/></xsl:variable>
<xsl:if test="$periodMultiplier &lt; 0 or $periodMultiplier &gt; 99">
<error><context><xsl:value-of select="$newContext"/></context><text>*** periodMultiplier must be in the range 0 to 99 in this context. Value = '<xsl:value-of select="$periodMultiplier"/>'</text></error>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:swTerminationDateTenor">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="period"><xsl:value-of select="fpml:period"/></xsl:variable>
<xsl:if test="not($period='M')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** period must be equal to 'M' in this context. Value = '<xsl:value-of select="$period"/>'</text></error>
</xsl:if>


<xsl:call-template name="isValidperiodMultiplier">
<xsl:with-param name="elementName">periodMultiplier</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:periodMultiplier"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="periodMultiplier"><xsl:value-of select="fpml:periodMultiplier"/></xsl:variable>
<xsl:if test="$periodMultiplier &lt; 0 or $periodMultiplier &gt; 99">
<error><context><xsl:value-of select="$newContext"/></context><text>*** periodMultiplier must be in the range 0 to 99 in this context. Value = '<xsl:value-of select="$periodMultiplier"/>'</text></error>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:party">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>



<xsl:variable name="partyId"><xsl:value-of select="fpml:partyId"/></xsl:variable>
<xsl:if test="$partyId=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or empty partyId.</text></error>
</xsl:if>


<xsl:variable name="id"><xsl:value-of select="@id"/></xsl:variable>
<xsl:if test="$id=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Missing or empty @id.</text></error>
</xsl:if>


<xsl:variable name="partyName"><xsl:value-of select="fpml:partyName"/></xsl:variable>
<xsl:if test="partyName">
<xsl:if test="$partyName=''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Empty partyName.</text></error>
</xsl:if>
</xsl:if>

</xsl:template>


<xsl:template match="fpml:swEarlyTerminationProvision">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>


<xsl:apply-templates select="fpml:swBreakFirstDate">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:if test="fpml:swBreakOverrideFirstDate">
<xsl:call-template name="isValidDate">
<xsl:with-param name="elementName">swBreakOverrideFirstDate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swBreakOverrideFirstDate"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:earlyTerminationProvision/fpml:mandatoryEarlyTermination/fpml:mandatoryEarlyTerminationDate/fpml:unadjustedDate">
<xsl:variable name="overrideFirstDate"><xsl:value-of select="fpml:swBreakOverrideFirstDate"/></xsl:variable>
<xsl:variable name="firstDate"><xsl:value-of select="fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:earlyTerminationProvision/fpml:mandatoryEarlyTermination/fpml:mandatoryEarlyTerminationDate/fpml:unadjustedDate"/></xsl:variable>
<xsl:choose>
<xsl:when test="$overrideFirstDate=$firstDate"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** For a mandatory early termination swBreakOverrideFirstDate whose value = '<xsl:value-of select="$overrideFirstDate"/>', must be equal to fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:earlyTerminationProvision/fpml:mandatoryEarlyTermination/fpml:mandatoryEarlyTerminationDate/fpml:unadjustedDate. Value = '<xsl:value-of select="$firstDate"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>


<xsl:if test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:earlyTerminationProvision/fpml:optionalEarlyTermination/fpml:cashSettlement/fpml:cashSettlementPaymentDate/fpml:adjustableDates/fpml:unadjustedDate[1]">
<xsl:variable name="overrideFirstDate"><xsl:value-of select="fpml:swBreakOverrideFirstDate"/></xsl:variable>
<xsl:variable name="firstDate"><xsl:value-of select="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:earlyTerminationProvision/fpml:optionalEarlyTermination/fpml:cashSettlement/fpml:cashSettlementPaymentDate/fpml:adjustableDates/fpml:unadjustedDate[1]"/></xsl:variable>
<xsl:choose>
<xsl:when test="$overrideFirstDate=$firstDate"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** For a Bermudan or European style optional early termination swBreakOverrideFirstDate whose value = '<xsl:value-of select="$overrideFirstDate"/>',  must be equal to /fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:earlyTerminationProvision/fpml:optionalEarlyTermination/fpml:cashSettlement/fpml:cashSettlementPaymentDate/fpml:adjustableDates/fpml:unadjustedDate[1]. Value = '<xsl:value-of select="$firstDate"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>


<xsl:if test="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:earlyTerminationProvision/fpml:optionalEarlyTermination/fpml:cashSettlement/fpml:cashSettlementPaymentDate/fpml:businessDateRange/fpml:unadjustedFirstDate">
<xsl:variable name="overrideFirstDate"><xsl:value-of select="fpml:swBreakOverrideFirstDate"/></xsl:variable>
<xsl:variable name="firstDate"><xsl:value-of select="/fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:earlyTerminationProvision/fpml:optionalEarlyTermination/fpml:cashSettlement/fpml:cashSettlementPaymentDate/fpml:businessDateRange/fpml:unadjustedFirstDate"/></xsl:variable>
<xsl:choose>
<xsl:when test="$overrideFirstDate=$firstDate"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** For an American style optional early termination swBreakOverrideFirstDate whose value = '<xsl:value-of select="$overrideFirstDate"/>',  must be equal to /fpml:SWDML/fpml:swLongFormTrade/fpml:swStructuredTradeDetails//fpml:FpML/fpml:trade//fpml:swap/fpml:earlyTerminationProvision/fpml:optionalEarlyTermination/fpml:cashSettlement/fpml:cashSettlementPaymentDate/fpml:businessDateRange/fpml:unadjustedFirstDate. Value = '<xsl:value-of select="$firstDate"/>'.</text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

</xsl:if>


<xsl:apply-templates select="fpml:swBreakFrequency">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>


<xsl:call-template name="isValidBreakCalculationMethod">
<xsl:with-param name="elementName">swBreakCalculationMethod</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swBreakCalculationMethod"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:template>


<xsl:template match="fpml:swBreakFirstDate">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="freq"><xsl:value-of select="fpml:periodMultiplier"/><xsl:value-of select="fpml:period"/></xsl:variable>
<xsl:choose>
<xsl:when test="$freq='1D'"/>
<xsl:when test="$freq='1Y'"/>
<xsl:when test="$freq='2Y'"/>
<xsl:when test="$freq='3Y'"/>
<xsl:when test="$freq='4Y'"/>
<xsl:when test="$freq='5Y'"/>
<xsl:when test="$freq='6Y'"/>
<xsl:when test="$freq='7Y'"/>
<xsl:when test="$freq='8Y'"/>
<xsl:when test="$freq='9Y'"/>
<xsl:when test="$freq='10Y'"/>
<xsl:when test="$freq='12Y'"/>
<xsl:when test="$freq='15Y'"/>
<xsl:when test="$freq='20Y'"/>
<xsl:when test="$freq='25Y'"/>
<xsl:when test="$freq='30Y'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** swBreakFirstDate must be equal to 1D, 1Y, 2Y, 3Y, 4Y, 5Y, 6Y, 7Y, 8Y, 9Y, 10Y, 12Y, 15Y, 20Y, 25Y and 30Y. Value = '<xsl:value-of select="$freq"/>'.</text></error></xsl:otherwise>
</xsl:choose>

</xsl:template>


<xsl:template match="fpml:swBreakFrequency">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="freq"><xsl:value-of select="fpml:periodMultiplier"/><xsl:value-of select="fpml:period"/></xsl:variable>
<xsl:choose>
<xsl:when test="$freq='1D'"/>
<xsl:when test="$freq='6M'"/>
<xsl:when test="$freq='1Y'"/>
<xsl:when test="$freq='2Y'"/>
<xsl:when test="$freq='3Y'"/>
<xsl:when test="$freq='4Y'"/>
<xsl:when test="$freq='5Y'"/>
<xsl:when test="$freq='6Y'"/>
<xsl:when test="$freq='7Y'"/>
<xsl:when test="$freq='8Y'"/>
<xsl:when test="$freq='9Y'"/>
<xsl:when test="$freq='10Y'"/>
<xsl:otherwise><error><context><xsl:value-of select="$newContext"/></context><text>*** swBreakFrequency must be equal to 1D, 6M, 1Y, 2Y, 3Y, 4Y, 5Y, 6Y, 7Y, 8Y, 9Y or 10Y. Value = '<xsl:value-of select="$freq"/>'.</text></error></xsl:otherwise>
</xsl:choose>

</xsl:template>

<xsl:template match="fpml:swSettlementProvision">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:variable name="swSettlementCurrency"><xsl:value-of select="fpml:swSettlementCurrency"/></xsl:variable>
<xsl:if test="not(//fpml:swSettlementCurrency = 'USD')">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swSettlementCurrency must be equal to 'USD'. Value = '<xsl:value-of select="swSettlementCurrency"/>'.</text></error>
</xsl:if>

<xsl:apply-templates select="fpml:swNonDeliverableSettlement">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>

<xsl:template match="fpml:swNonDeliverableSettlement">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:call-template name="isValidNonDeliverableCurrency">
<xsl:with-param name="elementName">swReferenceCurrency</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swReferenceCurrency"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:if test="$tradeCurrency != fpml:swReferenceCurrency">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swReferenceCurrency value of '<xsl:value-of select="fpml:swReferenceCurrency"/>' must equal Trade Currency of '<xsl:value-of select="$tradeCurrency"/>'.</text></error>
</xsl:if>
</xsl:template>

<xsl:template match="fpml:swAssociatedBonds">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/></xsl:variable>



<xsl:if test="fpml:swNegotiatedSpreadRate">
<xsl:variable name="swNegotiatedSpreadRate"><xsl:value-of select="fpml:swNegotiatedSpreadRate"/></xsl:variable>
<xsl:call-template name="isValidNumber">
<xsl:with-param name="elementName">swNegotiatedSpreadRate</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$swNegotiatedSpreadRate"/></xsl:with-param>
<xsl:with-param name="minIncl">-0.0999999</xsl:with-param>
<xsl:with-param name="maxIncl">0.0999999</xsl:with-param>
<xsl:with-param name="maxDecs">7</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:if test="count(fpml:swBondDetails) &gt; 2"><error><context><xsl:value-of select="$newContext"/></context><text>*** Unexpected number of swBondDetails child elements encountered. 0 to 2 expected.</text></error></xsl:if>

<xsl:apply-templates select="fpml:swBondDetails">
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:apply-templates>

</xsl:template>


<xsl:template match="fpml:swBondDetails">
<xsl:param name="context"/>
<xsl:variable name="newContext"><xsl:value-of select="$context"/>/<xsl:value-of select="local-name()"/>[<xsl:number value="position()"/>]</xsl:variable>



<xsl:if test="fpml:swBondId">
<xsl:call-template name="isValidBondId">
<xsl:with-param name="elementName">swBondId</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swBondId"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>


<xsl:variable name="swBondName"><xsl:value-of select="fpml:swBondName"/></xsl:variable>
<xsl:if test="$swBondName =''">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Empty swBondName.</text></error>
</xsl:if>


<xsl:if test="string-length($swBondName) &gt; 40">
<error><context><xsl:value-of select="$newContext"/></context><text>*** Invalid swBondName string length. Exceeded max length of 40 characters.</text></error>
</xsl:if>


<xsl:variable name="swBondFaceAmount"><xsl:value-of select="fpml:swBondFaceAmount"/></xsl:variable>
<xsl:call-template name="isValidIntegerNumber">
<xsl:with-param name="elementName">swBondFaceAmount</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$swBondFaceAmount"/></xsl:with-param>
<xsl:with-param name="minIncl">1</xsl:with-param>
<xsl:with-param name="maxIncl">999999999999</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:call-template name="isValidPriceType">
<xsl:with-param name="elementName">swPriceType</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="fpml:swPriceType"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>


<xsl:variable name="swPriceType"><xsl:value-of select="fpml:swPriceType"/></xsl:variable>
<xsl:if test="$tradeCurrency ='USD'">
<xsl:if test="$swPriceType !='F128'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swPriceType must be equal to 'F128' if trade currency is equal to 'USD'. Value = '<xsl:value-of select="$swPriceType"/>'.</text></error>
</xsl:if>
</xsl:if>


<xsl:if test="$tradeCurrency ='CAD'">
<xsl:if test="$swPriceType !='D5'">
<error><context><xsl:value-of select="$newContext"/></context><text>*** swPriceType must be equal to 'D5' if trade currency is equal to 'CAD'. Value = '<xsl:value-of select="$swPriceType"/>'.</text></error>
</xsl:if>
</xsl:if>


<xsl:variable name="swBondPrice"><xsl:value-of select="fpml:swBondPrice"/></xsl:variable>
<xsl:if test="$swPriceType='F128'">
<xsl:choose>
<xsl:when test="not($swBondPrice='')">
<xsl:choose>

<xsl:when test="contains($swBondPrice,'-')">

<xsl:call-template name="isValidIntegerNumber2">
<xsl:with-param name="elementName">swBondPrice</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="substring-before($swBondPrice,'-')"/></xsl:with-param>
<xsl:with-param name="minIncl">0</xsl:with-param>
<xsl:with-param name="maxIncl">999</xsl:with-param>
<xsl:with-param name="maxDigits">3</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:call-template name="isValid32nd">
<xsl:with-param name="elementName">swBondPrice</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="substring(substring-after($swBondPrice,'-'),1,2)"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

<xsl:call-template name="isValid128th">
<xsl:with-param name="elementName">swBondPrice</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="substring(substring-after($swBondPrice,'-'),3)"/></xsl:with-param>
<xsl:with-param name="testNumber"></xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>

</xsl:when>
<xsl:otherwise>
<error><context><xsl:value-of select="$newContext"/></context><text>*** If swBondPrice is equal to 'F128' swBondPrice must contain '-' fractional separator. Value = '<xsl:value-of select="$swBondPrice"/>'.</text></error>
</xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise>
<error><context><xsl:value-of select="$newContext"/></context><text>*** Empty swBondPrice.</text></error>
</xsl:otherwise>
</xsl:choose>
</xsl:if>


<xsl:if test="$swPriceType='D5'">
<xsl:call-template name="isValidNumber2">
<xsl:with-param name="elementName">swBondPrice</xsl:with-param>
<xsl:with-param name="elementValue"><xsl:value-of select="$swBondPrice"/></xsl:with-param>
<xsl:with-param name="minIncl">0</xsl:with-param>
<xsl:with-param name="maxIncl">999.99999</xsl:with-param>
<xsl:with-param name="maxDecs">5</xsl:with-param>
<xsl:with-param name="context"><xsl:value-of select="$newContext"/></xsl:with-param>
</xsl:call-template>
</xsl:if>

</xsl:template>


<xsl:template name="isValidBondId">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='USD.OTR.2Y'"/>
<xsl:when test="$elementValue='USD.OTR.3Y'"/>
<xsl:when test="$elementValue='USD.OTR.5Y'"/>
<xsl:when test="$elementValue='USD.OTR.10Y'"/>
<xsl:when test="$elementValue='USD.OTR.30Y'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidBoolean">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='true'"/>
<xsl:when test="$elementValue='false'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidBusinessCenter">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='BEBR'"/>
<xsl:when test="$elementValue='CHZU'"/>
<xsl:when test="$elementValue='CATO'"/>
<xsl:when test="$elementValue='DKCO'"/>
<xsl:when test="$elementValue='EUTA'"/>
<xsl:when test="$elementValue='FRPA'"/>
<xsl:when test="$elementValue='GBLO'"/>
<xsl:when test="$elementValue='JPTO'"/>
<xsl:when test="$elementValue='NOOS'"/>
<xsl:when test="$elementValue='SEST'"/>
<xsl:when test="$elementValue='USNY'"/>

<xsl:when test="$elementValue='ARBA'"/>
<xsl:when test="$elementValue='ATVI'"/>
<xsl:when test="$elementValue='AUME'"/>
<xsl:when test="$elementValue='AUSY'"/>
<xsl:when test="$elementValue='BRSP'"/>
<xsl:when test="$elementValue='CAMO'"/>
<xsl:when test="$elementValue='CHGE'"/>
<xsl:when test="$elementValue='CLSA'"/>
<xsl:when test="$elementValue='CNBE'"/>
<xsl:when test="$elementValue='CZPR'"/>
<xsl:when test="$elementValue='DEFR'"/>
<xsl:when test="$elementValue='EETA'"/>
<xsl:when test="$elementValue='ESMA'"/>
<xsl:when test="$elementValue='FIHE'"/>
<xsl:when test="$elementValue='GRAT'"/>
<xsl:when test="$elementValue='HKHK'"/>
<xsl:when test="$elementValue='HUBU'"/>
<xsl:when test="$elementValue='IDJA'"/>
<xsl:when test="$elementValue='IEDU'"/>
<xsl:when test="$elementValue='ILTA'"/>
<xsl:when test="$elementValue='INMU'"/>
<xsl:when test="$elementValue='ITMI'"/>
<xsl:when test="$elementValue='ITRO'"/>
<xsl:when test="$elementValue='KRSE'"/>
<xsl:when test="$elementValue='LBBE'"/>
<xsl:when test="$elementValue='LULU'"/>
<xsl:when test="$elementValue='MXMC'"/>
<xsl:when test="$elementValue='MYKL'"/>
<xsl:when test="$elementValue='NLAM'"/>
<xsl:when test="$elementValue='NYFD'"/>
<xsl:when test="$elementValue='NYSE'"/>
<xsl:when test="$elementValue='NZAU'"/>
<xsl:when test="$elementValue='NZWE'"/>
<xsl:when test="$elementValue='PAPC'"/>
<xsl:when test="$elementValue='PHMA'"/>
<xsl:when test="$elementValue='PLWA'"/>
<xsl:when test="$elementValue='PTLI'"/>
<xsl:when test="$elementValue='RUMO'"/>
<xsl:when test="$elementValue='SARI'"/>
<xsl:when test="$elementValue='SGSI'"/>
<xsl:when test="$elementValue='SKBR'"/>
<xsl:when test="$elementValue='THBA'"/>
<xsl:when test="$elementValue='TRAN'"/>
<xsl:when test="$elementValue='TWTA'"/>
<xsl:when test="$elementValue='USCH'"/>
<xsl:when test="$elementValue='USGS'"/>
<xsl:when test="$elementValue='USLA'"/>
<xsl:when test="$elementValue='ZAJO'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>

</xsl:template>


<xsl:template name="isValidBusinessDayConvention">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='MODFOLLOWING'"/>
<xsl:when test="$elementValue='FOLLOWING'"/>
<xsl:when test="$elementValue='PRECEDING'"/>
<xsl:when test="$elementValue='NONE'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidCalculationAgentParty">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='NonExercisingParty'"/>
<xsl:when test="$elementValue='AsSpecifiedInMasterAgreement'"/>
<xsl:otherwise>
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error>
</xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidCompoundingMethod">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='Flat'"/>
<xsl:when test="$elementValue='Straight'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidCurrency">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/> for product type of '<xsl:value-of select="$productType"/>'. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$productType='IRS'">
<xsl:choose>
<xsl:when test="$elementValue='AUD'"/>
<xsl:when test="$elementValue='CAD'"/>
<xsl:when test="$elementValue='CHF'"/>
<xsl:when test="$elementValue='CNY'"/>
<xsl:when test="$elementValue='CZK'"/>
<xsl:when test="$elementValue='DKK'"/>
<xsl:when test="$elementValue='EUR'"/>
<xsl:when test="$elementValue='GBP'"/>
<xsl:when test="$elementValue='HKD'"/>
<xsl:when test="$elementValue='HUF'"/>
<xsl:when test="$elementValue='IDR'"/>
<xsl:when test="$elementValue='ILS'"/>
<xsl:when test="$elementValue='INR'"/>
<xsl:when test="$elementValue='KRW'"/>
<xsl:when test="$elementValue='JPY'"/>
<xsl:when test="$elementValue='MXN'"/>
<xsl:when test="$elementValue='MYR'"/>
<xsl:when test="$elementValue='NOK'"/>
<xsl:when test="$elementValue='NZD'"/>
<xsl:when test="$elementValue='PHP'"/>
<xsl:when test="$elementValue='PLN'"/>
<xsl:when test="$elementValue='SEK'"/>
<xsl:when test="$elementValue='SGD'"/>
<xsl:when test="$elementValue='SKK'"/>
<xsl:when test="$elementValue='THB'"/>
<xsl:when test="$elementValue='TWD'"/>
<xsl:when test="$elementValue='USD'"/>
<xsl:when test="$elementValue='ZAR'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:when test="$productType='Swaption'">
<xsl:choose>
<xsl:when test="$elementValue='AUD'"/>
<xsl:when test="$elementValue='CAD'"/>
<xsl:when test="$elementValue='CHF'"/>
<xsl:when test="$elementValue='CZK'"/>
<xsl:when test="$elementValue='DKK'"/>
<xsl:when test="$elementValue='EUR'"/>
<xsl:when test="$elementValue='GBP'"/>
<xsl:when test="$elementValue='HKD'"/>
<xsl:when test="$elementValue='HUF'"/>
<xsl:when test="$elementValue='JPY'"/>
<xsl:when test="$elementValue='NOK'"/>
<xsl:when test="$elementValue='NZD'"/>
<xsl:when test="$elementValue='PLN'"/>
<xsl:when test="$elementValue='SEK'"/>
<xsl:when test="$elementValue='SKK'"/>
<xsl:when test="$elementValue='USD'"/>
<xsl:when test="$elementValue='ZAR'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:when test="$productType='FRA'">
<xsl:choose>
<xsl:when test="$elementValue='AUD'"/>
<xsl:when test="$elementValue='CAD'"/>
<xsl:when test="$elementValue='CHF'"/>
<xsl:when test="$elementValue='CZK'"/>
<xsl:when test="$elementValue='DKK'"/>
<xsl:when test="$elementValue='EUR'"/>
<xsl:when test="$elementValue='GBP'"/>
<xsl:when test="$elementValue='HKD'"/>
<xsl:when test="$elementValue='HUF'"/>
<xsl:when test="$elementValue='ILS'"/>
<xsl:when test="$elementValue='JPY'"/>
<xsl:when test="$elementValue='NOK'"/>
<xsl:when test="$elementValue='NZD'"/>
<xsl:when test="$elementValue='PLN'"/>
<xsl:when test="$elementValue='SEK'"/>
<xsl:when test="$elementValue='SGD'"/>
<xsl:when test="$elementValue='SKK'"/>
<xsl:when test="$elementValue='USD'"/>
<xsl:when test="$elementValue='ZAR'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:when test="$productType='OIS'">
<xsl:choose>
<xsl:when test="$elementValue='AUD'"/>
<xsl:when test="$elementValue='CAD'"/>
<xsl:when test="$elementValue='CHF'"/>
<xsl:when test="$elementValue='DKK'"/>
<xsl:when test="$elementValue='EUR'"/>
<xsl:when test="$elementValue='GBP'"/>
<xsl:when test="$elementValue='HKD'"/>
<xsl:when test="$elementValue='INR'"/>
<xsl:when test="$elementValue='JPY'"/>
<xsl:when test="$elementValue='NZD'"/>
<xsl:when test="$elementValue='SEK'"/>
<xsl:when test="$elementValue='SGD'"/>
<xsl:when test="$elementValue='USD'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:when test="$productType='ZCInflationSwap'">
<xsl:choose>
<xsl:when test="$elementValue='AUD'"/>
<xsl:when test="$elementValue='CAD'"/>
<xsl:when test="$elementValue='DKK'"/>
<xsl:when test="$elementValue='EUR'"/>
<xsl:when test="$elementValue='GBP'"/>
<xsl:when test="$elementValue='JPY'"/>
<xsl:when test="$elementValue='SEK'"/>
<xsl:when test="$elementValue='USD'"/>
<xsl:when test="$elementValue='ZAR'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise>
</xsl:otherwise>
</xsl:choose>

</xsl:template>


<xsl:template name="isValidDate">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Invalid date format for <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:if test="not(string-length($elementValue)=10)">
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error>
</xsl:if>



<xsl:choose>
<xsl:when test="substring($elementValue,5,1)='-'">
<xsl:choose>
<xsl:when test="substring($elementValue,8,1)='-'">
<xsl:choose>
<xsl:when test="string(number(substring($elementValue,1,1)))!= 'NaN'">
<xsl:choose>
<xsl:when test="string(number(substring($elementValue,2,1)))!= 'NaN'">
<xsl:choose>
<xsl:when test="string(number(substring($elementValue,3,1)))!= 'NaN'">
<xsl:choose>
<xsl:when test="string(number(substring($elementValue,4,1)))!= 'NaN'">
<xsl:choose>
<xsl:when test="string(number(substring($elementValue,6,1)))!= 'NaN'">
<xsl:choose>
<xsl:when test="string(number(substring($elementValue,7,1)))!= 'NaN'">
<xsl:choose>
<xsl:when test="string(number(substring($elementValue,9,1)))!= 'NaN'">
<xsl:choose>
<xsl:when test="string(number(substring($elementValue,10,1)))!= 'NaN'">
<xsl:choose>
<xsl:when test="number(substring($elementValue,1,4)) != 0">
<xsl:choose>
<xsl:when test="number(substring($elementValue,6,2)) != 0 and number(substring($elementValue,6,2)) &lt; 13">
<xsl:choose>
<xsl:when test="number(substring($elementValue,9,2)) != 0 and number(substring($elementValue,9,2)) &lt; 32">
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidDayCountFraction">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/> for product type of '<xsl:value-of select="$productType"/>'. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:if test="$productType='IRS' or $productType='OIS' or $productType='Swaption'">
<xsl:choose>
<xsl:when test="$elementValue='ACT/365.FIXED'"/>
<xsl:when test="$elementValue='ACT/365.ISDA'"/>
<xsl:when test="$elementValue='ACT/360'"/>
<xsl:when test="$elementValue='30/360'"/>
<xsl:when test="$elementValue='30E/360'"/>
<xsl:when test="$elementValue='30E/360.ISDA'"/>
<xsl:when test="$elementValue='ACT/ACT.ISMA'"/>
<xsl:when test="$elementValue='ACT/ACT.ICMA'"/>
<xsl:when test="$elementValue='ACT/ACT.ISDA'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

<xsl:if test="$productType='FRA'">
<xsl:choose>
<xsl:when test="$elementValue='ACT/365.FIXED'"/>
<xsl:when test="$elementValue='ACT/360'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

<xsl:if test="$productType='ZCInflationSwap'">
<xsl:choose>
<xsl:when test="$elementValue='1/1'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

</xsl:template>


<xsl:template name="isValidDayType">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='Business'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidInformationProvider">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Missing, empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='ISDA'"/>
<xsl:when test="$elementValue='Telerate'"/>
<xsl:when test="$elementValue='Reuters'"/>
<xsl:otherwise>
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error>
</xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidIntegerNumber">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="minIncl"/>
<xsl:param name="maxIncl"/>
<xsl:param name="context"/>

<xsl:choose>
<xsl:when test="string(number($elementValue)) !='NaN' and not(contains($elementValue,'.')) and not(contains($elementValue,' '))">
<xsl:if test="number($elementValue) &lt; $minIncl or number($elementValue) &gt; $maxIncl">
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$elementName"/> is outside allowable range; minIncl=<xsl:value-of select="$minIncl"/>, maxIncl=<xsl:value-of select="$maxIncl"/>. Value = '<xsl:value-of select="$elementValue"/>'.</text></error>
</xsl:if>
</xsl:when>
<xsl:otherwise>
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$elementName"/> is not a valid integer number. Value = '<xsl:value-of select="$elementValue"/>'.</text></error>
</xsl:otherwise>
</xsl:choose>

</xsl:template>


<xsl:template name="isValidIMMCurrency">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">rollConvention must not be equal to 'IMM' if trade currency is equal to '<xsl:value-of select="$elementValue"/>' (IMM Rolls not currently supported in SwapsWire for <xsl:value-of select="$elementValue"/>).</xsl:variable>
<xsl:choose>
<xsl:when test="$elementValue='AUD'"/>
<xsl:when test="$elementValue='CAD'"/>
<xsl:when test="$elementValue='CZK'"/>
<xsl:when test="$elementValue='CHF'"/>
<xsl:when test="$elementValue='DKK'"/>
<xsl:when test="$elementValue='EUR'"/>
<xsl:when test="$elementValue='GBP'"/>
<xsl:when test="$elementValue='HKD'"/>
<xsl:when test="$elementValue='IDR'"/>
<xsl:when test="$elementValue='ILS'"/>
<xsl:when test="$elementValue='INR'"/>
<xsl:when test="$elementValue='HUF'"/>
<xsl:when test="$elementValue='JPY'"/>
<xsl:when test="$elementValue='KRW'"/>
<xsl:when test="$elementValue='MYR'"/>
<xsl:when test="$elementValue='NOK'"/>
<xsl:when test="$elementValue='NZD'"/>
<xsl:when test="$elementValue='PLN'"/>
<xsl:when test="$elementValue='SEK'"/>
<xsl:when test="$elementValue='SGD'"/>
<xsl:when test="$elementValue='SKK'"/>
<xsl:when test="$elementValue='THB'"/>
<xsl:when test="$elementValue='TWD'"/>
<xsl:when test="$elementValue='USD'"/>
<xsl:when test="$elementValue='ZAR'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>

</xsl:template>


<xsl:template name="isValidIMMMonth">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="calculationPeriodFrequency"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">When rollConvention is equal to 'IMM' and floating leg calculationPeriodFrequency is equal to '3M', '6M' or '1Y' <xsl:value-of select="$elementName"/> month must be Mar, Jun, Sep or Dec. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:variable name="month"><xsl:value-of select="substring($elementValue,6,2)"/></xsl:variable>
<xsl:choose>
<xsl:when test="$calculationPeriodFrequency='3M' or $calculationPeriodFrequency='6M' or $calculationPeriodFrequency='1Y'">
<xsl:choose>
<xsl:when test="$month='03'"/>
<xsl:when test="$month='06'"/>
<xsl:when test="$month='09'"/>
<xsl:when test="$month='12'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise/>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidIntegerNumber2">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="minIncl"/>
<xsl:param name="maxIncl"/>
<xsl:param name="maxDigits"/>
<xsl:param name="context"/>

<xsl:choose>
<xsl:when test="string(number($elementValue)) !='NaN' and not(contains($elementValue,'.')) and not(contains($elementValue,' '))">
<xsl:if test="number($elementValue) &lt; $minIncl or number($elementValue) &gt; $maxIncl">
<error><context><xsl:value-of select="$context"/></context><text>*** The part of <xsl:value-of select="$elementName"/> left of fractional separator is outside allowable range; minIncl=<xsl:value-of select="$minIncl"/>, maxIncl=<xsl:value-of select="$maxIncl"/>. Value = '<xsl:value-of select="$elementValue"/>'.</text></error>
</xsl:if>
</xsl:when>
<xsl:otherwise>
<error><context><xsl:value-of select="$context"/></context><text>*** The part of <xsl:value-of select="$elementName"/> left of fractional separator is not a valid integer number. Value = '<xsl:value-of select="$elementValue"/>'.</text></error>
</xsl:otherwise>
</xsl:choose>

<xsl:if test="string-length($elementValue) &gt; $maxDigits"><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$elementName"/> has too many digits to left of fractional separator; maxDigits=<xsl:value-of select="$maxDigits"/>. Value = '<xsl:value-of select="$elementValue"/>'.</text></error></xsl:if>

</xsl:template>


<xsl:template name="isValidMasterAgreementType">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='ISDA'"/>
<xsl:when test="$elementValue='AFB/FBF'"/>
<xsl:when test="$elementValue='DERV'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidNumber">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="minIncl"/>
<xsl:param name="maxIncl"/>
<xsl:param name="maxDecs"/>
<xsl:param name="context"/>

<xsl:choose>
<xsl:when test="string(number($elementValue)) !='NaN' and not(contains($elementValue,' ')) and not(contains($elementValue,'e')) and not(contains($elementValue,'E'))">
<xsl:if test="number($elementValue) &lt; $minIncl or number($elementValue) &gt; $maxIncl">
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$elementName"/> is outside allowable range; minIncl=<xsl:value-of select="$minIncl"/>, maxIncl=<xsl:value-of select="$maxIncl"/>. Value = '<xsl:value-of select="$elementValue"/>'.</text></error>
</xsl:if>
</xsl:when>
<xsl:otherwise>
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$elementName"/> is not a valid number. Value = '<xsl:value-of select="$elementValue"/>'.</text></error>
</xsl:otherwise>
</xsl:choose>

<xsl:if test="string-length(substring-after($elementValue,'.')) &gt; $maxDecs"><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$elementName"/> has too many decimal places; maxDecs=<xsl:value-of select="$maxDecs"/>. Value = '<xsl:value-of select="$elementValue"/>'.</text></error></xsl:if>

</xsl:template>


<xsl:template name="isValidNumber2">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="minIncl"/>
<xsl:param name="maxIncl"/>
<xsl:param name="maxDecs"/>
<xsl:param name="context"/>

<xsl:choose>
<xsl:when test="string(number($elementValue)) !='NaN' and not(contains($elementValue,' ')) and not(contains($elementValue,'e')) and not(contains($elementValue,'E'))">
<xsl:if test="number($elementValue) &lt; $minIncl or number($elementValue) &gt; $maxIncl">
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$elementName"/> is outside allowable range; minIncl=<xsl:value-of select="$minIncl"/>, maxIncl=<xsl:value-of select="$maxIncl"/>. Value = '<xsl:value-of select="$elementValue"/>'.</text></error>
</xsl:if>
<xsl:if test="contains($elementValue,'.') and string-length(substring-after($elementValue,'.')) = 0">
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$elementName"/> is not a valid number. At least one digit must follow decimal separator. Value = '<xsl:value-of select="$elementValue"/>'.</text></error>
</xsl:if>
<xsl:if test="contains($elementValue,'.') and string-length(substring-before($elementValue,'.')) = 0">
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$elementName"/> is not a valid number. At least one digit must precede decimal separator. Value = '<xsl:value-of select="$elementValue"/>'.</text></error>
</xsl:if>
</xsl:when>
<xsl:otherwise>
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$elementName"/> is not a valid number. Value = '<xsl:value-of select="$elementValue"/>'.</text></error>
</xsl:otherwise>
</xsl:choose>

<xsl:if test="string-length(substring-after($elementValue,'.')) &gt; $maxDecs"><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$elementName"/> has too many decimal places; maxDecs=<xsl:value-of select="$maxDecs"/>. Value = '<xsl:value-of select="$elementValue"/>'.</text></error></xsl:if>

</xsl:template>


<xsl:template name="isValidPayRelativeTo">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='CalculationPeriodEndDate'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidPeriod">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/> for product type of '<xsl:value-of select="$productType"/>'. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:if test="not($productType='OIS')">
<xsl:choose>
<xsl:when test="$elementValue='D'"/>
<xsl:when test="$elementValue='W'"/>
<xsl:when test="$elementValue='M'"/>
<xsl:when test="$elementValue='Y'"/>
<xsl:when test="$elementValue='T'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

<xsl:if test="$productType='OIS'">
<xsl:choose>
<xsl:when test="$elementValue='D'"/>
<xsl:when test="$elementValue='M'"/>
<xsl:when test="$elementValue='Y'"/>
<xsl:when test="$elementValue='T'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

</xsl:template>


<xsl:template name="isValidperiodMultiplier">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="not(contains($elementValue,'.')) and not(contains($elementValue,'e')) and not(contains($elementValue,'E'))">
<xsl:if test="string(number($elementValue)) ='NaN'">
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error>
</xsl:if>
</xsl:when>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidPriceType">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='F128'"/>
<xsl:when test="$elementValue='D5'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidProductType">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>

<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/> if SWDML version = "<xsl:value-of select="$version"/>". Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:if test="$version='4-2'">
<xsl:choose>
<xsl:when test="$elementValue='SingleCurrencyInterestRateSwap'"/>
<xsl:when test="$elementValue='FRA'"/>
<xsl:when test="$elementValue='OIS'"/>
<xsl:when test="$elementValue='Swaption'"/>
<xsl:when test="$elementValue='ZC Inflation Swap'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

</xsl:template>

<xsl:template name="isValidProductSubType">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='ZeroCouponFixed'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>

</xsl:template>

<xsl:template name="isValidQuotationRateType">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Missing, empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='Bid'"/>
<xsl:when test="$elementValue='Ask'"/>
<xsl:when test="$elementValue='Mid'"/>
<xsl:when test="$elementValue='ExercisingPartyPays'"/>
<xsl:otherwise>
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error>
</xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidResetRelativeTo">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>

<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/> for product type is '<xsl:value-of select="$productType"/>'. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:if test="$productType='IRS' or $productType='fpml:capFloor' or $productType='Swaption'">
<xsl:choose>
<xsl:when test="$elementValue='CalculationPeriodStartDate'"/>
<xsl:when test="$elementValue='CalculationPeriodEndDate'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

<xsl:if test="$productType='OIS'">
<xsl:choose>
<xsl:when test="$elementValue='CalculationPeriodEndDate'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

</xsl:template>


<xsl:template name="isValidRollConvention">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>

<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/> for product type of '<xsl:value-of select="$productType"/>'. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:if test="not($productType='OIS')">
<xsl:choose>
<xsl:when test="$elementValue='NONE'"/>
<xsl:when test="$elementValue='EOM'"/>
<xsl:when test="$elementValue='IMM'"/>
<xsl:when test="$elementValue='IMMAUD'"/>
<xsl:when test="$elementValue='IMMCAD'"/>
<xsl:when test="$elementValue='IMMNZD'"/>
<xsl:when test="$elementValue='1'"/>
<xsl:when test="$elementValue='2'"/>
<xsl:when test="$elementValue='3'"/>
<xsl:when test="$elementValue='4'"/>
<xsl:when test="$elementValue='5'"/>
<xsl:when test="$elementValue='6'"/>
<xsl:when test="$elementValue='7'"/>
<xsl:when test="$elementValue='8'"/>
<xsl:when test="$elementValue='9'"/>
<xsl:when test="$elementValue='10'"/>
<xsl:when test="$elementValue='11'"/>
<xsl:when test="$elementValue='12'"/>
<xsl:when test="$elementValue='13'"/>
<xsl:when test="$elementValue='14'"/>
<xsl:when test="$elementValue='15'"/>
<xsl:when test="$elementValue='16'"/>
<xsl:when test="$elementValue='17'"/>
<xsl:when test="$elementValue='18'"/>
<xsl:when test="$elementValue='19'"/>
<xsl:when test="$elementValue='20'"/>
<xsl:when test="$elementValue='21'"/>
<xsl:when test="$elementValue='22'"/>
<xsl:when test="$elementValue='23'"/>
<xsl:when test="$elementValue='24'"/>
<xsl:when test="$elementValue='25'"/>
<xsl:when test="$elementValue='26'"/>
<xsl:when test="$elementValue='27'"/>
<xsl:when test="$elementValue='28'"/>
<xsl:when test="$elementValue='29'"/>
<xsl:when test="$elementValue='30'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

<xsl:if test="$productType='OIS'">
<xsl:choose>
<xsl:when test="$elementValue='NONE'"/>
<xsl:when test="$elementValue='EOM'"/>
<xsl:when test="$elementValue='1'"/>
<xsl:when test="$elementValue='2'"/>
<xsl:when test="$elementValue='3'"/>
<xsl:when test="$elementValue='4'"/>
<xsl:when test="$elementValue='5'"/>
<xsl:when test="$elementValue='6'"/>
<xsl:when test="$elementValue='7'"/>
<xsl:when test="$elementValue='8'"/>
<xsl:when test="$elementValue='9'"/>
<xsl:when test="$elementValue='10'"/>
<xsl:when test="$elementValue='11'"/>
<xsl:when test="$elementValue='12'"/>
<xsl:when test="$elementValue='13'"/>
<xsl:when test="$elementValue='14'"/>
<xsl:when test="$elementValue='15'"/>
<xsl:when test="$elementValue='16'"/>
<xsl:when test="$elementValue='17'"/>
<xsl:when test="$elementValue='18'"/>
<xsl:when test="$elementValue='19'"/>
<xsl:when test="$elementValue='20'"/>
<xsl:when test="$elementValue='21'"/>
<xsl:when test="$elementValue='22'"/>
<xsl:when test="$elementValue='23'"/>
<xsl:when test="$elementValue='24'"/>
<xsl:when test="$elementValue='25'"/>
<xsl:when test="$elementValue='26'"/>
<xsl:when test="$elementValue='27'"/>
<xsl:when test="$elementValue='28'"/>
<xsl:when test="$elementValue='29'"/>
<xsl:when test="$elementValue='30'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:if>

</xsl:template>


<xsl:template name="isValidStubLength">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='Short'"/>
<xsl:when test="$elementValue='Long'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidStubPosition">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='Start'"/>
<xsl:when test="$elementValue='End'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValidTime">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='00:00:00'"/>
<xsl:when test="$elementValue='01:00:00'"/>
<xsl:when test="$elementValue='02:00:00'"/>
<xsl:when test="$elementValue='03:00:00'"/>
<xsl:when test="$elementValue='04:00:00'"/>
<xsl:when test="$elementValue='05:00:00'"/>
<xsl:when test="$elementValue='06:00:00'"/>
<xsl:when test="$elementValue='07:00:00'"/>
<xsl:when test="$elementValue='08:00:00'"/>
<xsl:when test="$elementValue='09:00:00'"/>
<xsl:when test="$elementValue='10:00:00'"/>
<xsl:when test="$elementValue='11:00:00'"/>
<xsl:when test="$elementValue='12:00:00'"/>
<xsl:when test="$elementValue='12:30:00'"/>
<xsl:when test="$elementValue='13:00:00'"/>
<xsl:when test="$elementValue='14:00:00'"/>
<xsl:when test="$elementValue='15:00:00'"/>
<xsl:when test="$elementValue='16:00:00'"/>
<xsl:when test="$elementValue='17:00:00'"/>
<xsl:when test="$elementValue='18:00:00'"/>
<xsl:when test="$elementValue='19:00:00'"/>
<xsl:when test="$elementValue='20:00:00'"/>
<xsl:when test="$elementValue='21:00:00'"/>
<xsl:when test="$elementValue='22:00:00'"/>
<xsl:when test="$elementValue='23:00:00'"/>
<xsl:otherwise>
<error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error>
</xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValid32nd">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText"> If swBondPrice is equal to 'F128' two characters to right of fractional separator in <xsl:value-of select="$elementName"/> are not in range 00 - 31. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='00'"/>
<xsl:when test="$elementValue='01'"/>
<xsl:when test="$elementValue='02'"/>
<xsl:when test="$elementValue='03'"/>
<xsl:when test="$elementValue='04'"/>
<xsl:when test="$elementValue='05'"/>
<xsl:when test="$elementValue='06'"/>
<xsl:when test="$elementValue='07'"/>
<xsl:when test="$elementValue='08'"/>
<xsl:when test="$elementValue='09'"/>
<xsl:when test="$elementValue='10'"/>
<xsl:when test="$elementValue='11'"/>
<xsl:when test="$elementValue='12'"/>
<xsl:when test="$elementValue='13'"/>
<xsl:when test="$elementValue='14'"/>
<xsl:when test="$elementValue='15'"/>
<xsl:when test="$elementValue='16'"/>
<xsl:when test="$elementValue='17'"/>
<xsl:when test="$elementValue='18'"/>
<xsl:when test="$elementValue='19'"/>
<xsl:when test="$elementValue='20'"/>
<xsl:when test="$elementValue='21'"/>
<xsl:when test="$elementValue='22'"/>
<xsl:when test="$elementValue='23'"/>
<xsl:when test="$elementValue='24'"/>
<xsl:when test="$elementValue='25'"/>
<xsl:when test="$elementValue='26'"/>
<xsl:when test="$elementValue='27'"/>
<xsl:when test="$elementValue='28'"/>
<xsl:when test="$elementValue='29'"/>
<xsl:when test="$elementValue='30'"/>
<xsl:when test="$elementValue='31'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template name="isValid128th">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText"> If swBondPrice is equal to 'F128' third character to right of fractional separator in <xsl:value-of select="$elementName"/> must be '2', '+' or '6'. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue=''"/>
<xsl:when test="$elementValue='2'"/>
<xsl:when test="$elementValue='+'"/>
<xsl:when test="$elementValue='6'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template name="isValidBreakCalculationMethod">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='Adjust To Coupon Dates'"/>
<xsl:when test="$elementValue='Straight Calendar Dates'"/>
<xsl:when test="$elementValue='ISDA Standard Method'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template name="isValidNonDeliverableCurrency">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">Empty or invalid <xsl:value-of select="$elementName"/> for Non-deliverable product type of '<xsl:value-of select="$productType"/>'. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$productType='IRS'">
<xsl:choose>
<xsl:when test="$elementValue='CNY'"/>
<xsl:when test="$elementValue='IDR'"/>
<xsl:when test="$elementValue='INR'"/>
<xsl:when test="$elementValue='KRW'"/>
<xsl:when test="$elementValue='MYR'"/>
<xsl:when test="$elementValue='PHP'"/>
<xsl:when test="$elementValue='THB'"/>
<xsl:when test="$elementValue='TWD'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:when test="$productType='OIS'">
<xsl:choose>
<xsl:when test="$elementValue='INR'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:when>
</xsl:choose>
</xsl:template>

<xsl:template name="isValidFRADiscounting">
<xsl:param name="elementName"/>
<xsl:param name="elementValue"/>
<xsl:param name="testNumber"/>
<xsl:param name="context"/>
<xsl:variable name="errorText">ANDREW Empty or invalid <xsl:value-of select="$elementName"/>. Value = '<xsl:value-of select="$elementValue"/>'.</xsl:variable>

<xsl:choose>
<xsl:when test="$elementValue='ISDA'"/>
<xsl:when test="$elementValue='NONE'"/>
<xsl:otherwise><error><context><xsl:value-of select="$context"/></context><text>*** <xsl:value-of select="$errorText"/></text></error></xsl:otherwise>
</xsl:choose>
</xsl:template>

</xsl:stylesheet>



